@@ -55,80 +55,35 @@ K_EXPORT_COMPONENT_FACTORY(libexcelimport, ExcelImportFactory("kofficefilters"))
 #define UNICODE_GBP 0x00A3
 #define UNICODE_JPY 0x00A5
 
-namespace Swinder {
-
+namespace Swinder
+{
 // qHash function to support hashing by Swinder::FormatFont instances.
 static inline uint qHash(const Swinder::FormatFont& font)
 {
     // TODO: make this a better hash
-    return qHash(string(font.fontFamily())) ^ qRound(font.fontSize() * 100);
+    return qHash(font.fontFamily()) ^ qRound(font.fontSize() * 100);
 }
 
-qreal offset( unsigned long dimension, unsigned long offset ) {
+static qreal offset( unsigned long dimension, unsigned long offset ) {
     return (float)dimension * (float)offset / 1024.0;
 }
 
-qreal columnWidth(Sheet* sheet, unsigned long col) {
+static qreal columnWidth(Sheet* sheet, unsigned long col) {
     if( sheet->column(col, false) )
         return sheet->column(col)->width();
 
     return sheet->defaultColWidth();
 }
 
-qreal rowHeight(Sheet* sheet, unsigned long row) {
+static qreal rowHeight(Sheet* sheet, unsigned long row) {
     if( sheet->row(row, false) )
         return sheet->row(row)->height();
 
     return sheet->defaultRowHeight();
 }
 
-qreal heightOffset( Sheet* sheet, qreal rwT, qreal dyT, qreal rwB, qreal dyB ) {
-    return - offset( rowHeight(sheet, rwT), dyT)
-           + offset( rowHeight(sheet, rwB), dyB);
-}
-
-qreal widthOffset( Sheet* sheet, qreal colL, qreal dxL, qreal colR, qreal dxR  ) {
-    return - offset(columnWidth(sheet, colL), dxL)
-           + offset(columnWidth(sheet, colR), dxR);
-}
-
-qreal columnStart(Sheet* sheet, unsigned long col) {
-    double columnStart = 0.0;
-    for( unsigned long i = 0; i < col; ++i )
-        columnStart += columnWidth(sheet, i);
-
-    return columnStart;
-}
-
-qreal rowStart(Sheet* sheet, unsigned long row) {
-    double rowStart = 0.0;
-    for( unsigned long i = 0; i < row; ++i )
-        rowStart += rowHeight(sheet, i);
-
-    return rowStart;
-}
-
-qreal columnDistance(Sheet* sheet, unsigned long col1, unsigned long col2) {
-    double columnDistance = 0.0;
-
-    for( unsigned long i = col1; i < col2; ++i )
-        columnDistance += columnWidth(sheet, i);
-
-    return columnDistance;
-}
-
-qreal rowDistance(Sheet* sheet, unsigned long row1, unsigned long row2) {
-    double rowDistance = 0.0;
-    for( unsigned long i = row1; i < row2; ++i )
-        rowDistance += rowHeight(sheet, i);
-
-    return rowDistance;
-}
-
-}
-
 // Returns A for 1, B for 2, C for 3, etc.
-QString columnName(uint column)
+static QString columnName(uint column)
 {
     QString s;
     unsigned digits = 1;
@@ -140,6 +95,21 @@ QString columnName(uint column)
     return s;
 }
 
+static QString encodeSheetName(const QString& name)
+{
+    QString sheetName = name;
+    if (sheetName.contains(' ') || sheetName.contains('.') || sheetName.contains('\''))
+        sheetName = '\'' + sheetName.replace('\'', "''") + '\'';
+    return sheetName;
+}
+
+static QString encodeAddress(const QString& sheetName, uint column, uint row)
+{
+    return QString("%1.%2%3").arg(sheetName).arg(columnName(column)).arg(row+1);
+}
+
+}
+
 using namespace Swinder;
 
 class ExcelImport::Private
@@ -183,8 +153,8 @@ public:
     void processWorkbookForStyle(Workbook* workbook, KoXmlWriter* xmlWriter);
     void processSheetForBody(KoOdfWriteStore* store, Sheet* sheet, KoXmlWriter* xmlWriter);
     void processSheetForStyle(Sheet* sheet, KoXmlWriter* xmlWriter);
-    void processSheetForHeaderFooter ( Sheet* sheet, KoXmlWriter* writer);
-    void processHeaderFooterStyle (UString text, KoXmlWriter* xmlWriter);
+    void processSheetForHeaderFooter(Sheet* sheet, KoXmlWriter* writer);
+    void processHeaderFooterStyle(const QString& text, KoXmlWriter* xmlWriter);
     void processColumnForBody(Sheet* sheet, int columnIndex, KoXmlWriter* xmlWriter, unsigned& outlineLevel);
     void processColumnForStyle(Sheet* sheet, int columnIndex, KoXmlWriter* xmlWriter);
     int processRowForBody(KoOdfWriteStore* store, Sheet* sheet, int rowIndex, KoXmlWriter* xmlWriter, unsigned& outlineLevel);
@@ -219,17 +189,6 @@ ExcelImport::~ExcelImport()
     delete d;
 }
 
-class StoreImpl : public Store {
-public:
-    StoreImpl(KoStore* store) : Store(), m_store(store) {}
-    virtual ~StoreImpl() {}
-    virtual bool open(const std::string& filename) { return m_store->open(filename.c_str()); }
-    virtual bool write(const char *data, int size) { return m_store->write(data, size); }
-    virtual bool close() { return m_store->close(); }
-private:
-    KoStore* m_store;
-};
-
 KoFilter::ConversionStatus ExcelImport::convert(const QByteArray& from, const QByteArray& to)
 {
     if (from != "application/vnd.ms-excel")
@@ -257,8 +216,7 @@ KoFilter::ConversionStatus ExcelImport::convert(const QByteArray& from, const QB
     d->storeout->disallowNameExpansion();
 
     // open inputFile
-    StoreImpl *storeimpl = new StoreImpl(d->storeout);
-    d->workbook = new Swinder::Workbook(storeimpl);
+    d->workbook = new Swinder::Workbook(d->storeout);
     connect(d->workbook, SIGNAL(sigProgress(int)), this, SIGNAL(sigProgress(int)));
     if (!d->workbook->load(d->inputFile.toLocal8Bit())) {
         delete d->workbook;
@@ -284,8 +242,7 @@ KoFilter::ConversionStatus ExcelImport::convert(const QByteArray& from, const QB
     // header and footer are read from each sheet and saved in styles
     // So creating content before styles
     // store document content
-    if ( !d->createContent( &oasisStore ) )
-    {
+    if (!d->createContent(&oasisStore)) {
         kWarning() << "Couldn't open the file 'content.xml'.";
         delete d->workbook;
         delete d->storeout;
@@ -293,8 +250,7 @@ KoFilter::ConversionStatus ExcelImport::convert(const QByteArray& from, const QB
     }
 
     // store document styles
-    if ( !d->createStyles( d->storeout, manifestWriter, d->mainStyles ) )
-    {
+    if (!d->createStyles(d->storeout, manifestWriter, d->mainStyles)) {
         kWarning() << "Couldn't open the file 'styles.xml'.";
         delete d->workbook;
         delete d->storeout;
@@ -329,11 +285,13 @@ KoFilter::ConversionStatus ExcelImport::convert(const QByteArray& from, const QB
     // we are done!
     delete d->workbook;
     delete d->styles;
+    delete d->mainStyles;
     delete d->storeout;
     d->inputFile.clear();
     d->outputFile.clear();
     d->workbook = 0;
     d->styles = 0;
+    d->mainStyles = 0;
     d->cellStyles.clear();
     d->rowStyles.clear();
     d->colStyles.clear();
@@ -565,14 +523,14 @@ bool ExcelImport::Private::createSettings(KoOdfWriteStore* store)
     settingsWriter->startElement("config:config-item-map-entry");
     settingsWriter->addConfigItem("ViewId", QString::fromLatin1("View1"));
     if(Sheet *sheet = workbook->sheet(workbook->activeTab()))
-        settingsWriter->addConfigItem("ActiveTable", string(sheet->name()));
+        settingsWriter->addConfigItem("ActiveTable", sheet->name());
 
     settingsWriter->startElement("config:config-item-map-named");
     settingsWriter->addAttribute("config:name", "Tables");
     for(uint i = 0; i < workbook->sheetCount(); ++i) {
         Sheet* sheet = workbook->sheet(i);
         settingsWriter->startElement("config:config-item-map-entry");
-        settingsWriter->addAttribute("config:name", string(sheet->name()));
+        settingsWriter->addAttribute("config:name", sheet->name());
         QPoint point = sheet->firstVisibleCell();
         settingsWriter->addConfigItem("CursorPositionX", point.x());
         settingsWriter->addConfigItem("CursorPositionY", point.y());
@@ -624,13 +582,13 @@ void ExcelImport::Private::processWorkbookForBody(KoOdfWriteStore* store, Workbo
         processSheetForBody(store, sheet, xmlWriter);
     }
 
-    std::map<std::pair<unsigned, UString>, UString> &namedAreas = workbook->namedAreas();
+    std::map<std::pair<unsigned, QString>, QString> &namedAreas = workbook->namedAreas();
     if(namedAreas.size() > 0) {
         xmlWriter->startElement("table:named-expressions");
-        for(std::map<std::pair<unsigned, UString>, UString>::iterator it = namedAreas.begin(); it != namedAreas.end(); it++) {
+        for(std::map<std::pair<unsigned, QString>, QString>::iterator it = namedAreas.begin(); it != namedAreas.end(); it++) {
             xmlWriter->startElement("table:named-range");
-            xmlWriter->addAttribute("table:name", string((*it).first.second) ); // e.g. "My Named Range"
-            QString range = string((*it).second);
+            xmlWriter->addAttribute("table:name", it->first.second ); // e.g. "My Named Range"
+            QString range = it->second;
             if(range.startsWith('[') && range.endsWith(']'))
                 range = range.mid(1, range.length() - 2);
             xmlWriter->addAttribute("table:cell-range-address", range); // e.g. "$Sheet1.$B$2:.$B$3"
@@ -643,23 +601,17 @@ void ExcelImport::Private::processWorkbookForBody(KoOdfWriteStore* store, Workbo
     int rangeId = 1;
     for (unsigned i = 0; i < workbook->sheetCount(); i++) {
         QList<QRect> filters = workbook->filterRanges(i);
-        QString sheetName = string(workbook->sheet(i)->name());
+        QString sheetName = workbook->sheet(i)->name();
         if (filters.size()) {
             if (!openedDBRanges) xmlWriter->startElement("table:database-ranges");
             openedDBRanges = true;
 
             foreach (const QRect& filter, filters) {
-                QString sRange(sheetName);
-                sRange.append(".");
-                sRange.append(columnName(filter.left()));
-                sRange.append(QString::number(filter.top()+1));
+                QString sRange(encodeAddress(sheetName, filter.left(), filter.top()));
                 sRange.append(":");
-                sRange.append(sheetName);
-                sRange.append(".");
-                sRange.append(columnName(filter.right()));
-                sRange.append(QString::number(workbook->sheet(i)->maxRow()));
+                sRange.append(encodeAddress(sheetName, filter.right(), workbook->sheet(i)->maxRow()));
                 xmlWriter->startElement("table:database-range");
-                xmlWriter->addAttribute("table:name", QString("database-%1").arg(rangeId++));
+                xmlWriter->addAttribute("table:name", QString("excel-database-%1").arg(rangeId++));
                 xmlWriter->addAttribute("table:display-filter-buttons", "true");
                 xmlWriter->addAttribute("table:target-range-address", sRange);
                 xmlWriter->endElement(); // table:database-range
@@ -679,10 +631,10 @@ void ExcelImport::Private::processWorkbookForStyle(Workbook* workbook, KoXmlWrit
 
     QString contentElement;
     QString masterStyleName("Default");
-    QString pageLayoutStyleName ("Mpm");
+    QString pageLayoutStyleName("Mpm");
 
-    KoGenStyle *pageLayoutStyle = new KoGenStyle(KoGenStyle::PageLayoutStyle);
-    pageLayoutStyle->addProperty("style:writing-mode", "lr-tb");
+    KoGenStyle pageLayoutStyle(KoGenStyle::PageLayoutStyle);
+    pageLayoutStyle.addProperty("style:writing-mode", "lr-tb");
 
     QBuffer buf;
     buf.open(QIODevice::WriteOnly);
@@ -710,16 +662,15 @@ void ExcelImport::Private::processWorkbookForStyle(Workbook* workbook, KoXmlWrit
     buf.close();
     buf.setData("", 0);
 
-    pageLayoutStyle->addProperty("1header-footer-style", pageLyt, KoGenStyle::StyleChildElement);
-    pageLayoutStyleName = mainStyles->insert(*pageLayoutStyle, pageLayoutStyleName, KoGenStyles::DontAddNumberToName);
+    pageLayoutStyle.addProperty("1header-footer-style", pageLyt, KoGenStyle::StyleChildElement);
+    pageLayoutStyleName = mainStyles->insert(pageLayoutStyle, pageLayoutStyleName, KoGenStyles::DontAddNumberToName);
 
-    for(unsigned i = 0; i < workbook->sheetCount(); i++)
-    {
+    for (unsigned i = 0; i < workbook->sheetCount(); i++) {
         Sheet* sheet = workbook->sheet(i);
         processSheetForStyle(sheet, xmlWriter);
 
         buf.open(QIODevice::WriteOnly);
-        processSheetForHeaderFooter (workbook->sheet(0), &writer);
+        processSheetForHeaderFooter(workbook->sheet(0), &writer);
         contentElement = QString::fromUtf8(buf.buffer(), buf.buffer().size());
         buf.close();
         QString childElementName = QString::number(i).append("master-style");
@@ -728,7 +679,7 @@ void ExcelImport::Private::processWorkbookForStyle(Workbook* workbook, KoXmlWrit
         masterStyle.addAttribute("style:page-layout-name", pageLayoutStyleName);
 
         masterStyleName = mainStyles->insert(masterStyle, masterStyleName, KoGenStyles::DontAddNumberToName);
-        masterStyle.addAttribute( "style:name", masterStyleName);
+        masterStyle.addAttribute("style:name", masterStyleName);
     }
 }
 
@@ -740,7 +691,7 @@ void ExcelImport::Private::processSheetForBody(KoOdfWriteStore* store, Sheet* sh
 
     xmlWriter->startElement("table:table");
 
-    xmlWriter->addAttribute("table:name", string(sheet->name()));
+    xmlWriter->addAttribute("table:name", sheet->name());
     xmlWriter->addAttribute("table:print", "false");
     xmlWriter->addAttribute("table:style-name", sheetStyles[sheetFormatIndex]);
     ++sheetFormatIndex;
@@ -823,54 +774,54 @@ void ExcelImport::Private::processSheetForStyle(Sheet* sheet, KoXmlWriter* xmlWr
 }
 
 // Processes headers and footers for a sheet.
-void ExcelImport::Private::processSheetForHeaderFooter ( Sheet* sheet, KoXmlWriter* xmlWriter )
+void ExcelImport::Private::processSheetForHeaderFooter(Sheet* sheet, KoXmlWriter* xmlWriter)
 {
-    if ( !sheet ) return;
-    if ( !xmlWriter ) return;
+    if (!sheet) return;
+    if (!xmlWriter) return;
 
-    xmlWriter->startElement( "style:header" );
-    if ( !sheet->leftHeader().isEmpty() ) {
-        xmlWriter->startElement( "style:region-left" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->leftHeader(), xmlWriter);
+    xmlWriter->startElement("style:header");
+    if (!sheet->leftHeader().isEmpty()) {
+        xmlWriter->startElement("style:region-left");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->leftHeader(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
-    if ( !sheet->centerHeader().isEmpty() ) {
-        xmlWriter->startElement( "style:region-center" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->centerHeader(), xmlWriter);
+    if (!sheet->centerHeader().isEmpty()) {
+        xmlWriter->startElement("style:region-center");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->centerHeader(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
-    if ( !sheet->rightHeader().isEmpty() ) {
-        xmlWriter->startElement( "style:region-right" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->rightHeader(), xmlWriter);
+    if (!sheet->rightHeader().isEmpty()) {
+        xmlWriter->startElement("style:region-right");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->rightHeader(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
     xmlWriter->endElement();
 
-    xmlWriter->startElement( "style:footer" );
-    if ( !sheet->leftFooter().isEmpty() ) {
-        xmlWriter->startElement( "style:region-left" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->leftFooter(), xmlWriter);
+    xmlWriter->startElement("style:footer");
+    if (!sheet->leftFooter().isEmpty()) {
+        xmlWriter->startElement("style:region-left");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->leftFooter(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
-    if ( !sheet->centerFooter().isEmpty() ) {
-        xmlWriter->startElement( "style:region-center" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->centerFooter(), xmlWriter);
+    if (!sheet->centerFooter().isEmpty()) {
+        xmlWriter->startElement("style:region-center");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->centerFooter(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
-    if ( !sheet->rightFooter().isEmpty() ) {
-        xmlWriter->startElement( "style:region-right" );
-        xmlWriter->startElement( "text:p" );
-        processHeaderFooterStyle (sheet->rightFooter(), xmlWriter);
+    if (!sheet->rightFooter().isEmpty()) {
+        xmlWriter->startElement("style:region-right");
+        xmlWriter->startElement("text:p");
+        processHeaderFooterStyle(sheet->rightFooter(), xmlWriter);
         xmlWriter->endElement();
         xmlWriter->endElement();
     }
@@ -878,61 +829,61 @@ void ExcelImport::Private::processSheetForHeaderFooter ( Sheet* sheet, KoXmlWrit
 }
 
 // Processes the styles of a headers and footers for a sheet.
-void ExcelImport::Private::processHeaderFooterStyle (UString text, KoXmlWriter* xmlWriter)
+void ExcelImport::Private::processHeaderFooterStyle(const QString& text, KoXmlWriter* xmlWriter)
 {
     QString content;
     bool skipUnsupported = false;
     int lastPos;
-    int pos = text.find(UString('&'));
+    int pos = text.indexOf('&');
     int len = text.length();
-    if ( (pos < 0) && (text.length() > 0) ) // If ther is no &
-        xmlWriter->addTextNode(text.cstring().c_str());
+    if ((pos < 0) && (text.length() > 0))   // If ther is no &
+        xmlWriter->addTextNode(text);
     else if (pos > 0) // Some text and '&'
-        xmlWriter->addTextNode( text.substr( 0,  pos-1 ).cstring().c_str() );
+        xmlWriter->addTextNode(text.mid(0,  pos - 1));
 
     while (pos >= 0) {
-        switch (text[pos + 1].unicode() ) {
-            case 'D':
-                xmlWriter->startElement( "text:date");
-                xmlWriter->addTextNode( QDate::currentDate().toString("DD/MM/YYYY"));
-                xmlWriter->endElement();
-                break;
-            case 'T':
-                xmlWriter->startElement( "text:time");
-                xmlWriter->addTextNode( QTime::currentTime().toString("HH:MM:SS"));
-                xmlWriter->endElement();
-                break;
-            case 'P':
-                xmlWriter->startElement( "text:page-number");
-                xmlWriter->addTextNode( "1" );
-                xmlWriter->endElement();
-                break;
-            case 'N':
-                xmlWriter->startElement( "text:page-count");
-                xmlWriter->addTextNode( "999" );
-                xmlWriter->endElement();
-                break;
-            case 'F':
-                xmlWriter->startElement( "text:title");
-                xmlWriter->addTextNode( "???" );
-                xmlWriter->endElement();
-                break;
-            case 'A':
-                xmlWriter->startElement( "text:sheet-name");
-                xmlWriter->addTextNode( "???" );
-                xmlWriter->endElement();
-                break;
-            case '\"':
-            default:
-                skipUnsupported = true;
-                break;
+        switch (text[pos + 1].unicode()) {
+        case 'D':
+            xmlWriter->startElement("text:date");
+            xmlWriter->addTextNode(QDate::currentDate().toString("DD/MM/YYYY"));
+            xmlWriter->endElement();
+            break;
+        case 'T':
+            xmlWriter->startElement("text:time");
+            xmlWriter->addTextNode(QTime::currentTime().toString("HH:MM:SS"));
+            xmlWriter->endElement();
+            break;
+        case 'P':
+            xmlWriter->startElement("text:page-number");
+            xmlWriter->addTextNode("1");
+            xmlWriter->endElement();
+            break;
+        case 'N':
+            xmlWriter->startElement("text:page-count");
+            xmlWriter->addTextNode("999");
+            xmlWriter->endElement();
+            break;
+        case 'F':
+            xmlWriter->startElement("text:title");
+            xmlWriter->addTextNode("???");
+            xmlWriter->endElement();
+            break;
+        case 'A':
+            xmlWriter->startElement("text:sheet-name");
+            xmlWriter->addTextNode("???");
+            xmlWriter->endElement();
+            break;
+        case '\"':
+        default:
+            skipUnsupported = true;
+            break;
         }
         lastPos = pos;
-        pos = text.find(UString('&'), lastPos + 1);
-        if ( !skipUnsupported && (pos > (lastPos + 1)) )
-            xmlWriter->addTextNode( text.substr( lastPos+2, (pos - lastPos - 2) ).cstring().c_str() );
-        else if ( !skipUnsupported && (pos < 0) )//Remaining text
-            xmlWriter->addTextNode( text.substr( lastPos+2, len - (lastPos + 2)).cstring().c_str() );
+        pos = text.indexOf('&', lastPos + 1);
+        if (!skipUnsupported && (pos > (lastPos + 1)))
+            xmlWriter->addTextNode(text.mid(lastPos + 2, (pos - lastPos - 2)));
+        else if (!skipUnsupported && (pos < 0))  //Remaining text
+            xmlWriter->addTextNode(text.mid(lastPos + 2, len - (lastPos + 2)));
         else
             skipUnsupported = false;
     }
@@ -945,7 +896,7 @@ void ExcelImport::Private::processColumnForBody(Sheet* sheet, int columnIndex, K
 
     if (!xmlWriter) return;
 
-    int newOutlineLevel = column ? column->outlineLevel() : 0;
+    unsigned newOutlineLevel = column ? column->outlineLevel() : 0;
     while (newOutlineLevel > outlineLevel) {
         xmlWriter->startElement("table:table-column-group");
         outlineLevel++;
@@ -1006,7 +957,7 @@ int ExcelImport::Private::processRowForBody(KoOdfWriteStore* store, Sheet* sheet
     if (!xmlWriter) return repeat;
     Row *row = sheet->row(rowIndex, false);
 
-    int newOutlineLevel = row ? row->outlineLevel() : 0;
+    unsigned newOutlineLevel = row ? row->outlineLevel() : 0;
     while (newOutlineLevel > outlineLevel) {
         xmlWriter->startElement("table:table-row-group");
         outlineLevel++;
@@ -1127,21 +1078,21 @@ QString extractConditional(const QString &_text)
 {
     const QString text = removeEscaped(_text);
 #if 1
-    if ( text.startsWith('_') && text.length() >= 3 ) {
+    if (text.startsWith('_') && text.length() >= 3) {
         QChar end;
-        if(text[1] == '(') end = ')';
-        else if(text[1] == '_') end = '_';
-        else if(text[1] == ' ') end = ' ';
-        else kDebug() << "Probably unhandled condition=" << text[1] <<"in text=" << text;
-        if(! end.isNull()) {
+        if (text[1] == '(') end = ')';
+        else if (text[1] == '_') end = '_';
+        else if (text[1] == ' ') end = ' ';
+        else kDebug() << "Probably unhandled condition=" << text[1] << "in text=" << text;
+        if (! end.isNull()) {
             {
-                QString regex = QString( "^_%1(.*\"\\$\".*)%2;.*" ).arg(QString("\\%1").arg(text[1])).arg(QString("\\%1").arg(end));
+                QString regex = QString("^_%1(.*\"\\$\".*)%2;.*").arg(QString("\\%1").arg(text[1])).arg(QString("\\%1").arg(end));
                 QRegExp ex(regex);
                 ex.setMinimal(true);
                 if (ex.indexIn(text) >= 0) return ex.cap(1);
             }
             {
-                QString regex = QString( "^_%1(.*\\[\\$.*\\].*)%2;.*" ).arg(QString("\\%1").arg(text[1])).arg(QString("\\%1").arg(end));
+                QString regex = QString("^_%1(.*\\[\\$.*\\].*)%2;.*").arg(QString("\\%1").arg(text[1])).arg(QString("\\%1").arg(end));
                 QRegExp ex(regex);
                 ex.setMinimal(true);
                 if (ex.indexIn(text) >= 0) return ex.cap(1);
@@ -1149,7 +1100,7 @@ QString extractConditional(const QString &_text)
         }
     }
 #else
-    if ( text.startsWith('_') ) {
+    if (text.startsWith('_')) {
         return text.split(";").first();
     }
 #endif
@@ -1161,15 +1112,15 @@ QString extractConditional(const QString &_text)
 // [$EUR]\ #,##0.00"
 // [$₩-412]* #,##0.0000
 // * #,##0_)[$€-1]_
-static bool currencyFormat(const QString& valueFormat, QString *currencyVal = 0, QString *formatVal = 0)
+static bool currencyFormat(const QString& valueFormat, QString *currencyVal = 0, QString * formatVal = 0)
 {
     QString vf = extractConditional(valueFormat);
 
     // dollar is special cause it starts with a $
     QRegExp dollarRegEx("^\"\\$\"[*\\-\\s]*([#,]*[\\d]+(|.[#0]+)).*");
     if (dollarRegEx.indexIn(vf) >= 0) {
-        if(currencyVal) *currencyVal = "$";
-        if(formatVal) *formatVal = dollarRegEx.cap(1);
+        if (currencyVal) *currencyVal = "$";
+        if (formatVal) *formatVal = dollarRegEx.cap(1);
         return true;
     }
 
@@ -1177,10 +1128,10 @@ static bool currencyFormat(const QString& valueFormat, QString *currencyVal = 0,
     QRegExp crRegEx("\\[\\$(.*)\\]");
     crRegEx.setMinimal(true);
     if (crRegEx.indexIn(vf) >= 0) {
-        if(currencyVal) {
+        if (currencyVal) {
             *currencyVal = crRegEx.cap(1);
         }
-        if(formatVal) {
+        if (formatVal) {
             QRegExp vlRegEx("([#,]*[\\d]+(|.[#0]+))");
             *formatVal = vlRegEx.indexIn(vf) >= 0 ? vlRegEx.cap(1) : QString();
         }
@@ -1299,12 +1250,12 @@ static QString convertFraction(double serialNo, const QString& valueFormat)
 
 QString cellFormula(Cell* cell)
 {
-    QString formula = string(cell->formula());
-    if(!formula.isEmpty()) {
+    QString formula = cell->formula();
+    if (!formula.isEmpty()) {
         if(formula.startsWith("ROUNDUP(") || formula.startsWith("ROUNDDOWN(") || formula.startsWith("ROUND(") || formula.startsWith("RAND(")) {
             // Special case Excel formulas that differ from OpenFormula
             formula.prepend("msoxl:=");
-        } else if(!formula.isEmpty()) {
+        } else if (!formula.isEmpty()) {
             formula.prepend("=");
         }
     }
@@ -1313,11 +1264,11 @@ QString cellFormula(Cell* cell)
 
 QString currencyValue(const QString &value)
 {
-    if(value.isEmpty()) return QString();
-    if(value[0] == '$') return "USD";
-    if(value[0] == QChar(UNICODE_EUR)) return "EUR";
-    if(value[0] == QChar(UNICODE_GBP)) return "GBP";
-    if(value[0] == QChar(UNICODE_JPY)) return "JPY";
+    if (value.isEmpty()) return QString();
+    if (value[0] == '$') return "USD";
+    if (value[0] == QChar(UNICODE_EUR)) return "EUR";
+    if (value[0] == QChar(UNICODE_GBP)) return "GBP";
+    if (value[0] == QChar(UNICODE_JPY)) return "JPY";
     QRegExp symbolRegEx("^([^a-zA-Z0-9\\-_\\s]+)");
     if (symbolRegEx.indexIn(value) >= 0) return symbolRegEx.cap(1);
     return QString();
@@ -1355,7 +1306,7 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
         xmlWriter->addAttribute("office:value-type", "boolean");
         xmlWriter->addAttribute("office:boolean-value", value.asBoolean() ? "true" : "false");
     } else if (value.isFloat() || value.isInteger()) {
-        const QString valueFormat = string(cell->format().valueFormat());
+        const QString valueFormat = cell->format().valueFormat();
 
         if (isPercentageFormat(valueFormat)) {
             xmlWriter->addAttribute("office:value-type", "percentage");
@@ -1377,13 +1328,14 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
             xmlWriter->addAttribute("office:value", QString::number(value.asFloat(), 'g', 15));
         }
     } else if (value.isText() || value.isError()) {
-        QString str = string(value.asString());
+        QString str = value.asString();
         QString linkName, linkLocation;
 
-        if (cell->hasHyperlink()) {
-            linkLocation = string(cell->hyperlinkLocation());
+        Hyperlink link = cell->hyperlink();
+        if (link.isValid) {
+            linkLocation = link.location;
             if(!linkLocation.isEmpty()) {
-                linkName = string(cell->hyperlinkDisplayName()).trimmed();
+                linkName = link.displayName.trimmed();
                 if(linkName.isEmpty())
                     linkName = str;
                 str.clear(); // at Excel cells with links don't have additional text content
@@ -1445,7 +1397,7 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
         if (!linkName.isEmpty()) {
             xmlWriter->startElement("text:a");
             xmlWriter->addAttribute("xlink:href", linkLocation);
-            const QString targetFrameName = string(cell->hyperlinkTargetFrameName());
+            const QString targetFrameName = link.targetFrameName;
             if (! targetFrameName.isEmpty())
                 xmlWriter->addAttribute("office:target-frame-name", targetFrameName);
             xmlWriter->addTextNode(linkName);
@@ -1455,15 +1407,14 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
         xmlWriter->endElement(); //  text:p
     }
 
-    const UString note = cell->note();
+    const QString note = cell->note();
     if (! note.isEmpty()) {
-        const QString n = string(note);
         xmlWriter->startElement("office:annotation");
         //xmlWriter->startElement("dc:creator");
         //xmlWriter->addTextNode(authorName); //TODO
         //xmlWriter->endElement(); // dc:creator
         xmlWriter->startElement("text:p");
-        xmlWriter->addTextNode(n);
+        xmlWriter->addTextNode(note);
         xmlWriter->endElement(); // text:p
         xmlWriter->endElement(); // office:annotation
     }
@@ -1482,17 +1433,15 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
 
         xmlWriter->startElement("draw:frame");
         //xmlWriter->addAttribute("draw:name", "Graphics 1");
-        xmlWriter->addAttribute("table:end-cell", string(sheet->name()) + "." + columnName(picture->m_colR) + QString::number(picture->m_rwB));
-        xmlWriter->addAttribute("table:end-x", QString::number(dxR));
-        xmlWriter->addAttribute("table:end-y", QString::number(dyB));
+        xmlWriter->addAttribute("table:end-cell-address", encodeAddress(sheet->name(), picture->m_colR, picture->m_rwB));
+        xmlWriter->addAttributePt("table:end-x", offset(columnWidth(sheet, colR), dxR));
+        xmlWriter->addAttributePt("table:end-y", offset(rowHeight(sheet, rwB), dyB));
         xmlWriter->addAttribute("draw:z-index", "0");
-        xmlWriter->addAttributePt("svg:x", columnStart(sheet, colL) + offset(columnWidth(sheet, colL), dxL) );
-        xmlWriter->addAttributePt("svg:y", rowStart(sheet, rwT) + offset(rowHeight(sheet, rwT), dyT));
-        xmlWriter->addAttributePt("svg:width", columnDistance(sheet, colL, colR) + widthOffset(sheet, colL, dxL, colR, dxR) );
-        xmlWriter->addAttributePt("svg:height", rowDistance(sheet, rwT, rwB) + heightOffset(sheet, rwT, dyT, rwB, dyB) );
+        xmlWriter->addAttributePt("svg:x", offset(columnWidth(sheet, colL), dxL) );
+        xmlWriter->addAttributePt("svg:y", offset(rowHeight(sheet, rwT), dyT));
 
         xmlWriter->startElement("draw:image");
-        xmlWriter->addAttribute("xlink:href", picture->m_filename.c_str());
+        xmlWriter->addAttribute("xlink:href", "Pictures/" + picture->m_filename);
         xmlWriter->addAttribute("xlink:type", "simple");
         xmlWriter->addAttribute("xlink:show", "embed");
         xmlWriter->addAttribute("xlink:actuate", "onLoad");
@@ -1514,7 +1463,7 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
 
         ChartExport *c = new ChartExport(chart->m_chart);
         c->m_href = QString("Chart%1").arg(this->charts.count()+1);
-        c->m_endCellAddress = string(sheet->name()) + "." + columnName(drawobj->m_colR) + QString::number(drawobj->m_rwB);
+        c->m_endCellAddress = encodeAddress(sheet->name(), drawobj->m_colR, drawobj->m_rwB);
         c->m_notifyOnUpdateOfRanges = "Sheet1.D2:Sheet1.F2";
 
         const unsigned long colL = drawobj->m_colL;
@@ -1526,14 +1475,12 @@ void ExcelImport::Private::processCellForBody(KoOdfWriteStore* store, Cell* cell
         const unsigned long rwT = drawobj->m_rwT;
         const unsigned long dyB = drawobj->m_dyB;
 
-        c->m_x = columnStart(sheet, colL) + offset(columnWidth(sheet, colL), dxL);
-        c->m_y = rowStart(sheet, rwT) + offset(rowHeight(sheet, rwT), dyT);
-        c->m_width = columnDistance(sheet, colL, colR) + widthOffset(sheet, colL, dxL, colR, dxR);
-        c->m_height = rowDistance(sheet, rwT, rwB) + heightOffset(sheet, rwT, dyT, rwB, dyB);
+        c->m_x = offset(columnWidth(sheet, colL), dxL);
+        c->m_y = offset(rowHeight(sheet, rwT), dyT);
 
         if (!chart->m_chart->m_cellRangeAddress.isNull() )
-            c->m_cellRangeAddress = string(sheet->name()) + "." + columnName(chart->m_chart->m_cellRangeAddress.left()) + QString::number(chart->m_chart->m_cellRangeAddress.top()) + ":" +
-                                    string(sheet->name()) + "." + columnName(chart->m_chart->m_cellRangeAddress.right()) + QString::number(chart->m_chart->m_cellRangeAddress.bottom());
+            c->m_cellRangeAddress = encodeAddress(sheet->name(), chart->m_chart->m_cellRangeAddress.left(), chart->m_chart->m_cellRangeAddress.top()) + ":" +
+                                    encodeAddress(sheet->name(), chart->m_chart->m_cellRangeAddress.right(), chart->m_chart->m_cellRangeAddress.bottom());
 
         this->charts << c;
 
@@ -1589,7 +1536,7 @@ QString ExcelImport::Private::processCellFormat(Format* format, const QString& f
 {
     // handle data format, e.g. number style
     QString refName;
-    QString valueFormat = string(format->valueFormat());
+    QString valueFormat = format->valueFormat();
     if (valueFormat != QString("General")) {
         refName = processValueFormat(valueFormat);
     } else {
@@ -1598,7 +1545,7 @@ QString ExcelImport::Private::processCellFormat(Format* format, const QString& f
             if (roundRegExp.indexIn(formula) >= 0) {
                 bool ok = false;
                 int decimals = roundRegExp.cap(1).trimmed().toInt(&ok);
-                if(ok) {
+                if (ok) {
                     KoGenStyle style(KoGenStyle::NumericNumberStyle);
                     QBuffer buffer;
                     buffer.open(QIODevice::WriteOnly);
@@ -1639,7 +1586,7 @@ QString ExcelImport::Private::processCellFormat(Format* format, const QString& f
 QString ExcelImport::Private::processRowFormat(Format* format, const QString& breakBefore, int rowRepeat, double rowHeight)
 {
     QString refName;
-    QString valueFormat = string(format->valueFormat());
+    QString valueFormat = format->valueFormat();
     if (valueFormat != QString("General"))
         refName = processValueFormat(valueFormat);
 
@@ -1940,7 +1887,7 @@ void ExcelImport::Private::processSheetBackground(Sheet* sheet, KoGenStyle& styl
 
     //TODO add the manifest entry
     writer.startElement("style:background-image");
-    writer.addAttribute("xlink:href", sheet->backgroundImage().ascii());
+    writer.addAttribute("xlink:href", sheet->backgroundImage());
     writer.addAttribute("xlink:type", "simple");
     writer.addAttribute("xlink:show", "embed");
     writer.addAttribute("xlink:actuate", "onLoad");
@@ -1948,7 +1895,7 @@ void ExcelImport::Private::processSheetBackground(Sheet* sheet, KoGenStyle& styl
 
     buffer.close();
     style.addChildElement("style:background-image", QString::fromUtf8(buffer.buffer(), buffer.buffer().size()));
-    manifestEntries.insert(QString::fromAscii(sheet->backgroundImage().ascii()), "image/bmp");
+    manifestEntries.insert(sheet->backgroundImage(), "image/bmp");
 }
 
 void ExcelImport::Private::addManifestEntries(KoXmlWriter* manifestWriter)
@@ -1964,7 +1911,7 @@ void ExcelImport::Private::addManifestEntries(KoXmlWriter* manifestWriter)
 void ExcelImport::Private::insertPictureManifest(Picture* picture)
 {
     QString mimeType;
-    const QString fileName = QString::fromAscii(picture->m_filename.c_str());
+    const QString fileName = picture->m_filename;
     const QString extension = fileName.right(fileName.size() - fileName.lastIndexOf('.') - 1);
 
     if( extension == "gif" ) {
