@@ -19,7 +19,6 @@
 
 #include "cell.h"
 #include "excel.h"
-#include "ustring.h"
 #include "format.h"
 #include "value.h"
 #include "objects.h"
@@ -36,19 +35,13 @@ public:
     unsigned row;
     unsigned column;
     Value value;
-    UString formula;
-    Format format;
+    QString formula;
+    const Format* format;
     unsigned columnSpan;
     unsigned rowSpan;
     bool covered;
     int columnRepeat;
-    bool hasHyperlink;
-    UString hyperlinkDisplayName;
-    UString hyperlinkLocation;
-    UString hyperlinkTargetFrameName;
-    UString note;
-    std::vector<Picture*> pictures;
-    std::vector<ChartObject*> charts;
+    QString note;
 };
 
 }
@@ -66,13 +59,11 @@ Cell::Cell(Sheet* sheet, unsigned column, unsigned row)
     d->rowSpan    = 1;
     d->covered    = false;
     d->columnRepeat = 1;
-    d->hasHyperlink = false;
+    d->format     = 0;
 }
 
 Cell::~Cell()
 {
-    qDeleteAll(d->pictures);
-    qDeleteAll(d->charts);
     delete d;
 }
 
@@ -91,25 +82,25 @@ unsigned Cell::row() const
     return d->row;
 }
 
-UString Cell::name() const
+QString Cell::name() const
 {
     return name(column(), row());
 }
 
-UString Cell::name(unsigned column, unsigned row)
+QString Cell::name(unsigned column, unsigned row)
 {
-    return columnLabel(column) + UString::from(row);
+    return columnLabel(column) + QString::number(row);
 }
 
-UString Cell::columnLabel() const
+QString Cell::columnLabel() const
 {
     return columnLabel(column());
 }
 
 // FIXME be careful for integer overflow
-UString Cell::columnLabel(unsigned column)
+QString Cell::columnLabel(unsigned column)
 {
-    UString str;
+    QString str;
     unsigned digits = 1;
     unsigned offset = 0;
 
@@ -117,7 +108,7 @@ UString Cell::columnLabel(unsigned column)
         offset += limit;
 
     for (unsigned c = column - offset; digits; --digits, c /= 26)
-        str = UString(UChar('A' + (c % 26))) + str;
+        str = QString(QChar('A' + (c % 26))) + str;
 
     return str;
 }
@@ -132,22 +123,24 @@ void Cell::setValue(const Value& value)
     d->value = value;
 }
 
-UString Cell::formula() const
+QString Cell::formula() const
 {
     return d->formula;
 }
 
-void Cell::setFormula(const UString& formula)
+void Cell::setFormula(const QString& formula)
 {
     d->formula = formula;
 }
 
-Format Cell::format() const
+const Format& Cell::format() const
 {
-    return d->format;
+    static const Format null;
+    if (!d->format) return null;
+    return *(d->format);
 }
 
-void Cell::setFormat(const Format& format)
+void Cell::setFormat(const Format* format)
 {
     d->format = format;
 }
@@ -167,7 +160,7 @@ void Cell::setColumnSpan(unsigned span)
         if (lastCell) {
             Format curFormat = format();
             curFormat.borders().setRightBorder(lastCell->format().borders().rightBorder());
-            setFormat(curFormat);
+            setFormat(sheet()->workbook()->format(sheet()->workbook()->addFormat(curFormat)));
         }
     }
 }
@@ -187,7 +180,7 @@ void Cell::setRowSpan(unsigned span)
         if (lastCell) {
             Format curFormat = format();
             curFormat.borders().setBottomBorder(lastCell->format().borders().bottomBorder());
-            setFormat(curFormat);
+            setFormat(sheet()->workbook()->format(sheet()->workbook()->addFormat(curFormat)));
         }
     }
 }
@@ -214,73 +207,52 @@ void Cell::setColumnRepeat(int repeat)
 
 bool Cell::hasHyperlink() const
 {
-    return d->hasHyperlink;
+    return d->sheet->hyperlink(d->column, d->row).isValid;
 }
 
-UString Cell::hyperlinkDisplayName() const
+Hyperlink Cell::hyperlink() const
 {
-    return d->hyperlinkDisplayName;
+    return d->sheet->hyperlink(d->column, d->row);
 }
 
-UString Cell::hyperlinkLocation() const
+void Cell::setHyperlink(const Hyperlink& link)
 {
-    return d->hyperlinkLocation;
+    d->sheet->setHyperlink(d->column, d->row, link);
 }
 
-UString Cell::hyperlinkTargetFrameName() const
-{
-    return d->hyperlinkTargetFrameName;
-}
-
-void Cell::removeHyperlink()
-{
-    d->hyperlinkDisplayName = UString();
-    d->hyperlinkLocation = UString();
-    d->hyperlinkTargetFrameName = UString();
-    d->hasHyperlink = false;
-}
-
-void Cell::setHyperlink(const UString& displayName, const UString& location, const UString& targetFrameName)
-{
-    d->hyperlinkDisplayName = displayName;
-    d->hyperlinkLocation = location;
-    d->hyperlinkTargetFrameName = targetFrameName;
-    d->hasHyperlink = true;
-}
-
-UString Cell::note() const
+QString Cell::note() const
 {
     return d->note;
 }
 
-void Cell::setNote(const UString &n)
+void Cell::setNote(const QString &n)
 {
     d->note = n;
 }
 
-std::vector<Picture*> Cell::pictures() const
+QList<Picture*> Cell::pictures() const
 {
-    return d->pictures;
+    return d->sheet->pictures(d->column, d->row);
 }
 
-void Cell::setPictures(std::vector<Picture*> pics)
+void Cell::setPictures(const QList<Picture*>& pics)
 {
-    d->pictures = pics;
+    d->sheet->setPictures(d->column, d->row, pics);
 }
 
 void Cell::addPicture(Picture* picture)
 {
-    d->pictures.push_back(picture);
+    d->sheet->addPicture(d->column, d->row, picture);
 }
 
-std::vector<ChartObject*> Cell::charts() const
+QList<ChartObject*> Cell::charts() const
 {
-    return d->charts;
+    return d->sheet->charts(d->column, d->row);
 }
 
 void Cell::addChart(ChartObject* chart)
 {
-    d->charts.push_back(chart);
+    d->sheet->addChart(d->column, d->row, chart);
 }
 
 bool Cell::operator==(const Cell &other) const
@@ -294,9 +266,7 @@ bool Cell::operator==(const Cell &other) const
     if (columnRepeat() != other.columnRepeat()) return false;
 
     if (hasHyperlink() != other.hasHyperlink()) return false;
-    if (hasHyperlink() && ( hyperlinkDisplayName() != other.hyperlinkDisplayName() ||
-                            hyperlinkLocation() != other.hyperlinkLocation() ||
-                            hyperlinkTargetFrameName() != other.hyperlinkTargetFrameName() ) ) return false;
+    if (hasHyperlink() && hyperlink() != other.hyperlink()) return false;
 
     if (note() != other.note()) return false;
 
