@@ -43,13 +43,13 @@ public:
     std::map<unsigned, Sheet*> bofMap;
 
     // for EXTERNBOOK and EXTERNSHEET
-    std::vector<UString> externBookTable;
-    std::vector<UString> externSheetTable;
+    std::vector<QString> externBookTable;
+    std::vector<QString> externSheetTable;
 
     // for NAME
-    std::vector<UString> nameTable;
+    std::vector<QString> nameTable;
     // for EXTERNNAME
-    std::vector<UString> externNameTable;
+    std::vector<QString> externNameTable;
 
     // password protection flag
     // TODO: password hash for record decryption
@@ -63,10 +63,13 @@ public:
     std::map<unsigned, FormatFont> fontCache;
 
     // table of format
-    std::map<unsigned, UString> formatsTable;
+    std::map<unsigned, QString> formatsTable;
+    
+    // cache of formats
+    std::map<unsigned, int> formatCache;
 
     // shared-string table
-    std::vector<UString> stringTable;
+    std::vector<QString> stringTable;
     std::vector<std::map<unsigned, FormatFont> > formatRunsTable;
 
     // color table (from Palette record)
@@ -76,7 +79,7 @@ public:
     std::vector<XFRecord> xfTable;
 
     // table blib items
-    std::vector< MsoDrawingBlibItem* > drawingTable;
+    QList< MsoDrawingBlibItem* > drawingTable;
 
     // list of chart sheets
     QList< Sheet* > chartSheets;
@@ -166,12 +169,12 @@ Sheet* GlobalsSubStreamHandler::sheetFromPosition(unsigned position) const
         return 0;
 }
 
-UString GlobalsSubStreamHandler::stringFromSST(unsigned index) const
+QString GlobalsSubStreamHandler::stringFromSST(unsigned index) const
 {
     if (index < d->stringTable.size())
         return d->stringTable[index];
     else
-        return UString();
+        return QString();
 }
 
 std::map<unsigned, FormatFont> GlobalsSubStreamHandler::formatRunsFromSST(unsigned index) const
@@ -216,34 +219,34 @@ XFRecord GlobalsSubStreamHandler::xformat(unsigned index) const
         return XFRecord(d->workbook);
 }
 
-UString GlobalsSubStreamHandler::valueFormat(unsigned index) const
+QString GlobalsSubStreamHandler::valueFormat(unsigned index) const
 {
-    std::map<unsigned, UString>::iterator it = d->formatsTable.find(index);
+    std::map<unsigned, QString>::iterator it = d->formatsTable.find(index);
     if (it != d->formatsTable.end())
         return it->second;
     else
-        return UString();
+        return QString();
 }
 
-const std::vector<UString>& GlobalsSubStreamHandler::externSheets() const
+const std::vector<QString>& GlobalsSubStreamHandler::externSheets() const
 {
     return d->externSheetTable;
 }
 
-UString GlobalsSubStreamHandler::nameFromIndex(unsigned index) const
+QString GlobalsSubStreamHandler::nameFromIndex(unsigned index) const
 {
     if (index < d->nameTable.size())
         return d->nameTable[index];
     std::cerr << "Invalid index in GlobalsSubStreamHandler::nameFromIndex index=" << index << " size=" << d->externNameTable.size() << std::endl;
-    return UString();
+    return QString();
 }
 
-UString GlobalsSubStreamHandler::externNameFromIndex(unsigned index) const
+QString GlobalsSubStreamHandler::externNameFromIndex(unsigned index) const
 {
     if (index < d->externNameTable.size())
         return d->externNameTable[index];
     std::cerr << "Invalid index in GlobalsSubStreamHandler::externNameFromIndex index=" << index << " size=" << d->externNameTable.size() << std::endl;
-    return UString();
+    return QString();
 }
 
 FormatFont GlobalsSubStreamHandler::convertedFont(unsigned index) const
@@ -272,7 +275,7 @@ FormatFont GlobalsSubStreamHandler::convertedFont(unsigned index) const
 Color GlobalsSubStreamHandler::convertedColor(unsigned index) const
 {
     if ((index >= 8) && (index < 0x40))
-        return customColor(index -8);
+        return customColor(index - 8);
 
     // FIXME the following colors depend on system color settings
     // 0x0040  system window text color for border lines
@@ -402,15 +405,18 @@ static unsigned convertPatternStyle(unsigned pattern)
 }
 
 // big task: convert Excel XFormat into Swinder::Format
-Format GlobalsSubStreamHandler::convertedFormat(unsigned index) const
+const Format* GlobalsSubStreamHandler::convertedFormat(unsigned index) const
 {
-    Format format;
+    static const Format blankFormat;
+    if (index >= xformatCount()) return &blankFormat;
 
-    if (index >= xformatCount()) return format;
+    int& formatIt = d->formatCache[index];
+    if (formatIt) return workbook()->format(formatIt-1);
+    Format format;
 
     XFRecord xf = xformat(index);
 
-    UString valueFormat = this->valueFormat(xf.formatIndex());
+    QString valueFormat = this->valueFormat(xf.formatIndex());
     if (valueFormat.isEmpty()) {
         const unsigned ifmt = xf.formatIndex();
         switch (ifmt) {
@@ -502,7 +508,7 @@ Format GlobalsSubStreamHandler::convertedFormat(unsigned index) const
     alignment.setWrap(xf.textWrap());
 
     unsigned angle = xf.rotationAngle();
-    if (angle > 90) angle = 360-(angle-90);
+    if (angle > 90) angle = 360 - (angle - 90);
     alignment.setRotationAngle(angle);
 
     alignment.setStackedLetters(xf.stackedLetters());
@@ -549,7 +555,8 @@ Format GlobalsSubStreamHandler::convertedFormat(unsigned index) const
     background.setPattern(convertPatternStyle(xf.fillPattern()));
     format.setBackground(background);
 
-    return format;
+    formatIt = workbook()->addFormat(format) + 1;
+    return workbook()->format(formatIt-1);
 }
 
 void GlobalsSubStreamHandler::handleRecord(Record* record)
@@ -669,15 +676,15 @@ void GlobalsSubStreamHandler::handleExternSheet(ExternSheetRecord* record)
     for (unsigned i = 0; i < record->refCount(); i++) {
         unsigned bookRef = record->bookRef(i);
 
-        UString result;
+        QString result;
         if (bookRef >= d->externBookTable.size()) {
-            result = UString("Error");
+            result = QString("Error");
         } else {
-            UString book = d->externBookTable[bookRef];
+            QString book = d->externBookTable[bookRef];
             if (book == "\004") {
                 unsigned sheetRef = record->firstSheetRef(i);
                 if (sheetRef >= d->workbook->sheetCount()) {
-                    result = UString("Error");
+                    result = QString("Error");
                 } else {
                     result = d->workbook->sheet(sheetRef)->name();
                 }
@@ -686,16 +693,16 @@ void GlobalsSubStreamHandler::handleExternSheet(ExternSheetRecord* record)
             }
         }
 
-        if (result.find(UString(" ")) != -1 || result.find(UString("'")) != -1) {
+        if (result.indexOf(' ') != -1 || result.indexOf('\'') != -1) {
             // escape string
-            UString outp("'");
+            QString outp("'");
             for (int idx = 0; idx < result.length(); idx++) {
                 if (result[idx] == '\'')
-                    outp.append(UString("''"));
+                    outp.append(QString("''"));
                 else
-                    outp.append(UString(result[idx]));
+                    outp.append(QString(result[idx]));
             }
-            result = outp + UString("'");
+            result = outp + QString("'");
         }
 
         d->externSheetTable[i] = result;
@@ -755,9 +762,9 @@ void GlobalsSubStreamHandler::handleName(NameRecord* record)
         } else {
             FormulaTokens tokens;
             tokens.push_back(record->m_formula);
-            UString f = decodeFormula(0, 0, false, tokens);
+            QString f = decodeFormula(0, 0, false, tokens);
             if(!f.isEmpty()) {
-                UString n = record->definedName();
+                QString n = record->definedName();
                 d->workbook->setNamedArea(record->sheetIndex(), n, f);
             }
         }
@@ -779,8 +786,8 @@ void GlobalsSubStreamHandler::handleSST(SSTRecord* record)
 
     d->stringTable.clear();
     d->formatRunsTable.clear();
-    for (unsigned i = 0; i < record->count();i++) {
-        UString str = record->stringAt(i);
+    for (unsigned i = 0; i < record->count(); i++) {
+        QString str = record->stringAt(i);
         d->stringTable.push_back(str);
         std::map<unsigned, unsigned> formatRunsRaw = record->formatRunsAt(i);
         std::map<unsigned, FormatFont> formatRuns;
@@ -800,11 +807,11 @@ void GlobalsSubStreamHandler::handleXF(XFRecord* record)
 
 void GlobalsSubStreamHandler::handleProtect(ProtectRecord* record)
 {
-  if (!record) return;
+    if (!record) return;
 
-  if (record->isLocked()) {
-      std::cout << "TODO: The workbook is protected but protected workbooks is not supported yet!" << std::endl;
-  }
+    if (record->isLocked()) {
+        std::cout << "TODO: The workbook is protected but protected workbooks is not supported yet!" << std::endl;
+    }
 }
 
 void GlobalsSubStreamHandler::handleWindow1(Window1Record* record)
@@ -830,7 +837,7 @@ void GlobalsSubStreamHandler::handleMsoDrawingGroup(MsoDrawingGroupRecord* recor
 
 MsoDrawingBlibItem* GlobalsSubStreamHandler::drawing(unsigned long pid) const
 {
-    if (pid <= 0 || pid > d->drawingTable.size()) {
+    if (pid < 1 || pid > uint(d->drawingTable.size())) {
         std::cerr << "GlobalsSubStreamHandler::drawing: Invalid index=" << (pid - 1) << std::endl;
         return 0;
     }
@@ -842,7 +849,7 @@ QList< Sheet* >& GlobalsSubStreamHandler::chartSheets()
     return d->chartSheets;
 }
 
-Store* GlobalsSubStreamHandler::store() const
+KoStore* GlobalsSubStreamHandler::store() const
 {
     return d->workbook->store();
 }
