@@ -20,9 +20,10 @@
 #ifndef SWINDER_SHEET_H
 #define SWINDER_SHEET_H
 
-#include "ustring.h"
 #include "format.h"
-#include <QImage>
+#include "cell.h"
+#include <QtCore/QString>
+#include <QtGui/QImage>
 
 class QPoint;
 
@@ -51,9 +52,9 @@ public:
      */
     void clear();
 
-    void setName(const UString& name);
+    void setName(const QString& name);
 
-    UString name() const;
+    QString name() const;
 
     // return cell at specified column and row
     // automatically create the cell if previously there is no cell there
@@ -102,19 +103,19 @@ public:
 
      */
 
-    UString leftHeader() const;
-    void setLeftHeader(const UString& h);
-    UString centerHeader() const;
-    void setCenterHeader(const UString& h);
-    UString rightHeader() const;
-    void setRightHeader(const UString& h);
+    QString leftHeader() const;
+    void setLeftHeader(const QString& h);
+    QString centerHeader() const;
+    void setCenterHeader(const QString& h);
+    QString rightHeader() const;
+    void setRightHeader(const QString& h);
 
-    UString leftFooter() const;
-    void setLeftFooter(const UString& f);
-    UString centerFooter() const;
-    void setCenterFooter(const UString& f);
-    UString rightFooter() const;
-    void setRightFooter(const UString& f);
+    QString leftFooter() const;
+    void setLeftFooter(const QString& f);
+    QString centerFooter() const;
+    void setCenterFooter(const QString& f);
+    QString rightFooter() const;
+    void setRightFooter(const QString& f);
 
     // left margin, in points (pt)
     double leftMargin() const;
@@ -165,8 +166,8 @@ public:
     unsigned long password() const;
     void setPassword(unsigned long hash);
 
-    UString backgroundImage();
-    void setBackgroundImage(const Swinder::UString& imagePath);
+    QString backgroundImage();
+    void setBackgroundImage(const QString& imagePath);
 
     void addVerticalPageBreak(const VerticalPageBreak& pageBreak);
     QList<VerticalPageBreak> verticalPageBreaks();
@@ -174,6 +175,9 @@ public:
     void addHorizontalPageBreak(const HorizontalPageBreak& pageBreak);
     QList<HorizontalPageBreak> horizontalPageBreaks();
 
+#ifdef SWINDER_XLS2RAW
+    void dumpStats();
+#endif
 private:
     // no copy or assign
     Sheet(const Sheet&);
@@ -181,6 +185,17 @@ private:
 
     class Private;
     Private *d;
+
+    friend class Cell;
+
+    Hyperlink hyperlink(unsigned column, unsigned row) const;
+    void setHyperlink(unsigned column, unsigned row, const Hyperlink& link);
+    QList<Picture*> pictures(unsigned column, unsigned row) const;
+    void setPictures(unsigned column, unsigned row, const QList<Picture*>& pictures);
+    void addPicture(unsigned column, unsigned row, Picture* picture);
+    QList<ChartObject*> charts(unsigned column, unsigned row) const;
+    void setCharts(unsigned column, unsigned row, const QList<ChartObject*>& charts);
+    void addChart(unsigned column, unsigned row, ChartObject* chart);
 };
 
 struct VerticalPageBreak {
@@ -213,7 +228,7 @@ public:
     void setWidth(double w);
 
     const Format& format() const;
-    void setFormat(const Format& f);
+    void setFormat(const Format* f);
 
     bool visible() const;
     void setVisible(bool v);
@@ -251,7 +266,7 @@ public:
     void setHeight(double w);
 
     const Format& format() const;
-    void setFormat(const Format& f);
+    void setFormat(const Format* f);
 
     bool visible() const;
     void setVisible(bool v);
