@@ -54,7 +54,7 @@
 Document::Document(const std::string& fileName, KoFilterChain* chain, KoXmlWriter* bodyWriter,
                    KoGenStyles* mainStyles, KoXmlWriter* metaWriter, KoXmlWriter* manifestWriter,
                    KoStore* store, POLE::Storage* storage,
-		   LEInputStream* data, LEInputStream* table, LEInputStream* wdocument)
+                   LEInputStream* data, LEInputStream* table, LEInputStream* wdocument)
         : m_textHandler(0)
         , m_tableHandler(0)
         , m_replacementHandler(new KWordReplacementHandler)
@@ -71,10 +71,11 @@ Document::Document(const std::string& fileName, KoFilterChain* chain, KoXmlWrite
         , m_headerCount(0)
         , m_writingHeader(false)
         , m_evenOpen(false)
-	, m_firstOpen(false)
+        , m_firstOpen(false)
         , m_buffer(0)
         , m_bufferEven(0)
         , m_writeMasterPageName(false)
+        , m_omittMasterPage(false)
         , m_data_stream(data)
         , m_table_stream(table)
         , m_wdocument_stream(wdocument)
@@ -95,7 +96,7 @@ Document::Document(const std::string& fileName, KoFilterChain* chain, KoXmlWrite
         m_textHandler->setDocument(this);
         m_tableHandler = new KWordTableHandler(bodyWriter, mainStyles);
         m_tableHandler->setDocument(this);
-        m_graphicsHandler = new KWordGraphicsHandler(this, bodyWriter, manifestWriter, store, mainStyles, m_picNames);
+        m_graphicsHandler = new KWordGraphicsHandler(this, bodyWriter, manifestWriter, store, mainStyles);
 
         connect(m_textHandler, SIGNAL(subDocFound(const wvWare::FunctorBase*, int)),
                 this, SLOT(slotSubDocFound(const wvWare::FunctorBase*, int)));
@@ -296,20 +297,19 @@ void Document::processStyles()
 
         // Process paragraph styles.
         if (style && style->type() == wvWare::Style::sgcPara) {
-            const wvWare::Style* followingStyle = styles.styleByID(style->followingStyle());
-            if (followingStyle && followingStyle != style) {
-                QString followingName = Conversion::string(followingStyle->name());
-            }
-
             //create this style & add formatting info to it
             kDebug(30513) << "creating ODT paragraphstyle" << name;
             KoGenStyle userStyle(KoGenStyle::ParagraphStyle, "paragraph");
             userStyle.addAttribute("style:display-name", displayName);
 
+            const wvWare::Style* followingStyle = styles.styleByID(style->followingStyle());
+            if (followingStyle && followingStyle != style) {
+                QString followingName = Conversion::string(followingStyle->name());
+            }
+
             const wvWare::Style* parentStyle = styles.styleByIndex(style->m_std->istdBase);
             if (parentStyle) {
-                userStyle.addAttribute("style:parent-style-name",
-                                       Conversion::styleNameString(parentStyle->name()));
+                userStyle.setParentName(Conversion::styleNameString(parentStyle->name()));
             }
 
             //set font name in style
@@ -336,19 +336,29 @@ void Document::processStyles()
 
             const wvWare::Style* parentStyle = styles.styleByIndex(style->m_std->istdBase);
             if (parentStyle) {
-                userStyle.addAttribute("style:parent-style-name",
-                                       Conversion::styleNameString(parentStyle->name()));
+                userStyle.setParentName(Conversion::styleNameString(parentStyle->name()));
             }
 
-            // even if we were able to process character properties in the chpx
-            // lists then we don't need to the design is such that the styles
-            // are modified during processing of text runs
+            //set font name in style
+            QString fontName = m_textHandler->getFont(style->chp().ftcAscii);
+            if (!fontName.isEmpty()) {
+                m_mainStyles->insertFontFace(KoFontFace(fontName));
+                userStyle.addProperty(QString("style:font-name"), fontName, KoGenStyle::TextType);
+            }
+
+            // Process the character and paragraph properties.
+            Paragraph::applyCharacterProperties(&style->chp(), &userStyle, parentStyle);
 
             //add style to main collection, using the name that it had in the .doc
             QString actualName = m_mainStyles->insert(userStyle, name, KoGenStyles::DontAddNumberToName);
             kDebug(30513) << "added style " << actualName;
         }
     }
+    //also create a defaul style which is needed to store the default tab spacing
+    KoGenStyle defaultStyle(KoGenStyle::ParagraphStyle, "paragraph");
+    defaultStyle.setDefaultStyle(true);
+    defaultStyle.addPropertyPt("style:tab-stop-distance", (qreal)m_parser->dop().dxaTab / 20.0);
+    m_mainStyles->insert(defaultStyle, "nevershown");
 }
 
 //just call parsing function
@@ -384,107 +394,118 @@ void Document::bodyEnd()
                this, SLOT(slotSectionFound(wvWare::SharedPtr<const wvWare::Word97::SEP>)));
 }
 
-//sets paper size
-//sets format & orientation
-//sets column information
-//sets up borders
+//create page-layout and master-page
 void Document::slotSectionFound(wvWare::SharedPtr<const wvWare::Word97::SEP> sep)
 {
     kDebug(30513) ;
-    // does this section require a specific first page
+    m_omittMasterPage = false;
+    static KoGenStyle prevStyle(KoGenStyle::PageLayoutStyle);
+
+    //does this section require a specific first page
     bool firstPage = sep->fTitlePage || sep->pgbApplyTo;
 
     // *******************************
     // page-layout style
     // *******************************
     kDebug(30513) << "preparing page-layout styles";
-
     KoGenStyle* pageLayoutStyle = new KoGenStyle(KoGenStyle::PageLayoutStyle);
-    QString pageLayoutStyleName("Mpm");
-    if (m_textHandler->m_sectionNumber > 1) {
-        pageLayoutStyleName.append(QString::number(m_textHandler->m_sectionNumber));
-    }
 
-    // set page-layout attributes
+    //set page-layout attributes
     setPageLayoutStyle(pageLayoutStyle, sep, 0);
     pageLayoutStyle->setAutoStyleInStylesDotXml(true);
-    pageLayoutStyleName = m_mainStyles->insert(*pageLayoutStyle, pageLayoutStyleName,
-                                               KoGenStyles::DontAddNumberToName);
-    // add the name into the list
-    m_pageLayoutName_list.prepend(pageLayoutStyleName);
 
-    // delete the object, we've added it to the collection
-    delete pageLayoutStyle;
-    pageLayoutStyle = 0;
+    //NOTE: Each section may require a new page-layout.  If this is not the
+    //case and the header/footer content didn't change, the <style:master-page>
+    //element can be omitted.  Except of continuous section break a manual page
+    //break has to be inserted.
 
-    // check if a first-page specific page-layout has to be created
+    //TODO: Even page/Odd page section break support
+
+    //check changes in both the header/footer content and page-layout style
+    if ( !firstPage && (sep->bkc == 0) &&
+         (prevStyle == *pageLayoutStyle) &&
+         (headersChanged() == false) )
+    {
+        //FIXME: missing support for fo:break-before="page" in table properties
+        //so let's omitt the <style:master-page> element only in case of a
+        //continuous section break
+
+//         if (sep->bkc != 0) {
+//             textHandler()->set_breakBeforePage(true);
+//         }
+        kDebug(30513) << "omitting page-layout & master-page creation";
+        m_omittMasterPage = true;
+
+        //cleaning required!
+        delete pageLayoutStyle;
+    } else {
+        //save the actual KoGenStyle!
+        prevStyle = *pageLayoutStyle;
+
+        //add data into corresponding lists
+        m_pageLayoutStyle_list.prepend(pageLayoutStyle);
+    }
+    if (m_omittMasterPage) {
+        return;
+    }
+    //check if a first-page specific page-layout has to be created
     if (firstPage) {
        pageLayoutStyle = new KoGenStyle(KoGenStyle::PageLayoutStyle);
 
-       QString fPageLayoutStyleName("FMpm");
-       if (m_textHandler->m_sectionNumber > 1) {
-          fPageLayoutStyleName.append(QString::number(m_textHandler->m_sectionNumber));
-       }
-       // set page-layout attributes for the first page
+       //set page-layout attributes for the first page
        setPageLayoutStyle(pageLayoutStyle, sep, 1);
        pageLayoutStyle->setAutoStyleInStylesDotXml(true);
-       fPageLayoutStyleName = m_mainStyles->insert(*pageLayoutStyle, fPageLayoutStyleName,
-                                                   KoGenStyles::DontAddNumberToName);
-       // add the name into the list
-       m_pageLayoutName_list.prepend(fPageLayoutStyleName);
 
-       // delete the object, we've added it to the collection
-       delete pageLayoutStyle;
-       pageLayoutStyle = 0;
+       //add data into corresponding lists
+       m_pageLayoutStyle_list.prepend(pageLayoutStyle);
     }
 
     // *******************************
     // master-page style
     // *******************************
     KoGenStyle* masterStyle = new KoGenStyle(KoGenStyle::MasterPageStyle);
-    QString masterStyleName("Standard");
+    QString masterStyleName;
 
+    //NOTE: The first master-page-name has to be "Standard", kword has hard
+    //coded that the value of fo:backgroud-color from this style is used for
+    //the entire frameset.
     if (m_textHandler->m_sectionNumber > 1) {
+        masterStyleName.append("MP");
         masterStyleName.append(QString::number(m_textHandler->m_sectionNumber));
+    } else {
+        masterStyleName.append("Standard");
     }
     masterStyle->addAttribute("style:display-name", masterStyleName);
-    masterStyleName = m_mainStyles->insert(*masterStyle, masterStyleName,
-                                           KoGenStyles::DontAddNumberToName);
-    // delete the object, we've added it to the collection
-    delete masterStyle;
-    masterStyle = 0;
 
-    // add the name into the list
+    //add data into corresponding lists
     m_masterPageName_list.prepend(masterStyleName);
+    m_masterPageStyle_list.prepend(masterStyle);
 
-    // initialize the header/footer list
+    //initialize the header/footer list
     m_hasHeader_list.prepend(false);
     m_hasFooter_list.prepend(false);
 
-    // check if a first-page specific master-page has to be created
+    //check if a first-page specific master-page has to be created
     if (firstPage) {
         masterStyle = new KoGenStyle(KoGenStyle::MasterPageStyle);
+        masterStyleName.clear();
+        masterStyleName.append("First_Page");
 
-        QString fMasterStyleName("First_page");
         if (m_textHandler->m_sectionNumber > 1) {
-            fMasterStyleName.append(QString::number(m_textHandler->m_sectionNumber));
+            masterStyleName.append(QString::number(m_textHandler->m_sectionNumber));
         }
-        masterStyle->addAttribute("style:display-name", fMasterStyleName);
+        masterStyle->addAttribute("style:display-name", masterStyleName);
         masterStyle->addAttribute("style:next-style-name", m_masterPageName_list.last());
-        fMasterStyleName = m_mainStyles->insert(*masterStyle, fMasterStyleName,
-                                                KoGenStyles::DontAddNumberToName);
-        // add the name into the list
-        m_masterPageName_list.prepend(fMasterStyleName);
 
-        // delete the object, we've added it to the collection
-        delete masterStyle;
-        masterStyle = 0;
+        //add data into corresponding lists
+        m_masterPageName_list.prepend(masterStyleName);
+        m_masterPageStyle_list.prepend(masterStyle);
 
         //initialize the header/footer list
         m_hasHeader_list.prepend(false);
         m_hasFooter_list.prepend(false);
     }
-    // required by handlers
+    //required by handlers
     m_writeMasterPageName = true;
 
     for (int i = 0; i < m_masterPageName_list.size(); i++) {
@@ -497,13 +518,14 @@ void Document::slotSectionEnd(wvWare::SharedPtr<const wvWare::Word97::SEP> sep)
     kDebug(30513);
     KoGenStyle* masterPageStyle = 0;
     KoGenStyle* pageLayoutStyle = 0;
+    QString pageLayoutName;
 
     for (int i = 0; i < m_masterPageName_list.size(); i++) {
-        //get a pointer to the object in the styles collection
-        masterPageStyle = m_mainStyles->styleForModification(m_masterPageName_list[i]);
-        Q_ASSERT(masterPageStyle);
-        pageLayoutStyle = m_mainStyles->styleForModification(m_pageLayoutName_list[i]);
+
+        pageLayoutStyle = m_pageLayoutStyle_list[i];
+        masterPageStyle = m_masterPageStyle_list[i];
         Q_ASSERT(pageLayoutStyle);
+        Q_ASSERT(masterPageStyle);
 
         //set the margins - depends on whether a header/footer is present
         if (m_hasHeader_list[i]) {
@@ -518,18 +540,32 @@ void Document::slotSectionEnd(wvWare::SharedPtr<const wvWare::Word97::SEP> sep)
         } else if (sep->brcBottom.brcType == 0) {
             pageLayoutStyle->addPropertyPt("fo:margin-bottom", (double)sep->dyaBottom / 20.0);
         }
-        //set the page-layout-name attribute in the master-page style
-        masterPageStyle->addAttribute("style:page-layout-name", m_pageLayoutName_list[i]);
+
+        pageLayoutName = m_mainStyles->insert(*pageLayoutStyle, "Mpm");
+        masterPageStyle->addAttribute("style:page-layout-name", pageLayoutName);
+        m_mainStyles->insert(*masterPageStyle, m_masterPageName_list[i], KoGenStyles::DontAddNumberToName);
+
+        //delete objects, we've added them to the collection
+        delete masterPageStyle;
+        delete pageLayoutStyle;
     }
     //clear lists
-    m_pageLayoutName_list.clear();
+    m_pageLayoutStyle_list.clear();
+    m_masterPageStyle_list.clear();
     m_masterPageName_list.clear();
     m_hasHeader_list.clear();
     m_hasFooter_list.clear();
+
     //reset header data
     m_headerCount = 0;
 }
 
+void Document::headersMask(QList<bool> mask)
+{
+    kDebug(30513) ;
+    m_headersMask = mask;
+}
+
 //creates a frameset element with the header info
 void Document::headerStart(wvWare::HeaderData::Type type)
 {
@@ -582,7 +618,7 @@ void Document::headerStart(wvWare::HeaderData::Type type)
         m_buffer = new QBuffer();
         m_buffer->open(QIODevice::WriteOnly);
         m_headerWriter = new KoXmlWriter(m_buffer);
-	m_firstOpen = true;
+        m_firstOpen = true;
         m_headerWriter->startElement("style:header");
         m_hasHeader_list.replace(0, true);
         break;
@@ -590,9 +626,9 @@ void Document::headerStart(wvWare::HeaderData::Type type)
         m_buffer = new QBuffer();
         m_buffer->open(QIODevice::WriteOnly);
         m_headerWriter = new KoXmlWriter(m_buffer);
-	m_firstOpen = true;
+        m_firstOpen = true;
         m_headerWriter->startElement("style:footer");
-	m_hasFooter_list.replace(0, true);
+        m_hasFooter_list.replace(0, true);
         break;
     }
     //tell other handlers we're writing a header
@@ -626,13 +662,14 @@ void Document::headerEnd()
         KoGenStyle* masterPageStyle = 0;
         QString name = 0;
         if (m_firstOpen) {
-	    name = m_masterPageName_list.first();
+            name = m_masterPageName_list.first();
+            masterPageStyle = m_masterPageStyle_list.first();
             m_firstOpen = false;
 	}
 	else {
-	    name = m_masterPageName_list.last();
+            name = m_masterPageName_list.last();
+            masterPageStyle = m_masterPageStyle_list.last();
 	}
-        masterPageStyle = m_mainStyles->styleForModification(name);
         Q_ASSERT(masterPageStyle);
         m_headerWriter->endElement(); //style:header/footer
 
@@ -644,10 +681,10 @@ void Document::headerEnd()
         }
         QString contents = QString::fromUtf8(m_buffer->buffer(), m_buffer->buffer().size());
         masterPageStyle->addChildElement(QString::number(m_headerCount), contents);
-	kDebug(30513) << "updating master-page style:" << name;
+        kDebug(30513) << "updating master-page style:" << name;
 
-	delete m_buffer;
-	m_buffer = 0;
+        delete m_buffer;
+        m_buffer = 0;
     }
 
     delete m_headerWriter;
@@ -655,7 +692,6 @@ void Document::headerEnd()
 
     //we're done with this header, so reset to false
     m_writingHeader = false;
-    return;
 }
 
 void Document::footnoteStart()
@@ -890,8 +926,8 @@ void Document::processSubDocQueue()
 }
 
 void Document::setPageLayoutStyle(KoGenStyle* pageLayoutStyle,
-				  wvWare::SharedPtr<const wvWare::Word97::SEP> sep,
-				  bool firstPage)
+                                  wvWare::SharedPtr<const wvWare::Word97::SEP> sep,
+                                  bool firstPage)
 {
     // TODO: Check page-layout attributes specific for the first page.
 
@@ -952,25 +988,33 @@ void Document::setPageLayoutStyle(KoGenStyle* pageLayoutStyle,
     //NOTE: 3 - whole document, not mentioned in the "Word Binary File Format
     //(.doc) Structure Specification", but mentiond in word97_generated.h
     if ( (sep->pgbApplyTo == 0) ||
-	((sep->pgbApplyTo == 1) && firstPage) ||
-	((sep->pgbApplyTo == 2) && !firstPage))
+        ((sep->pgbApplyTo == 1) && firstPage) ||
+        ((sep->pgbApplyTo == 2) && !firstPage))
     {
         // FIXME: check if we can use fo:border instead of fo:border-left, etc.
         if (sep->brcLeft.brcType != 0) {
             pageLayoutStyle->addProperty("fo:border-left",
-					 Conversion::setBorderAttributes(sep->brcLeft));
+                                         Conversion::setBorderAttributes(sep->brcLeft));
+            pageLayoutStyle->addProperty("koffice:specialborder-left",
+                                         Conversion::borderKOfficeAttributes(sep->brcLeft));
         }
         if (sep->brcTop.brcType != 0) {
             pageLayoutStyle->addProperty("fo:border-top",
-					 Conversion::setBorderAttributes(sep->brcTop));
+                                         Conversion::setBorderAttributes(sep->brcTop));
+            pageLayoutStyle->addProperty("koffice:specialborder-top",
+                                         Conversion::borderKOfficeAttributes(sep->brcTop));
         }
         if (sep->brcRight.brcType != 0) {
             pageLayoutStyle->addProperty("fo:border-right",
-					 Conversion::setBorderAttributes(sep->brcRight));
-	}
+                                         Conversion::setBorderAttributes(sep->brcRight));
+            pageLayoutStyle->addProperty("koffice:specialborder-right",
+                                         Conversion::borderKOfficeAttributes(sep->brcRight));
+        }
         if (sep->brcBottom.brcType != 0) {
             pageLayoutStyle->addProperty("fo:border-bottom",
-					 Conversion::setBorderAttributes(sep->brcBottom));
+                                         Conversion::setBorderAttributes(sep->brcBottom));
+            pageLayoutStyle->addProperty("koffice:specialborder-bottom",
+                                         Conversion::borderKOfficeAttributes(sep->brcBottom));
         }
     }
     // the pgbOffsetFrom variable determins how to calculate the margins and paddings.
@@ -1001,8 +1045,17 @@ void Document::setPageLayoutStyle(KoGenStyle* pageLayoutStyle,
                                          (sep->dyaBottom - (sep->brcBottom.dptSpace * 20)) / 20);
     }
     // TODO: use sep->fEndNote to set the 'use endnotes or footnotes' flag
+}
 
-    return;
+bool Document::headersChanged(void) const
+{
+    int n = m_textHandler->m_sectionNumber - 1;
+    bool ret = false;
+
+    if (n < m_headersMask.size()) {
+        ret = m_headersMask[n];
+    }
+    return ret;
 }
 
 #include "document.moc"
