@@ -154,8 +154,7 @@ void DrawingWriter::SetClientRectangle(MSO::OfficeArtChildAnchor& anchor)
  */
 KWordGraphicsHandler::KWordGraphicsHandler(Document* doc, KoXmlWriter* bodyWriter,
                                          KoXmlWriter* manifestWriter, KoStore* store,
-                                         KoGenStyles* mainStyles,
-                                         QMap<QByteArray, QString>& picNames)
+                                         KoGenStyles* mainStyles)
 : QObject()
 , m_document(doc)
 , m_store(store)
@@ -166,7 +165,7 @@ KWordGraphicsHandler::KWordGraphicsHandler(Document* doc, KoXmlWriter* bodyWrite
 , m_fib(0)
 , m_pOfficeArtHeaderDgContainer(0)
 , m_pOfficeArtBodyDgContainer(0)
-, m_picNames(picNames)
+, m_zIndex(0)
 {
     kDebug(30513) ;
 }
@@ -335,10 +334,12 @@ DrawStyle KWordGraphicsHandler::getDrawingStyle()
 void KWordGraphicsHandler::drawObject(uint spid, MSO::OfficeArtDgContainer * dg, DrawingWriter& out
         , wvWare::Word97::FSPA* spa)
 {
-    if(dg == NULL)
+    if(dg == NULL || dg->groupShape == NULL)
         return;
 
-    foreach(const OfficeArtSpgrContainerFileBlock& co, dg->groupShape.rgfb) {
+    m_zIndex = 0;
+
+    foreach(const OfficeArtSpgrContainerFileBlock& co, dg->groupShape->rgfb) {
         //if spgr is in root, find out if his first item is sp with right spid
         if (co.anon.is<OfficeArtSpgrContainer>()) {
             const OfficeArtSpContainer* first =
@@ -348,6 +349,8 @@ void KWordGraphicsHandler::drawObject(uint spid, MSO::OfficeArtDgContainer * dg,
                 out.SetRectangle(*spa);
                 processObjectContent(*co.anon.get<OfficeArtSpgrContainer>(), out); //draw group
                 break;
+            } else {
+                m_zIndex = m_zIndex + (*co.anon.get<OfficeArtSpgrContainer>()).rgfb.size();
             }
         }
         else //if sp is in root, find out if it has the right spid
@@ -359,6 +362,7 @@ void KWordGraphicsHandler::drawObject(uint spid, MSO::OfficeArtDgContainer * dg,
                 processObjectContent(spCo, out); //draw object
                 break;
             }
+            m_zIndex++;
         }
     }
 }
@@ -632,11 +636,11 @@ void KWordGraphicsHandler::defineGraphicProperties(KoGenStyle& style, const Draw
     // draw:fill-gradient-name
     // draw:fill-hatch-name
     // draw:fill-hatch-solid
-    // draw:fill-image-height
     // draw:fill-image-name
     // draw:fill-image-ref-point
     // draw:fill-image-ref-point-x
     // draw:fill-image-ref-point-y
+    // draw:fill-image-height
     // draw:fill-image-width
     // draw:fit-to-contour
     // draw:fit-to-size
@@ -757,16 +761,6 @@ void KWordGraphicsHandler::defineGraphicProperties(KoGenStyle& style, const Draw
     // style:rel-height
     // style:rel-width
     // style:repeat
-
-    if (ds.fBehindDocument()) {
-        // The 'OpenDocument Essentials' say that if you want a frame in the background,
-        // you should set style:wrap="run-through" AND style:run-through="background"
-        style.addProperty("style:wrap", "run-through");
-        style.addProperty("style:run-through", "background");
-    }
-    else {
-        style.addProperty("style:run-through", "foreground");
-    }
     // style:shadow
     // svg:fill-rule
     // svg:height
@@ -864,7 +858,7 @@ void KWordGraphicsHandler::defineAnchorProperties(KoGenStyle& style, const DrawS
 
 void KWordGraphicsHandler::defineWrappingProperties(KoGenStyle& style, const DrawStyle& ds, const wvWare::Word97::FSPA* spa)
 {
-    //NOTE: margins are related to the style of text wrapping, (MS-DOC, page 464)
+    //process the wrapping style, (MS-DOC, page 464)
     if (spa != 0) {
         bool check_wrk = false;
         if (spa->wr == 0) {
@@ -874,23 +868,18 @@ void KWordGraphicsHandler::defineWrappingProperties(KoGenStyle& style, const Dra
         else if (spa->wr == 1) {
             //top and bottom wrapping
             style.addProperty("style:wrap", "none");
-            style.addPropertyPt("style:margin-top", ds.dyWrapDistTop()/12700.);
-            style.addPropertyPt("style:margin-bottom", ds.dyWrapDistBottom()/12700.);
         }
         else if (spa->wr == 2) {
             //square wrapping
             check_wrk = true;
-            style.addPropertyPt("style:margin-top", ds.dyWrapDistTop()/12700.);
-            style.addPropertyPt("style:margin-bottom", ds.dyWrapDistBottom()/12700.);
         }
         else if (spa->wr == 3) {
             //in front or behind the text
             style.addProperty("style:wrap", "run-through");
-            //check if shape is behind the text
-            if (spa->fBelowText == 1) {
+	    //check if shape is behind the text
+            if ((spa->fBelowText == 1) || (ds.fBehindDocument())) {
                 style.addProperty("style:run-through", "background");
-            }
-            else if (spa->fBelowText == 0) {
+            } else {
                 style.addProperty("style:run-through", "foreground");
             }
         }
@@ -918,38 +907,65 @@ void KWordGraphicsHandler::defineWrappingProperties(KoGenStyle& style, const Dra
                 style.addProperty("style:wrap", "right");
             }
             else if (spa->wrk == 3) {
-                style.addProperty("style:wrap", "dynamic");
+                style.addProperty("style:wrap", "biggest");
             }
-            style.addPropertyPt("style:margin-left", ds.dxWrapDistLeft()/12700.);
-            style.addPropertyPt("style:margin-right", ds.dxWrapDistRight()/12700.);
         }
     }
+    //no information from plcfSpa available 
+    else {
+        style.addProperty("style:wrap", "run-through");
+        if (ds.fBehindDocument()) {
+            style.addProperty("style:run-through", "background");
+        } else {
+            style.addProperty("style:run-through", "foreground");
+        }
+    }
+
+    //margins are related to text wrapping, 
+    style.addPropertyPt("style:margin-left", ds.dxWrapDistLeft()/12700.);
+    style.addPropertyPt("style:margin-right", ds.dxWrapDistRight()/12700.);
+    style.addPropertyPt("style:margin-top", ds.dyWrapDistTop()/12700.);
+    style.addPropertyPt("style:margin-bottom", ds.dyWrapDistBottom()/12700.);
+
     // style:number-wrapped-paragraphs
     // style:wrap-dynamic-treshold
 }
 
+void KWordGraphicsHandler::SetAnchorTypeAtribute(DrawingWriter& out)
+{
+    if (out.m_inline) {
+        out.xml.addAttribute("text:anchor-type","as-char");
+    } else {
+        out.xml.addAttribute("text:anchor-type","char");
+    }
+}
+
+void KWordGraphicsHandler::SetZIndexAtribute(DrawingWriter& out)
+{
+    out.xml.addAttribute("draw:z-index",m_zIndex);
+}
+
 void KWordGraphicsHandler::parseTextBox(const MSO::OfficeArtSpContainer& o, DrawingWriter out)
 {
     QString styleName;
     DrawStyle ds(m_OfficeArtDggContainer,&o);
-    if (out.m_bodyDrawing) {
-        KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
-        defineGraphicProperties(style, ds);
-        defineAnchorProperties(style, ds);
-        styleName = out.styles.insert(style);
-    }
-    else {
-        KoGenStyle style(KoGenStyle::GraphicStyle, "graphic");
-        defineGraphicProperties(style, ds);
-        defineAnchorProperties(style, ds);
-        styleName = out.styles.insert(style);
-    }
-
     DrawStyle drawStyle(m_OfficeArtDggContainer,NULL,&o);
+    wvWare::Word97::FSPA* spa = out.m_pSpa;
+    KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
+
+    if (!out.m_bodyDrawing) {
+        style.setAutoStyleInStylesDotXml(true);
+    }
+    defineGraphicProperties(style, ds);
+    defineWrappingProperties(style, ds, spa);
+    defineAnchorProperties(style, ds);
+    styleName = out.styles.insert(style);
 
     out.xml.startElement("draw:frame");
     out.xml.addAttribute("draw:style-name", styleName);
-    out.xml.addAttribute("text:anchor-type","char");
+    SetAnchorTypeAtribute(out);
+    SetZIndexAtribute(out);
+
     switch(drawStyle.txflTextFlow()) {
     case 1: //msotxflTtoBA up-down
     case 3: //msotxflTtoBN up-down
@@ -984,22 +1000,21 @@ void KWordGraphicsHandler::processRectangle(const MSO::OfficeArtSpContainer& o,D
 {
     QString styleName;
     DrawStyle ds(m_OfficeArtDggContainer,&o);
-    if (out.m_bodyDrawing) {
-        KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
-        defineGraphicProperties(style, ds);
-        defineAnchorProperties(style, ds);
-        styleName = out.styles.insert(style);
-    }
-    else {
-        KoGenStyle style(KoGenStyle::GraphicStyle, "graphic");
-        defineGraphicProperties(style, ds);
-        defineAnchorProperties(style, ds);
-        styleName = out.styles.insert(style);
+    wvWare::Word97::FSPA* spa = out.m_pSpa;
+    KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
+
+    if (!out.m_bodyDrawing) {
+        style.setAutoStyleInStylesDotXml(true);
     }
+    defineGraphicProperties(style, ds);
+    defineWrappingProperties(style, ds, spa);
+    defineAnchorProperties(style, ds);
+    styleName = out.styles.insert(style);
 
     out.xml.startElement("draw:frame");
     out.xml.addAttribute("draw:style-name", styleName);
-    out.xml.addAttribute("text:anchor-type","char");
+    SetAnchorTypeAtribute(out);
+    SetZIndexAtribute(out);
     out.xml.addAttribute("draw:layer", "layout");
     out.xml.addAttribute("svg:width", out.hLength());
     out.xml.addAttribute("svg:height", out.vLength());
@@ -1018,12 +1033,12 @@ void KWordGraphicsHandler::processInlinePictureFrame(const MSO::OfficeArtSpConta
     QString styleName;
     DrawStyle ds(NULL, &o);
     KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
-    defineGraphicProperties(style, ds);
 
     //in case a header or footer is processed, save the style into styles.xml
     if (m_document->writingHeader()) {
         style.setAutoStyleInStylesDotXml(true);
     }
+    defineGraphicProperties(style, ds);
     styleName = out.styles.insert(style);
 
     QString url;
@@ -1065,22 +1080,25 @@ void KWordGraphicsHandler::processFloatingPictureFrame(const MSO::OfficeArtSpCon
 
     QString styleName;
     DrawStyle ds(m_OfficeArtDggContainer, &o);
-    KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
     wvWare::Word97::FSPA* spa = out.m_pSpa;
-    defineGraphicProperties(style, ds);
-    defineWrappingProperties(style, ds, spa);
+    KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
 
-    //ODF-1.2: this property must be provided if wrap mode is in {left, right,
-    //parallel, dynamic} and anchor type is in {char, paragraph}
-    if (spa) {
-        if ((spa->wr != 1) && (spa->wr != 3)) {
-            style.addProperty("style:number-wrapped-paragraphs", "no-limit");
-	}
-    }
     //in case a header or footer is processed, save the style into styles.xml
     if (m_document->writingHeader()) {
         style.setAutoStyleInStylesDotXml(true);
     }
+    defineGraphicProperties(style, ds);
+    defineWrappingProperties(style, ds, spa);
+    defineAnchorProperties(style, ds);
+
+    //ODF-1.2: specifies the number of paragraphs that can wrap around a frame
+    //if wrap mode is in {left, right, parallel, dynamic} and anchor type is in
+    //{char, paragraph}
+    if (spa) {
+        if ((spa->wr != 1) && (spa->wr != 3)) {
+            style.addProperty("style:number-wrapped-paragraphs", "no-limit");
+        }
+    }
     styleName = out.styles.insert(style);
 
     QString url;
@@ -1095,6 +1113,7 @@ void KWordGraphicsHandler::processFloatingPictureFrame(const MSO::OfficeArtSpCon
     }
     out.xml.addAttribute("draw:style-name", styleName);
     out.xml.addAttribute("text:anchor-type","char");
+    SetZIndexAtribute(out);
     out.xml.addAttribute("svg:width", out.hLength());
     out.xml.addAttribute("svg:height", out.vLength());
     out.xml.addAttribute("svg:x", out.hOffset());
@@ -1109,22 +1128,22 @@ void KWordGraphicsHandler::processFloatingPictureFrame(const MSO::OfficeArtSpCon
 
     //check for user edited wrap points
     if (ds.fEditedWrap()) {
-	QString points;
-	QByteArray* data = NULL;
-	data = getComplexData<PWrapPolygonVertices>(o);
-	if (data) {
-	    QBuffer buf(data);
-	    buf.open(QIODevice::ReadOnly);
-	    LEInputStream in(&buf);
-	    PWrapPolygonVertices_complex _v;
-	    parsePWrapPolygonVertices_complex(in, _v);
-            buf.close();
+        QString points;
+        QByteArray* data = NULL;
+        data = getComplexData<PWrapPolygonVertices>(o);
+        if (data) {
+            QBuffer buf(data);
+            buf.open(QIODevice::ReadOnly);
+            LEInputStream in(&buf);
+            PWrapPolygonVertices_complex _v;
+            parsePWrapPolygonVertices_complex(in, _v);
+                buf.close();
 
-	    //_v.data is an array of POINTs, MS-ODRAW, page 89
-	    QByteArray a, a2;
-	    int* p;
+            //_v.data is an array of POINTs, MS-ODRAW, page 89
+            QByteArray a, a2;
+            int* p;
 
-	    for (int i = 0, offset = 0; i < _v.nElems; i++, offset += _v.cbElem) {
+            for (int i = 0, offset = 0; i < _v.nElems; i++, offset += _v.cbElem) {
                 // x coordinate of this point
                 a = _v.data.mid(offset, _v.cbElem);
                 a2 = a.mid(0, _v.cbElem / 2);
@@ -1155,6 +1174,11 @@ void KWordGraphicsHandler::processLineShape(const MSO::OfficeArtSpContainer& o,
     QString styleName;
     DrawStyle ds(NULL, &o);
     KoGenStyle style(KoGenStyle::GraphicAutoStyle, "graphic");
+
+    //in case a header or footer is processed, save the style into styles.xml
+    if (m_document->writingHeader()) {
+        style.setAutoStyleInStylesDotXml(true);
+    }
     defineGraphicProperties(style, ds);
 
     //NOTE: also the dxWidthHR propertie may store the width information
@@ -1187,17 +1211,13 @@ void KWordGraphicsHandler::processLineShape(const MSO::OfficeArtSpContainer& o,
     else {
         style.addProperty("draw:shadow", "visible");
     }
-
-    //in case a header or footer is processed, save the style into styles.xml
-    if (m_document->writingHeader()) {
-        style.setAutoStyleInStylesDotXml(true);
-    }
     styleName = out.styles.insert(style);
 
     //create a custom shape
     out.xml.startElement("draw:custom-shape");
     out.xml.addAttribute("draw:style-name", styleName);
-    out.xml.addAttribute("text:anchor-type", "as-char");
+    SetAnchorTypeAtribute(out);
+    SetZIndexAtribute(out);
 
     QString height = QString::number(ds.dxHeightHR() / 1440.0f).append("in");
     out.xml.addAttribute("svg:height", height);
@@ -1231,8 +1251,13 @@ void KWordGraphicsHandler::parseFloatingPictures(void)
             if (block.anon.is<OfficeArtFBSE>()) {
                 OfficeArtFBSE* fbse = block.anon.get<OfficeArtFBSE>();
                 if (!fbse->embeddedBlip) {
-                    //An foDelay value of 0xffffffff specifies that the file is
-                    //not in the delay stream and cRef must be zero.
+
+                    //NOTE: An foDelay value of 0xffffffff specifies that the
+                    //file is not in the delay stream and cRef must be zero.
+
+                    //NOTE: A cRef value of 0x00000000 specifies an empty slot
+                    //in the OfficeArtBStoreContainer.
+
                     if (fbse->foDelay != 0xffffffff) {
                         if (!fbse->cRef) {
                             kDebug(30513) << "Strange, no references to this BLIP, skipping";
@@ -1274,8 +1299,8 @@ KWordGraphicsHandler::createFloatingPictures(KoStore* store, KoXmlWriter* manife
         foreach (const OfficeArtBStoreContainerFileBlock& block, blipStore->rgfb) {
             ref = savePicture(block, store);
             if (ref.name.length() == 0) {
-                kDebug(30513) << "empty name in picture reference";
-                break;
+                kDebug(30513) << "Note: Empty picture reference, probably an empty slot";
+                continue;
 	    }
             manifest->addManifestEntry("Pictures/" + ref.name, ref.mimetype);
             fileNames[ref.uid] = ref.name;
