@@ -107,23 +107,40 @@ void Paragraph::addRunOfText(QString text,  wvWare::SharedPtr<const wvWare::Word
     const wvWare::Style* msTextStyle = styles.styleByIndex(chp->istd);
     Q_ASSERT(msTextStyle);
     QString msTextStyleName = Conversion::styleNameString(msTextStyle->name());
-    kDebug(30513) << "text has characterstyle " << msTextStyleName;
+    kDebug(30513) << "text based on characterstyle " << msTextStyleName;
 
-    KoGenStyle *textStyle = m_mainStyles->styleForModification(msTextStyleName);
-    if (!textStyle) {
-        kWarning() << "Couldn't retrieve style for modification!";
-    }
+    KoGenStyle *textStyle;
 
     bool suppresFontSize = false;
     if (m_textStyles.size() == 0 && m_paragraphProperties->pap().dcs.lines > 1) {
         suppresFontSize = true;
     }
 
-    // Modify the character style if we detect any diff between the
-    // chp of the paragraph and the summed chp.
-    const wvWare::Style* parentStyle = styles.styleByIndex(msTextStyle->m_std->istdBase);
-    if (parentStyle) {
-        applyCharacterProperties(chp, textStyle, m_paragraphStyle, suppresFontSize, m_combinedCharacters);
+    // Apply any extra properties to our auto style
+    // those extra properties is the diff beteween the referenceChp and the summed chp.
+    // ReferenceCHP can be either the paragraph or a named style
+    if (msTextStyle->sti() != 65) {
+        // this is not default paragraph font
+        textStyle = new KoGenStyle(KoGenStyle::TextAutoStyle, "text");
+        if (m_inStylesDotXml) {
+            textStyle->setAutoStyleInStylesDotXml(true);
+        }
+        textStyle->setParentName(msTextStyleName);
+        //if we have a new font, process that
+        const wvWare::Word97::CHP* refChp = &msTextStyle->chp();
+        if (!refChp || refChp->ftcAscii != chp->ftcAscii) {
+            if (!fontName.isEmpty()) {
+                textStyle->addProperty(QString("style:font-name"), fontName, KoGenStyle::TextType);
+            }
+        applyCharacterProperties(chp, textStyle, msTextStyle, suppresFontSize, m_combinedCharacters);
+        }
+    } else {
+        // Default Paragraph Font, which is handled differently
+        // Meaning we should really compare against the CHP of the paragraph
+        textStyle = new KoGenStyle(KoGenStyle::TextAutoStyle, "text");
+        if (m_inStylesDotXml) {
+            textStyle->setAutoStyleInStylesDotXml(true);
+        }
         //if we have a new font, process that
         const wvWare::Word97::CHP* refChp = &m_paragraphStyle->chp();
         if (!refChp || refChp->ftcAscii != chp->ftcAscii) {
@@ -131,14 +148,6 @@ void Paragraph::addRunOfText(QString text,  wvWare::SharedPtr<const wvWare::Word
                 textStyle->addProperty(QString("style:font-name"), fontName, KoGenStyle::TextType);
             }
         }
-    } else {
-        textStyle = new KoGenStyle(KoGenStyle::TextAutoStyle, "text");
-        if (m_inStylesDotXml) {
-            textStyle->setAutoStyleInStylesDotXml(true);
-        }
-        if (!fontName.isEmpty()) {
-            textStyle->addProperty(QString("style:font-name"), fontName, KoGenStyle::TextType);
-        }
         applyCharacterProperties(chp, textStyle, m_paragraphStyle, suppresFontSize, m_combinedCharacters);
     }
 
@@ -165,6 +174,11 @@ void Paragraph::writeToFile(KoXmlWriter* writer)
     // paragraph.
     if (m_dropCapStatus == IsDropCapPara) {
         kDebug(30513) << "returning with drop cap paragraph";
+        if (m_textStrings.size()) {
+            if (m_textStyles[0] != 0) {
+                m_dropCapStyleName= m_textStyles[0]->parentName();
+            }
+        }
         return;
     }
 
@@ -181,7 +195,10 @@ void Paragraph::writeToFile(KoXmlWriter* writer)
         // We have only support for fdct=1, i.e. regular dropcaps.
         // There is no support for fdct=2, i.e. dropcaps in the margin (ODF doesn't support this).
         tmpWriter.addAttribute("style:length", m_dcs_fdct > 0 ? 1 : 0);
-        tmpWriter.endElement();//style:drop-cap
+        if (!m_dropCapStyleName.isEmpty()) {
+            tmpWriter.addAttribute("style:style-name", m_dropCapStyleName.toUtf8());
+        }
+        tmpWriter.endElement(); //style:drop-cap
         buf.close();
 
         QString contents = QString::fromUtf8(buf.buffer(), buf.buffer().size());
@@ -310,6 +327,11 @@ void Paragraph::writeToFile(KoXmlWriter* writer)
         bool startedSpan = false;
         for (int i = 0; i < m_textStrings.size(); i++) {
             if (m_textStyles[i] == 0) {
+                if (startedSpan) {
+                    writer->endElement(); //text:span
+                    startedSpan = false;
+                    oldStyleName = " ";
+                }
                 //if style is null, we have an inner paragraph and add the
                 //complete paragraph element to writer need to get const char*
                 //from the QString
@@ -345,7 +367,7 @@ void Paragraph::writeToFile(KoXmlWriter* writer)
                     writer->addCompleteElement(m_textStrings[i].toLocal8Bit().constData());
                 }
                 //cleanup
-                delete m_textStyles[i];
+                //delete m_textStyles[i];
                 m_textStyles[i] = 0;
             }
         }
@@ -858,17 +880,18 @@ Paragraph::DropCapStatus Paragraph::dropCapStatus() const
     return m_dropCapStatus;
 }
 
-void Paragraph::getDropCapData(QString *string, int *type, int *lines, qreal *distance) const
+void Paragraph::getDropCapData(QString *string, int *type, int *lines, qreal *distance, QString *style) const
 {
     // As far as I can see there is only ever a single character as drop cap.
     *string = m_textStrings[0];
     *type = m_dcs_fdct;
     *lines = m_dcs_lines;
     *distance = m_dropCapDistance;
+    *style = m_dropCapStyleName;
 }
 
 
-void Paragraph::addDropCap(QString &string, int type, int lines, qreal distance)
+void Paragraph::addDropCap(QString &string, int type, int lines, qreal distance, QString style)
 {
     kDebug(30513) << "combining drop cap paragraph: " << string;
     if (m_dropCapStatus == IsDropCapPara) 
@@ -880,6 +903,7 @@ void Paragraph::addDropCap(QString &string, int type, int lines, qreal distance)
     m_dcs_fdct        = type;
     m_dcs_lines       = lines;
     m_dropCapDistance = distance;
+    m_dropCapStyleName = style;
 
     // Add the actual text.
     // Here we assume that there will only be one text snippet for the drop cap.
@@ -924,3 +948,27 @@ QString Paragraph::string(int index) const
     return m_textStrings[index];
 }
 
+QString Paragraph::createTextStyle(wvWare::SharedPtr<const wvWare::Word97::CHP> chp, const wvWare::StyleSheet& styles)
+{
+    const wvWare::Style* msTextStyle = styles.styleByIndex(chp->istd);
+    Q_ASSERT(msTextStyle);
+    QString msTextStyleName = Conversion::styleNameString(msTextStyle->name());
+    kDebug(30513) << "text based on characterstyle " << msTextStyleName;
+
+    KoGenStyle *textStyle;
+    textStyle = new KoGenStyle(KoGenStyle::TextAutoStyle, "text");
+    if (m_inStylesDotXml) {
+        textStyle->setAutoStyleInStylesDotXml(true);
+    }
+
+    bool suppresFontSize = false;
+    if (m_paragraphProperties->pap().dcs.lines > 1) {
+        suppresFontSize = true;
+    }
+    applyCharacterProperties(chp, textStyle, m_paragraphStyle, suppresFontSize, m_combinedCharacters);
+
+    QString textStyleName('T');
+    textStyleName = m_mainStyles->insert(*textStyle, textStyleName);
+
+    return textStyleName;
+}
