@@ -37,7 +37,8 @@
 
 using Conversion::twipsToPt;
 
-KWordTableHandler::KWordTableHandler(KoXmlWriter* bodyWriter, KoGenStyles* mainStyles)
+KWordTableHandler::KWordTableHandler(KoXmlWriter* bodyWriter, KoGenStyles* mainStyles) :
+m_floatingTable(false)
 {
     // This strange value (-2), is used to create a check that e.g.  a
     // table row is not written before a table:table is started.
@@ -70,6 +71,126 @@ void KWordTableHandler::tableStart(KWord::Table* table)
     m_row = -1;
     m_currentY = 0;
 
+    //check if the table is inside of an absolutely positioned frame
+    if ( (tap->dxaAbs != 0 || tap->dyaAbs) )
+    {
+        KoGenStyle userStyle(KoGenStyle::GraphicAutoStyle, "graphic");
+        QString drawStyleName;
+        int dxaAbs = 0;
+
+        writer->startElement("text:p", false);
+        writer->addAttribute("text:style-name", "Standard");
+
+        //process wrapping information
+        if (tap->textWrap) {
+            //right aligned
+            if (tap->dxaAbs == -8) {
+                userStyle.addProperty("style:wrap", "left");
+            }
+            //left aligned
+            else if (tap->dxaAbs == 0) {
+                userStyle.addProperty("style:wrap", "right");
+            } else {
+                userStyle.addProperty("style:wrap", "parallel");
+            }
+           //ODF-1.2: specifies the number of paragraphs that can wrap around a
+           //frame if wrap mode is in {left, right, parallel, dynamic} and
+           //anchor type is in {char, paragraph}
+            userStyle.addProperty("style:number-wrapped-paragraphs", "no-limit");
+        } else {
+            userStyle.addProperty("style:wrap", "none");
+        }
+
+        //margin information is related to wrapping of text around the table
+        userStyle.addPropertyPt("fo:margin-left", twipsToPt(tap->dxaFromText));
+        userStyle.addPropertyPt("fo:margin-right", twipsToPt(tap->dxaFromTextRight));
+        userStyle.addPropertyPt("fo:margin-top", twipsToPt(tap->dyaFromText));
+        userStyle.addPropertyPt("fo:margin-bottom", twipsToPt(tap->dyaFromTextBottom));
+
+        //MS-DOC - sprmPDxaAbs - relative horizontal position to anchor
+        // (-4) - center, (-8) - right, (-12) - inside, (-16) - outside
+        if (tap->dxaAbs == -4) {
+            userStyle.addProperty("style:horizontal-pos","center");
+        }
+        else if (tap->dxaAbs == -8)  {
+            userStyle.addProperty("style:horizontal-pos","right");
+            userStyle.addPropertyPt("fo:margin-right", 0);
+        }
+        else if (tap->dxaAbs == -12) {
+            userStyle.addProperty("style:horizontal-pos","inside");
+        }
+        else if (tap->dxaAbs == -16) {
+            userStyle.addProperty("style:horizontal-pos","outside");
+        }
+        else {
+            dxaAbs = tap->dxaAbs;
+            userStyle.addProperty("style:horizontal-pos","from-left");
+            userStyle.addPropertyPt("fo:margin-left", 0);
+        }
+
+        int dyaAbs = 0;
+        //MS-DOC - sprmPDyaAbs - relative vertical position to anchor
+        // (-4) - top, (-8) - middle, (-12) - bottom, (-16) - inside,
+        // (-20) - outside
+        if (tap->dyaAbs == -4) {
+            userStyle.addProperty("style:vertical-pos","top");
+        }
+        else if (tap->dyaAbs == -8) {
+            userStyle.addProperty("style:vertical-pos","middle");
+        }
+        else if (tap->dyaAbs == -12) {
+            userStyle.addProperty("style:vertical-pos","bottom");
+        }
+        else if (tap->dyaAbs == -16) {
+            userStyle.addProperty("style:vertical-pos","inline");
+        }
+        else if (tap->dyaAbs == -20) {
+            userStyle.addProperty("style:vertical-pos","inline");
+        }
+        else {
+            dyaAbs = tap->dyaAbs;
+            userStyle.addProperty("style:vertical-pos","from-top");
+        }
+        //MS-DOC - PositionCodeOperand - anchor vertical position
+        // 0 - margin, 1 - page, 2 - paragraph
+        if (tap->pcVert == 0) {
+            userStyle.addProperty("style:vertical-rel","page-content");
+        }
+        else if (tap->pcVert == 1) {
+            userStyle.addProperty("style:vertical-rel","page");
+        }
+        else if (tap->pcVert == 2) {
+            userStyle.addProperty("style:vertical-rel","paragraph");
+        }
+        //MS-DOC - PositionCodeOperand - anchor horizontal position
+        // 0 - current column, 1 - margin, 2 - page
+        if (tap->pcHorz == 0) {
+            userStyle.addProperty("style:horizontal-rel","paragraph");
+        }
+        else if (tap->pcHorz == 1) {
+            userStyle.addProperty("style:horizontal-rel","page-content");
+        }
+        else if (tap->pcHorz == 2) {
+            userStyle.addProperty("style:horizontal-rel","page");
+        }
+
+        drawStyleName = "fr";
+        drawStyleName = m_mainStyles->insert(userStyle, drawStyleName);
+        writer->startElement("draw:frame");
+        writer->addAttribute("draw:style-name", drawStyleName.toUtf8());
+        writer->addAttribute("text:anchor-type", "paragraph");
+
+        writer->addAttributePt("svg:width", 
+                               (double)(table->m_cellEdges[table->m_cellEdges.size() - 1] - 
+                               table->m_cellEdges[0]) / 20.0);
+
+        writer->addAttributePt("svg:x", (double)(dxaAbs + tap->rgdxaCenter[0])/20);
+        writer->addAttributePt("svg:y", (double)dyaAbs/20);
+        writer->startElement("draw:text-box");
+
+        m_floatingTable = true;
+    }
+
     //table style
     KoGenStyle tableStyle(KoGenStyle::TableAutoStyle, "table");
 
@@ -78,27 +199,38 @@ void KWordTableHandler::tableStart(KWord::Table* table)
         tableStyle.setAutoStyleInStylesDotXml(true);
     }
 
-    //process horizontal align information
-    QString align;
-    switch (table->tap->jc) {
-    case wvWare::hAlignLeft:
-        align = QString("left");
-        break;
-    case wvWare::hAlignCenter:
-        align = QString("center");
-        break;
-    case wvWare::hAlignRight:
-        align = QString("right");
-        break;
+    if (tap->fBiDi == 1) {
+        tableStyle.addProperty("style:writing-mode", "rl-tb");
+    } else {
+        tableStyle.addProperty("style:writing-mode", "lr-tb");
     }
 
-    tableStyle.addPropertyPt("style:width", (table->m_cellEdges[table->m_cellEdges.size()-1] - table->m_cellEdges[0]) / 20.0);
+    //process horizontal align information
+    QString align;
+    if (m_floatingTable != true) {
+        switch (tap->jc) {
+        case wvWare::hAlignLeft:
+            align = QString("left");
+            break;
+        case wvWare::hAlignCenter:
+            align = QString("center");
+            break;
+        case wvWare::hAlignRight:
+            align = QString("right");
+            break;
+        }
+    } else {
+        align = QString("margins");
+    } 
     tableStyle.addProperty("table:align", align);
+    tableStyle.addPropertyPt("style:width", (table->m_cellEdges[table->m_cellEdges.size()-1] - table->m_cellEdges[0]) / 20.0);
     tableStyle.addProperty("style:border-model", "collapsing");
 
     //process the margin information 
-    int margin = tap->rgdxaCenter[0];
-    tableStyle.addPropertyPt("fo:margin-left", twipsToPt(margin));
+    if (m_floatingTable != true) {
+        int margin = tap->rgdxaCenter[0];
+        tableStyle.addPropertyPt("fo:margin-left", twipsToPt(margin));
+    }
 
     //check if we need a master page name attribute.
     if (document()->writeMasterPageName() && !document()->writingHeader()) {
@@ -125,10 +257,11 @@ void KWordTableHandler::tableStart(KWord::Table* table)
                                        (table->m_cellEdges[r+1] - table->m_cellEdges[r]) / 20.0);
 
         QString tableColumnStyleName;
-        if (r >= 26)
+        if (r >= 26) {
             tableColumnStyleName = m_mainStyles->insert(tableColumnStyle, tableStyleName + ".A" + QChar('A' + r - 26), KoGenStyles::DontAddNumberToName);
-        else
+        } else {
             tableColumnStyleName = m_mainStyles->insert(tableColumnStyle, tableStyleName + '.' + QChar('A' + r), KoGenStyles::DontAddNumberToName);
+        }
 
         writer->startElement("table:table-column");
         writer->addAttribute("table:style-name", tableColumnStyleName);
@@ -141,8 +274,18 @@ void KWordTableHandler::tableEnd()
     kDebug(30513) ;
     m_currentTable = 0L; // we don't own it, Document does
     KoXmlWriter*  writer = currentWriter();
-    //end table in content
+
     writer->endElement();//table:table
+
+    //check if the table is inside of an absolutely positioned frame
+    if ( m_floatingTable == true )
+    {
+        writer->endElement(); //draw:text-box
+        writer->endElement(); //draw:frame
+        writer->endElement(); //close the <text:p>
+
+        m_floatingTable = false;
+    }
 }
 
 void KWordTableHandler::tableRowStart(wvWare::SharedPtr<const wvWare::Word97::TAP> tap)
@@ -385,6 +528,9 @@ void KWordTableHandler::tableCellStart()
                                           brcWinner(tc.brcRight, m_tap->rgbrcTable[5]) :
                                           brcWinner(tc.brcRight, m_tap->rgbrcTable[3]);
 
+    const wvWare::Word97::BRC& brcTL2BR = tc.brcTL2BR;
+    const wvWare::Word97::BRC& brcTR2BL = tc.brcTR2BL;
+
     KoGenStyle cellStyle(KoGenStyle::TableCellAutoStyle, "table-cell");
 
     //in case a header or footer is processed, save the style into styles.xml
@@ -440,18 +586,45 @@ void KWordTableHandler::tableCellStart()
             cellStyle.addProperty("style:border-line-width-right", dba);
     }
 
-    //check if we have to ignore the shading information   
+    //top left to bottom right
+    if (brcTL2BR.brcType > 0 && brcTL2BR.brcType < 64) {
+        cellStyle.addProperty("style:diagonal-tl-br", Conversion::setBorderAttributes(brcTL2BR));
+        QString kba = Conversion::borderKOfficeAttributes(brcTL2BR);
+        if (!kba.isEmpty()) {
+            cellStyle.addProperty("koffice:specialborder-tl-br",kba);
+        }
+        QString dba = Conversion::setDoubleBorderAttributes(brcTL2BR);
+        if (!dba.isEmpty()) {
+            cellStyle.addProperty("style:diagonal-tl-br-widths", dba);
+        }
+    }
+
+    //top right to bottom left
+    if (brcTR2BL.brcType > 0 && brcTR2BL.brcType < 64) {
+        cellStyle.addProperty("style:diagonal-bl-tr", Conversion::setBorderAttributes(brcTR2BL));
+        QString kba = Conversion::borderKOfficeAttributes(brcTR2BL);
+        if (!kba.isEmpty()) {
+            cellStyle.addProperty("koffice:specialborder-tr-bl",kba);
+        }
+        QString dba = Conversion::setDoubleBorderAttributes(brcTR2BL);
+        if (!dba.isEmpty()) {
+            cellStyle.addProperty("style:diagonal-bl-tr-widths", dba);
+        }
+    }
+
+    //check if we have to ignore the shading information
     if (!shd.shdAutoOrNill) {
-	QString color = QString('#');
-	//ipatPct5 to ipatPct90
+        QString color = QString('#');
+        //ipatPct5 to ipatPct90
         if (shd.ipat >= 0x02 && shd.ipat <= 0x0d) {
             //get the color from the shading pattern
             uint grayColor = Conversion::shadingPatternToColor(shd.ipat);
             color.append(QString::number(grayColor | 0xff000000, 16).right(6).toUpper());
             cellStyle.addProperty("fo:background-color", color);
         }
-	//ipatSolid
-        else if (shd.ipat == 0x01) {
+        //ipatSolid or ipatnil means that no pattern is applied, but only color
+        //The case of neither color nor pattern is tested above by the shdAutoOrNill
+        else if (shd.ipat == 0x01 || shd.ipat == 0x00) {
             color.append(QString::number(shd.cvBack | 0xff000000, 16).right(6).toUpper());
             cellStyle.addProperty("fo:background-color", color);
         }
@@ -480,7 +653,13 @@ void KWordTableHandler::tableCellStart()
     }
     cellStyle.addProperty("style:vertical-align", align);
 
-    //TODO: parse and process cell padding information
+    //process cell padding information
+    qreal padVert = twipsToPt(m_tap->padVert);
+    qreal padHorz = twipsToPt(m_tap->padHorz);
+    cellStyle.addPropertyPt("fo:padding-top", padVert);
+    cellStyle.addPropertyPt("fo:padding-bottom", padVert);
+    cellStyle.addPropertyPt("fo:padding-left", padHorz);
+    cellStyle.addPropertyPt("fo:padding-right", padHorz);
 
     QString cellStyleName = m_mainStyles->insert(cellStyle, QLatin1String("cell"));
 
