@@ -41,11 +41,11 @@
 #include <KoShapeLoadingContext.h>
 #include <KoTextSharedLoadingData.h>
 #include <KoParagraphStyle.h>
+#include <KoShapeRegistry.h>
 
 #include "ApplicationSettings.h"
 #include "BindingManager.h"
 #include "CalculationSettings.h"
-#include "part/Canvas.h" // FIXME detach from part
 #include "Damages.h"
 #include "DependencyManager.h"
 #include "part/Doc.h" // FIXME detach from part
@@ -57,7 +57,6 @@
 #include "OdfSavingContext.h"
 #include "RecalcManager.h"
 #include "RowColumnFormat.h"
-#include "Selection.h"
 #include "Sheet.h"
 #include "StyleManager.h"
 #include "StyleStorage.h"
@@ -66,11 +65,12 @@
 #include "ValueConverter.h"
 #include "ValueFormatter.h"
 #include "ValueParser.h"
-#include "part/View.h" // FIXME detach from part
 
 // database
 #include "database/DatabaseManager.h"
 
+#include "shape/TableShapeFactory.h"
+
 // D-Bus
 #include "interfaces/MapAdaptor.h"
 #include <QtDBus/QtDBus>
@@ -124,10 +124,12 @@ public:
     int syntaxVersion;
 
     KCompletion listCompletion;
+
+    KoResourceManager* resourceManager;
 };
 
 
-Map::Map ( Doc* doc, int syntaxVersion)
+Map::Map(Doc* doc, int syntaxVersion)
         : QObject(doc),
         d(new Private)
 {
@@ -160,8 +162,18 @@ Map::Map ( Doc* doc, int syntaxVersion)
     d->defaultRowFormat = new RowFormat();
 
     QFont font(KoGlobal::defaultFont());
-    d->defaultRowFormat->setHeight(font.pointSizeF() + 3);
-    d->defaultColumnFormat->setWidth((font.pointSizeF() + 3) * 5);
+    d->defaultRowFormat->setHeight(font.pointSizeF() + 4);
+    d->defaultColumnFormat->setWidth((font.pointSizeF() + 4) * 5);
+
+    d->resourceManager = new KoResourceManager();
+    QVariant variant;
+    variant.setValue<void*>(this);
+    d->resourceManager->setResource(MapResourceId, variant);
+    KoShapeRegistry *registry = KoShapeRegistry::instance();
+    foreach (const QString &id, registry->keys()) {
+        KoShapeFactoryBase *shapeFactory = registry->value(id);
+        shapeFactory->newDocumentResourceManager(d->resourceManager);
+    }
 
     d->isLoading = false;
 
@@ -193,6 +205,13 @@ Map::Map ( Doc* doc, int syntaxVersion)
 
 Map::~Map()
 {
+    // we have to explicitly delete the Sheets, not let QObject take care of that
+    // as the sheet in its destructor expects the Map to still exist
+    qDeleteAll(d->lstSheets);
+    d->lstSheets.clear();
+
+    deleteLoadingInfo();
+
     delete d->bindingManager;
     delete d->databaseManager;
     delete d->dependencyManager;
@@ -209,6 +228,8 @@ Map::~Map()
 
     delete d->defaultColumnFormat;
     delete d->defaultRowFormat;
+
+    delete d->resourceManager;
     delete d;
 }
 
@@ -403,41 +424,6 @@ void Map::loadOdfSettings(KoOasisSettings &settings)
     }
 }
 
-void Map::saveOdfSettings(KoXmlWriter &settingsWriter)
-{
-    settingsWriter.addConfigItem("ViewId", QString::fromLatin1("View1"));
-    // Save visual info for the first view, such as active sheet and active cell
-    // It looks like a hack, but reopening a document creates only one view anyway (David)
-    View * view = d->doc->views().isEmpty() ? 0 : static_cast<View*>(d->doc->views().first());
-    if (view) { // no view if embedded document
-        // save current sheet selection before to save marker, otherwise current pos is not saved
-        view->saveCurrentSheetSelection();
-        //<config:config-item config:name="ActiveTable" config:type="string">Feuille1</config:config-item>
-        if(Sheet* sheet = view->activeSheet())
-            settingsWriter.addConfigItem("ActiveTable",  sheet->sheetName());
-    }
-
-    //<config:config-item-map-named config:name="Tables">
-    settingsWriter.startElement("config:config-item-map-named");
-    settingsWriter.addAttribute("config:name", "Tables");
-    foreach(Sheet* sheet, d->lstSheets) {
-        settingsWriter.startElement("config:config-item-map-entry");
-        settingsWriter.addAttribute("config:name", sheet->sheetName());
-        if (view) {
-            QPoint marker = view->markerFromSheet(sheet);
-            QPointF offset = view->offsetFromSheet(sheet);
-            settingsWriter.addConfigItem("CursorPositionX", marker.x() - 1);
-            settingsWriter.addConfigItem("CursorPositionY", marker.y() - 1);
-            settingsWriter.addConfigItem("xOffset", offset.x());
-            settingsWriter.addConfigItem("yOffset", offset.y());
-        }
-        sheet->saveOdfSettings(settingsWriter);
-        settingsWriter.endElement();
-    }
-    settingsWriter.endElement();
-}
-
-
 bool Map::saveOdf(KoXmlWriter & xmlWriter, KoShapeSavingContext & savingContext)
 {
     // Saving the custom cell styles including the default cell style.
@@ -459,7 +445,7 @@ bool Map::saveOdf(KoXmlWriter & xmlWriter, KoShapeSavingContext & savingContext)
     this->password(password);
     if (!password.isNull()) {
         xmlWriter.addAttribute("table:structure-protected", "true");
-        QByteArray str = KCodecs::base64Encode( password );
+        QByteArray str = KCodecs::base64Encode(password);
         // FIXME Stefan: see OpenDocument spec, ch. 17.3 Encryption
         xmlWriter.addAttribute("table:protection-key", QString(str.data()));
     }
@@ -496,17 +482,6 @@ QDomElement Map::save(QDomDocument& doc)
     spread.appendChild(s);
 
     QDomElement mymap = doc.createElement("map");
-    // Save visual info for the first view, such as active sheet and active cell
-    // It looks like a hack, but reopening a document creates only one view anyway (David)
-    View * view = d->doc->views().isEmpty() ? 0 : static_cast<View*>(d->doc->views().first());
-    if (view) { // no view if embedded document
-        Canvas * canvas = view->canvasWidget();
-        mymap.setAttribute("activeTable",  canvas->activeSheet()->sheetName());
-        mymap.setAttribute("markerColumn", view->selection()->marker().x());
-        mymap.setAttribute("markerRow",    view->selection()->marker().y());
-        mymap.setAttribute("xOffset",      canvas->xOffset());
-        mymap.setAttribute("yOffset",      canvas->yOffset());
-    }
 
     QByteArray password;
     this->password(password);
@@ -566,8 +541,8 @@ bool Map::loadOdf(const KoXmlElement& body, KoOdfLoadingContext& odfContext)
     OdfLoadingContext tableContext(odfContext);
     tableContext.validities = Validity::preloadValidities(body); // table:content-validations
 
-    // load text styles for rich-text content
-    KoShapeLoadingContext shapeContext(odfContext, 0); // TODO find a proper documentResourceManager somewhere.
+    // load text styles for rich-text content and TOS
+    KoShapeLoadingContext shapeContext(tableContext.odfContext, resourceManager());
     tableContext.shapeContext = &shapeContext;
     KoTextSharedLoadingData * sharedData = new KoTextSharedLoadingData();
     sharedData->loadOdfStyles(shapeContext, textStyleManager());
@@ -581,6 +556,11 @@ bool Map::loadOdf(const KoXmlElement& body, KoOdfLoadingContext& odfContext)
     }
     shapeContext.addSharedData(KOTEXT_SHARED_LOADING_ID, sharedData);
 
+    QVariant variant;
+    variant.setValue(textStyleManager());
+    resourceManager()->setResource(KoText::StyleManager, variant);
+
+
     // load default column style
     const KoXmlElement* defaultColumnStyle = odfContext.stylesReader().defaultStyle("table-column");
     if (defaultColumnStyle) {
@@ -653,7 +633,8 @@ bool Map::loadOdf(const KoXmlElement& body, KoOdfLoadingContext& odfContext)
 
     //pre-load auto styles
     QHash<QString, Conditions> conditionalStyles;
-    Styles autoStyles = d->styleManager->loadOdfAutoStyles(odfContext.stylesReader(), conditionalStyles);
+    Styles autoStyles = d->styleManager->loadOdfAutoStyles(odfContext.stylesReader(),
+                        conditionalStyles, parser());
 
     // load the sheet
     sheetNode = body.firstChild();
@@ -940,13 +921,12 @@ void Map::handleDamages(const QList<Damage*>& damages)
     QList<Damage*>::ConstIterator end(damages.end());
     for (QList<Damage*>::ConstIterator it = damages.begin(); it != end; ++it) {
         Damage* damage = *it;
-        if (!damage) continue;
 
         if (damage->type() == Damage::Cell) {
             CellDamage* cellDamage = static_cast<CellDamage*>(damage);
             kDebug(36007) << "Processing\t" << *cellDamage;
             Sheet* const damagedSheet = cellDamage->sheet();
-            const Region region = cellDamage->region();
+            const Region& region = cellDamage->region();
             const CellDamage::Changes changes = cellDamage->changes();
 
             // TODO Stefan: Detach the style cache from the CellView cache.
@@ -1030,4 +1010,9 @@ void Map::addCommand(QUndoCommand *command)
     emit commandAdded(command);
 }
 
+KoResourceManager* Map::resourceManager() const
+{
+    return d->resourceManager;
+}
+
 #include "Map.moc"
