@@ -35,13 +35,15 @@
 
 #include "CalculationSettings.h"
 #include "Cell.h"
+#include "Function.h"
+#include "FunctionDescription.h"
+#include "FunctionRepository.h"
 #include "Util.h"
-#include "ui/Editors.h"
+#include "ui/CellEditor.h"
 #include "Localization.h"
 #include "Map.h"
 #include "Selection.h"
 #include "Sheet.h"
-#include "Functions.h"
 
 #include <kcombobox.h>
 #include <kdebug.h>
@@ -59,7 +61,7 @@
 
 using namespace KSpread;
 
-FormulaDialog::FormulaDialog(QWidget* parent, Selection* selection, CellEditor* editor, const QString& formulaName)
+FormulaDialog::FormulaDialog(QWidget* parent, Selection* selection, CellEditorBase* editor, const QString& formulaName)
         : KDialog(parent)
 {
     setCaption(i18n("Function"));
@@ -76,11 +78,10 @@ FormulaDialog::FormulaDialog(QWidget* parent, Selection* selection, CellEditor*
     // Make sure that there is a cell editor running.
     if (cell.userInput().isEmpty())
         m_editor->setText("=");
+    else if (cell.userInput().at(0) != '=')
+        m_editor->setText('=' + cell.userInput());
     else
-        if (cell.userInput().at(0) != '=')
-            m_editor->setText('=' + cell.userInput());
-        else
-            m_editor->setText(cell.userInput());
+        m_editor->setText(cell.userInput());
 
     QWidget *page = new QWidget(this);
     setMainWidget(page);
@@ -230,7 +231,7 @@ FormulaDialog::FormulaDialog(QWidget* parent, Selection* selection, CellEditor*
     // Save the name of the active sheet.
     m_sheetName = m_selection->activeSheet()->sheetName();
     // Save the cells current text.
-    QString tmp_oldText = m_editor->text();
+    QString tmp_oldText = m_editor->toPlainText();
     // Position of the cell.
     m_column = m_selection->marker().x();
     m_row = m_selection->marker().y();
@@ -351,7 +352,7 @@ void FormulaDialog::slotOk()
             tmp = '=' + tmp;
         int pos = m_editor->cursorPosition() + tmp.length();
         m_editor->setText(tmp);
-        m_editor->setFocus();
+        m_editor->widget()->setFocus();
         m_editor->setCursorPosition(pos);
     }
 
@@ -374,7 +375,7 @@ void FormulaDialog::slotClose()
     if (m_editor != 0) {
         Q_ASSERT(m_editor);
         m_editor->setText(m_oldText);
-        m_editor->setFocus();
+        m_editor->widget()->setFocus();
     }
 
     m_selection->emitModified();
@@ -748,7 +749,7 @@ void FormulaDialog::slotActivated(const QString& category)
     functionsModel->setStringList(lst);
 
     QStringList upperList;
-    for (QStringList::Iterator it = lst.begin(); it != lst.end();++it)
+    for (QStringList::Iterator it = lst.begin(); it != lst.end(); ++it)
         upperList.append((*it).toUpper());
     listFunct.setItems(upperList);
 
