@@ -62,7 +62,6 @@
 
 #include "Cell.h"
 #include "Canvas.h"
-#include "Canvas_p.h"
 #include "Doc.h"
 #include "kspread_limits.h"
 #include "PrintSettings.h"
@@ -76,7 +75,6 @@
 #include "commands/DefinePrintRangeCommand.h"
 
 #include "ui/CellView.h"
-#include "ui/Editors.h"
 #include "ui/SheetView.h"
 
 using namespace KSpread;
@@ -84,14 +82,14 @@ using namespace KSpread;
 class CellTool::Private
 {
 public:
-    Canvas* canvas;
+    CanvasBase* canvas;
 };
 
 CellTool::CellTool(KoCanvasBase* canvas)
         : CellToolBase(canvas)
         , d(new Private)
 {
-    d->canvas = static_cast<Canvas*>(canvas);
+    d->canvas = static_cast<CanvasBase*>(canvas);
 
     KAction* action = 0;
 
@@ -159,7 +157,7 @@ int CellTool::maxRow() const
 
 SheetView* CellTool::sheetView(const Sheet* sheet) const
 {
-    return d->canvas->view()->sheetView(sheet);
+    return d->canvas->sheetView(sheet);
 }
 
 void CellTool::definePrintRange()
@@ -167,7 +165,7 @@ void CellTool::definePrintRange()
     DefinePrintRangeCommand* command = new DefinePrintRangeCommand();
     command->setSheet(selection()->activeSheet());
     command->add(*selection());
-    d->canvas->view()->doc()->addCommand(command);
+    d->canvas->doc()->addCommand(command);
 }
 
 #include "CellTool.moc"
