@@ -10,7 +10,7 @@
    Copyright 1999-2000 Simon Hausmann <hausmann@kde.org>
    Copyright 1999 David Faure <faure@kde.org>
    Copyright 1998-2000 Torben Weis <weis@kde.org>
-
+   
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
@@ -176,6 +176,7 @@ public:
 
     // reimplemented; paints the thumbnail
     virtual void paintContent(QPainter & painter, const QRect & rect);
+    virtual void paintContent(QPainter & painter, const QRect & rect, Sheet* sheet);
 
     void initConfig();
     void saveConfig();
@@ -199,6 +200,7 @@ public:
      */
     void updateAllViews();
 
+
 public Q_SLOTS:
     virtual void initEmpty();
 
@@ -212,8 +214,11 @@ protected Q_SLOTS:
     virtual void openTemplate(const KUrl& url);
 
 protected:
+
     KoView* createViewInstance(QWidget* parent);
 
+    QGraphicsItem *createCanvasItem();
+
     /**
      * @reimp Overloaded function of KoDocument.
      */
