@@ -22,37 +22,33 @@
 
 #include <QStringList>
 
-#include <KoShapeFactory.h>
+#include <KoShapeFactoryBase.h>
 
 class KoShape;
-class KoXmlElement;
+#include "KoXmlReaderForward.h"
+
+#define MapResourceId 65227211
 
 class TableShapePlugin : public QObject
 {
     Q_OBJECT
 public:
 
-    TableShapePlugin( QObject * parent,  const QStringList & );
+    TableShapePlugin(QObject * parent,  const QStringList &);
     ~TableShapePlugin() {}
 };
 
-class TableShapeFactory : public KoShapeFactory
+class TableShapeFactory : public KoShapeFactoryBase
 {
     Q_OBJECT
 public:
-    TableShapeFactory( QObject* parent );
+    TableShapeFactory(QObject* parent);
     ~TableShapeFactory();
 
-    virtual void populateDataCenterMap(QMap<QString, KoDataCenter*> &dataCenterMap);
+    virtual void newDocumentResourceManager(KoResourceManager *manager);
     virtual bool supports(const KoXmlElement &element) const;
 
-protected:
-    virtual KoShape* createDefaultShape() const;
-    virtual KoShape* createShape(const KoProperties* params) const;
-
-private:
-    class Private;
-    Private * const d;
+    virtual KoShape *createDefaultShape(KoResourceManager *documentResources = 0) const;
 };
 
 #endif // KSPREAD_TABLE_SHAPE_FACTORY
