@@ -26,6 +26,7 @@
 #include "KWPage.h"
 #include "KWCopyShape.h"
 #include "KWDocument.h"
+#include "KWPageBackground.h"
 
 #include <KoShapeRegistry.h>
 #include <KoShapeFactoryBase.h>
@@ -62,6 +63,14 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
     allHFTypes.append(KWord::OddPagesFooterTextFrameSet);
     allHFTypes.append(KWord::EvenPagesFooterTextFrameSet);
 
+    // create page background
+    KWTextFrameSet *fs = getOrCreate(KWord::PageBackgroundFrameSet, page);
+    if (!hasFrameOn(fs, pageNumber)) {
+        KoShape *shape = new KWPageBackground();
+        shape->setSize(QSizeF(page.width(), page.height()));
+        new KWFrame(shape, fs);
+    }
+
     // create headers & footers
     KWord::TextFrameSetType origin;
     if (shouldHaveHeaderOrFooter(pageNumber, true, &origin)) {
@@ -86,8 +95,31 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
         }
     }
 
+    // create main text frame. All columns of them.
+    if (page.pageStyle().hasMainTextFrame()) {
+        int columns = page.pageStyle().columns().columns;
+        KWTextFrameSet *fs = getOrCreate(KWord::MainTextFrameSet, page);
+        QRectF rect(QPointF(0, page.offsetInDocument()),
+                    QSizeF(page.width(), page.height()));
+        if (page.pageSide() == KWPage::PageSpread)
+            rect.setWidth(rect.width() / 2);
+        foreach (KWFrame *frame, framesInPage(rect)) {
+            if (frame->frameSet() == fs) {
+                columns--;
+                if (columns < 0) {
+                    fs->removeFrame(frame);
+                    delete frame;
+                }
+            }
+        }
+        while (columns > 0) {
+            new KWTextFrame(createTextShape(page), fs);
+            columns--;
+        }
+    }
+
     if (page.pageSide() == KWPage::PageSpread) {
-        // inline helper method
+        // inline helper class
         class PageSpreadShapeFactory
         {
         public:
@@ -137,29 +169,6 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
         }
     }
 
-    // create main text frame. All columns of them.
-    if (page.pageStyle().hasMainTextFrame()) {
-        int columns = page.pageStyle().columns().columns;
-        KWTextFrameSet *fs = getOrCreate(KWord::MainTextFrameSet, page);
-        QRectF rect(QPointF(0, page.offsetInDocument()),
-                    QSizeF(page.width(), page.height()));
-        if (page.pageSide() == KWPage::PageSpread)
-            rect.setWidth(rect.width() / 2);
-        foreach (KWFrame *frame, framesInPage(rect)) {
-            if (frame->frameSet() == fs) {
-                columns--;
-                if (columns < 0) {
-                    fs->removeFrame(frame);
-                    delete frame;
-                }
-            }
-        }
-        while (columns > 0) {
-            new KWTextFrame(createTextShape(page), fs);
-            columns--;
-        }
-    }
-
     bool odd = false; // an odd number of pages back, so frameOnBothSheets matters
     for (int i = pageNumber - 2; i < pageNumber; i++) {
         if (i < m_pageManager->begin().pageNumber()) {
@@ -212,15 +221,15 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
     Q_ASSERT(page.isValid());
 
     /* +-----------------+
-       |  0              | <- m_pageStyle->pageLayout()->topMargin + d:o->topPadding
+       |  0              | <- pageStyle->pageLayout()->topMargin + layout->topPadding
        |  1  [ header ]  |
-       |  2              | <- m_pageStyle->headerDistance()
+       |  2              | <- pageStyle->headerDistance()
        |  3  [ maintxt ] |
-       |  4              | <- m_pageStyle->endNoteDistance()
+       |  4              | <- pageStyle->endNoteDistance()
        |  5  [ endnote ] |
-       |  6              | <- m_pageStyle->footerDistance()
+       |  6              | <- pageStyle->footerDistance()
        |  7  [ footer ]  |
-       |  8              | <- m_pageStyle->pageLayout()->bottomMargin + d:o->bottomPadding
+       |  8              | <- pageStyle->pageLayout()->bottomMargin + layout->bottomPadding
        +-----------------+ */
 
     // Create some data structures used for the layouting of the frames later
@@ -242,23 +251,23 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
     qreal left = 0, width = page.width();
     if (page.pageSide() == KWPage::PageSpread) {
         width /= 2;
-        if (page.pageNumber() != pageNumber) { // doing the 'right' one
+        layout.leftMargin = page.pageEdgeMargin();
+        layout.rightMargin = page.marginClosestBinding();
+        if (page.pageNumber() != pageNumber) { // doing the 'right' part
             left = width;
-            qreal x = layout.leftMargin; // swap margins
-            layout.leftMargin = layout.rightMargin;
-            layout.rightMargin = x;
-            x = layout.leftPadding; // swap paddings
-            layout.leftPadding = layout.rightPadding;
-            layout.rightPadding = x;
+            qSwap(layout.leftMargin, layout.rightMargin);
+            qSwap(layout.leftPadding, layout.rightPadding);
         }
     }
     qreal textWidth = width - layout.leftMargin - layout.rightMargin
                             - layout.leftPadding - layout.rightPadding;
 
     KWPageStyle pageStyle = page.pageStyle();
-    const int columns = pageStyle.hasMainTextFrame() ? pageStyle.columns().columns * (page.pageSide() == KWPage::PageSpread ? 2 : 1) : 0;
+    const int columns = pageStyle.hasMainTextFrame() ? pageStyle.columns().columns : 0;
     int columnsCount = columns;
-    KWTextFrame **main, *footer = 0, *endnote = 0, *header = 0;
+    KWTextFrame **main;
+    KWTextFrame *footer = 0, *endnote = 0, *header = 0;
+    KWFrame *pageBackground = 0;
     main = new KWTextFrame*[columnsCount];
     if (columns > 0)
         main[0] = 0;
@@ -303,20 +312,25 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
             requestedHeight[3] = -1; // rest
             break;
         }
-        // TODO end + foot note frameset
+        case KWord::PageBackgroundFrameSet:
+            pageBackground = static_cast<KWFrame *>(frame);
+            break;
+        // TODO endnote frameset
         default:;
         }
     }
     if (minZIndex < INT_MAX) {
         --minZIndex;
+        if (endnote)
+            endnote->shape()->setZIndex(minZIndex--);
         for (int i = 0; i < columns; ++i)
             main[i]->shape()->setZIndex(minZIndex);
         if (footer)
-            footer->shape()->setZIndex(minZIndex);
-        if (endnote)
-            endnote->shape()->setZIndex(minZIndex);
+            footer->shape()->setZIndex(--minZIndex);
         if (header)
-            header->shape()->setZIndex(minZIndex);
+            header->shape()->setZIndex(--minZIndex);
+        if (pageBackground)
+            pageBackground->shape()->setZIndex(--minZIndex);
     }
 
     // spread space across items.
@@ -396,8 +410,13 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
             QPointF(left + layout.leftMargin + layout.leftPadding, resultingPositions[7]));
         footer->shape()->setSize(QSizeF(textWidth, resultingPositions[8] - resultingPositions[7]));
     }
+    if (pageBackground) {
+        pageBackground->shape()->setPosition(
+            QPointF(left, page.offsetInDocument()));
+        pageBackground->shape()->setSize(QSizeF(width, page.height()));
+    }
     delete [] main;
-// TODO footnotes, endnotes
+// TODO endnotes
 }
 
 bool KWFrameLayout::shouldHaveHeaderOrFooter(int pageNumber, bool header, KWord::TextFrameSetType *origin)
@@ -454,6 +473,9 @@ KWTextFrameSet *KWFrameLayout::getOrCreate(KWord::TextFrameSetType type, const K
     case KWord::EvenPagesFooterTextFrameSet:
         answer = &frameSets.evenFooters;
         break;
+    case KWord::PageBackgroundFrameSet:
+        answer = &frameSets.pageBackground;
+        break;
     case KWord::MainTextFrameSet:
         answer = &m_maintext;
         break;
@@ -501,6 +523,9 @@ void KWFrameLayout::setup()
         case KWord::EvenPagesFooterTextFrameSet:
             frameSets.evenFooters = tfs;
             break;
+        case KWord::PageBackgroundFrameSet:
+            frameSets.pageBackground = tfs;
+            break;
         case KWord::MainTextFrameSet:
             m_maintext = tfs;
             disconnect(tfs, SIGNAL(frameRemoved(KWFrame*)), this, SLOT(mainframeRemoved(KWFrame*)));
