@@ -268,7 +268,6 @@ void KWTextDocumentLayout::layout()
             void tryFit() {
                 const qreal leftIndent = m_state->x();
                 const qreal width = m_state->width();
-                const qreal rightIndent = m_state->shape->size().width() - width - leftIndent;
                 QRectF rect(leftIndent, m_state->y(), width, 1.);
                 line.setLineWidth(rect.width());
                 if (rect.width() <= 0. || line.textLength() == 0) {
@@ -285,7 +284,7 @@ void KWTextDocumentLayout::layout()
                 qreal eligableTop = rect.top();
                 while (true) {
                     if (m_state->numColumns() > 0) {
-                        line.setNumColumns(m_state->numColumns());
+                        line.setNumColumns(m_state->numColumns(),rect.width());
                         line.setPosition(QPointF(line.x(), rect.y()));
                     } else {
                         qreal x = rect.x();
@@ -294,9 +293,6 @@ void KWTextDocumentLayout::layout()
                             x += leftIndent;
                             effectiveLineWidth -= leftIndent;
                         }
-                        if (leftIndent + width > rect.right()) // limit moved the right edge, keep the indent.
-                            effectiveLineWidth = rect.width() - rightIndent;
-
                         line.setLineWidth(effectiveLineWidth);
                         line.setPosition(QPointF(x, rect.y()));
                     }
@@ -384,7 +380,7 @@ void KWTextDocumentLayout::layout()
                         }
                         if (isChild)
                             continue;
-                        QMatrix matrix = (frame->outlineShape()
+                        QTransform matrix = (frame->outlineShape()
                                 ? frame->outlineShape()
                                 : frame->shape())->absoluteTransformation(0);
                         matrix = matrix * currentShape->absoluteTransformation(0).inverted();
@@ -418,7 +414,7 @@ void KWTextDocumentLayout::layout()
                 foreach (Outline *outline, outlines) {
                     if (outline->shape() == strategy->anchoredShape()) {
                         ADEBUG << "  refreshing outline";
-                        QMatrix matrix = strategy->anchoredShape()->absoluteTransformation(0);
+                        QTransform matrix = strategy->anchoredShape()->absoluteTransformation(0);
                         matrix = matrix * currentShape->absoluteTransformation(0).inverted();
                         matrix.translate(0, m_state->documentOffsetInShape());
                         outline->changeMatrix(matrix);
@@ -444,14 +440,20 @@ void KWTextDocumentLayout::layout()
         foreach (KWAnchorStrategy *strategy, m_newAnchors) {
             ADEBUG << "  migrating strategy!";
             if (strategy->anchoredShape()) {
-                QMatrix matrix = strategy->anchoredShape()->absoluteTransformation(0);
-                matrix = matrix * currentShape->absoluteTransformation(0).inverted();
-                matrix.translate(0, m_state->documentOffsetInShape());
-                outlines.append(new Outline(strategy->anchoredShape(), matrix));
-
-                // if the anchor occupies the first character of our block, create one line for it.
+                KWFrame *frame = dynamic_cast<KWFrame*>(strategy->anchoredShape()->applicationData());
+                if (! frame || frame->textRunAround() != KWord::RunThrough) {
+                    QTransform matrix = strategy->anchoredShape()->absoluteTransformation(0);
+                    matrix = matrix * currentShape->absoluteTransformation(0).inverted();
+                    matrix.translate(0, m_state->documentOffsetInShape());
+                    outlines.append(new Outline(strategy->anchoredShape(), matrix));
+                 }
+                // if the anchor occupies the first character of our block,
+                // create one line for it. This can theoretically change currentshape=0
+                // midway through the loop causing crashes. However the textshape makes
+                // sure that a line like this always have height so infinite that it
+                // doesn't happen.
                 const int cursorPosition = m_state->cursorPosition();
-                if (cursorPosition == startOfBlockText && strategy->anchor()->positionInDocument() == cursorPosition) {
+                if (cursorPosition == startOfBlockText && strategy->anchor()->positionInDocument() == cursorPosition && !strategy->anchor()->isPositionedInline()) {
                     ADEBUG << "   creating line for anchor";
                     QTextLine line = m_state->layout->createLine();
                     line.setNumColumns(1);
