@@ -23,6 +23,7 @@
 #include "KoConnectionShape_p.h"
 
 #include "KoViewConverter.h"
+#include "KoShapeContainer.h"
 #include "KoShapeLoadingContext.h"
 #include "KoShapeSavingContext.h"
 #include "KoConnectionShapeLoadingUpdater.h"
@@ -60,7 +61,7 @@ QPointF KoConnectionShapePrivate::escapeDirection(int handleId) const
     Q_Q(const KoConnectionShape);
     QPointF direction;
     if (handleConnected(handleId)) {
-        QMatrix absoluteMatrix = q->absoluteTransformation(0);
+        QTransform absoluteMatrix = q->absoluteTransformation(0);
         QPointF handlePoint = absoluteMatrix.map(handles[handleId]);
         QPointF centerPoint;
         if (handleId == StartHandle)
@@ -82,7 +83,7 @@ QPointF KoConnectionShapePrivate::escapeDirection(int handleId) const
             direction = QPointF(1.0, 0.0);
 
         // transform escape direction by using our own transformation matrix
-        QMatrix invMatrix = absoluteMatrix.inverted();
+        QTransform invMatrix = absoluteMatrix.inverted();
         direction = invMatrix.map(direction) - invMatrix.map(QPointF());
         direction /= sqrt(direction.x() * direction.x() + direction.y() * direction.y());
     }
@@ -311,6 +312,8 @@ void KoConnectionShape::saveOdf(KoShapeSavingContext & context) const
 
     saveOdfCommonChildElements(context);
 
+    if (parent())
+        parent()->saveOdfChildElements(context);
     context.xmlWriter().endElement();
 }
 
@@ -387,7 +390,12 @@ bool KoConnectionShape::loadOdf(const KoXmlElement & element, KoShapeLoadingCont
             // if there is none, use the bounding rectangle of the parsed path
             viewBox = outline().boundingRect();
         }
-        QMatrix viewMatrix;
+        // convert path to viewbox coordinates to have a bounding rect of (0,0 1x1)
+        // which can later be fitted back into the target rect once we have all
+        // the required information
+        QTransform viewMatrix;
+        viewMatrix.scale(viewBox.width() ? static_cast<qreal>(1.0) / viewBox.width() : 1.0,
+                         viewBox.height() ? static_cast<qreal>(1.0) / viewBox.height() : 1.0);
         viewMatrix.translate(-viewBox.left(), -viewBox.top());
         d->map(viewMatrix);
 
@@ -429,24 +437,26 @@ void KoConnectionShape::finishLoadingConnection()
                 p2 = d->handles[EndHandle];
             }
 
-            QPointF bgp = m_subpaths.first()->first()->point();
-            QPointF egp = m_subpaths.last()->last()->point();
-            qreal x1 = bgp.x(), y1 = bgp.y(), x2 = egp.x(), y2 = egp.y(),
-                  kX = (p2.x()-p1.x())/(egp.x()-bgp.x()),
-                  kY = (p2.y()-p1.y())/(egp.y()-bgp.y()),
-                  width = outline().boundingRect().width(),
-                  height = outline().boundingRect().height();
+            QPointF relativeBegin = m_subpaths.first()->first()->point();
+            QPointF relativeEnd = m_subpaths.last()->last()->point();
 
-            p1.setY(p1.y()-y1*kY);
-            p1.setX(p1.x()-x1*kX);
-            p2.setY(p2.y()+(width-y2)*kY);
-            p2.setX(p2.x()+(height-x2)*kX);
+            QPointF diffRelative(relativeBegin - relativeEnd);
+            QPointF diffAbsolute(p1 - p2);
+
+            qreal factorX = diffRelative.x() ? diffAbsolute.x() / diffRelative.x(): 1.0;
+            qreal factorY = diffRelative.y() ? diffAbsolute.y() / diffRelative.y(): 1.0;
+
+            p1.setX(p1.x() - relativeBegin.x() * factorX);
+            p1.setY(p1.y() - relativeBegin.y() * factorY);
+            p2.setX(p2.x() + (1 - relativeEnd.x()) * factorX);
+            p2.setY(p2.y() + (1 - relativeEnd.y()) * factorY);
 
             QRectF targetRect = QRectF(p1, p2).normalized();
+
             // transform the normalized coordinates back to our target rectangle
-            QMatrix viewMatrix;
+            QTransform viewMatrix;
             viewMatrix.translate(targetRect.x(), targetRect.y());
-            viewMatrix.scale(kX, kY);
+            viewMatrix.scale(targetRect.width(), targetRect.height());
             d->map(viewMatrix);
 
             // pretend we are during a forced update, so normalize()
