@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
  * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
  * Copyright (C) 2006-2008 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
+ * Copyright (C) 2007,2009 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -30,6 +30,8 @@
 #include <KoGenStyles.h>
 #include <KoOdfGraphicStyles.h>
 
+#include <math.h>
+
 class KoLineBorder::Private
 {
 public:
@@ -42,10 +44,12 @@ KoLineBorder::KoLineBorder()
         : d(new Private())
 {
     d->color = QColor(Qt::black);
-    d->pen.setWidthF(0.0);
+    // we are not rendering stroke with zero width anymore
+    // so lets use a default width of 1.0
+    d->pen.setWidthF(1.0);
 }
 
-KoLineBorder::KoLineBorder(const KoLineBorder & other)
+KoLineBorder::KoLineBorder(const KoLineBorder &other)
         : KoShapeBorderModel(), d(new Private())
 {
     d->color = other.d->color;
@@ -66,7 +70,7 @@ KoLineBorder::~KoLineBorder()
     delete d;
 }
 
-KoLineBorder& KoLineBorder::operator = (const KoLineBorder & rhs)
+KoLineBorder& KoLineBorder::operator = (const KoLineBorder &rhs)
 {
     if (this == &rhs)
         return *this;
@@ -78,32 +82,41 @@ KoLineBorder& KoLineBorder::operator = (const KoLineBorder & rhs)
     return *this;
 }
 
-void KoLineBorder::fillStyle(KoGenStyle &style, KoShapeSavingContext &context)
+void KoLineBorder::fillStyle(KoGenStyle &style, KoShapeSavingContext &context) const
 {
     QPen pen = d->pen;
-    pen.setColor(d->color);
-    KoOdfGraphicStyles::saveOasisStrokeStyle(style, context.mainStyles(), pen);
+    if (d->brush.gradient())
+        pen.setBrush(d->brush);
+    else
+        pen.setColor(d->color);
+    KoOdfGraphicStyles::saveOdfStrokeStyle(style, context.mainStyles(), pen);
 }
 
-void KoLineBorder::borderInsets(const KoShape *shape, KoInsets &insets)
+void KoLineBorder::borderInsets(const KoShape *shape, KoInsets &insets) const
 {
     Q_UNUSED(shape);
     qreal lineWidth = d->pen.widthF();
     if (lineWidth < 0)
         lineWidth = 1;
-    lineWidth /= 2; // since we draw a line half inside, and half outside the object.
+    lineWidth *= 0.5; // since we draw a line half inside, and half outside the object.
+
+    // if we have square cap, we need a little more space
+    // -> sqrt( (0.5*penWidth)^2 + (0.5*penWidth)^2 )
+    if (capStyle() == Qt::SquareCap)
+        lineWidth *= M_SQRT2;
+
     insets.top = lineWidth;
     insets.bottom = lineWidth;
     insets.left = lineWidth;
     insets.right = lineWidth;
 }
 
-bool KoLineBorder::hasTransparency()
+bool KoLineBorder::hasTransparency() const
 {
     return d->color.alpha() > 0;
 }
 
-void KoLineBorder::paintBorder(KoShape *shape, QPainter &painter, const KoViewConverter &converter)
+void KoLineBorder::paint(KoShape *shape, QPainter &painter, const KoViewConverter &converter)
 {
     KoShape::applyConversion(painter, converter);
 
@@ -114,7 +127,20 @@ void KoLineBorder::paintBorder(KoShape *shape, QPainter &painter, const KoViewCo
     else
         pen.setColor(d->color);
 
-    painter.strokePath(shape->outline(), pen);
+    if (!pen.isCosmetic())
+        painter.strokePath(shape->outline(), pen);
+}
+
+void KoLineBorder::paint(KoShape *shape, QPainter &painter, const KoViewConverter &converter, const QColor &color )
+{
+    KoShape::applyConversion(painter, converter);
+
+    QPen pen = d->pen;
+    pen.setColor(color);
+
+    if (!pen.isCosmetic()) {
+        painter.strokePath(shape->outline(), pen);
+    }
 }
 
 void KoLineBorder::setCapStyle(Qt::PenCapStyle style)
@@ -195,7 +221,7 @@ qreal KoLineBorder::dashOffset() const
     return d->pen.dashOffset();
 }
 
-void KoLineBorder::setLineBrush(const QBrush & brush)
+void KoLineBorder::setLineBrush(const QBrush &brush)
 {
     d->brush = brush;
 }
