@@ -30,7 +30,6 @@
 #include "KoTextLocator.h"
 #include "KoTextOdfSaveHelper.h"
 #include "KoTextPaste.h"
-#include "KoUndoStack.h"
 #include "changetracker/KoChangeTracker.h"
 #include "changetracker/KoChangeTrackerElement.h"
 #include "changetracker/KoDeleteChangeMarker.h"
@@ -40,6 +39,7 @@
 #include "styles/KoTableCellStyle.h"
 
 #include <KLocale>
+#include <KUndoStack>
 
 #include <QApplication>
 #include <QFontDatabase>
@@ -107,18 +107,20 @@ void KoTextEditor::Private::documentCommandAdded()
         {}
 
         void undo() {
-            if (m_document.isNull())
+            QTextDocument *doc = m_document.data();
+            if (doc == 0)
                 return;
-            m_document->undo(KoTextDocument(m_document).textEditor()->cursor());
+            doc->undo(KoTextDocument(doc).textEditor()->cursor());
         }
 
         void redo() {
-            if (m_document.isNull())
+            QTextDocument *doc = m_document.data();
+            if (doc == 0)
                 return;
-            m_document->redo(KoTextDocument(m_document).textEditor()->cursor());
+            doc->redo(KoTextDocument(doc).textEditor()->cursor());
         }
 
-        QPointer<QTextDocument> m_document;
+        QWeakPointer<QTextDocument> m_document;
     };
 
     //kDebug() << "editor state: " << editorState << " headcommand: " << headCommand;
@@ -213,7 +215,6 @@ void KoTextEditor::Private::deleteSelection()
 #ifndef NDEBUG
     KoTextDocumentLayout *layout = qobject_cast<KoTextDocumentLayout*>(document->documentLayout());
     Q_ASSERT(layout);
-    Q_ASSERT(layout->inlineTextObjectManager());
 #endif
     QTextCursor delText = QTextCursor(caret);
     if (!delText.hasSelection())
@@ -318,24 +319,28 @@ void KoTextEditor::addCommand(QUndoCommand *command)
     d->updateState(KoTextEditor::Private::Custom, (!command->text().isEmpty())?command->text():i18n("Text"));
     //kDebug() << "will push the custom command: " << command->text();
     d->headCommand = command;
-    KoTextDocument(d->document).undoStack()->push(command);
+    QUndoStack *stack = KoTextDocument(d->document).undoStack();
+    if (stack)
+        stack->push(command);
+    else
+        command->redo();
     //kDebug() << "custom command pushed";
     d->updateState(KoTextEditor::Private::NoOp);
 }
 
 void KoTextEditor::registerTrackedChange(QTextCursor &selection, KoGenChange::Type changeType, QString title, QTextFormat& format, QTextFormat& prevFormat, bool applyToWholeBlock)
 {
+    if (!KoTextDocument(d->document).changeTracker() || !KoTextDocument(d->document).changeTracker()->recordChanges()) {
+        d->clearCharFormatProperty(KoCharacterStyle::ChangeTrackerId);
+        return;
+    }
 #ifndef NDEBUG
     KoTextDocumentLayout *layout = qobject_cast<KoTextDocumentLayout*>(d->document->documentLayout());
     Q_ASSERT(layout);
     Q_ASSERT(layout->inlineTextObjectManager());
 #endif
-    if (!KoTextDocument(d->document).changeTracker() || !KoTextDocument(d->document).changeTracker()->recordChanges()) {
-        d->clearCharFormatProperty(KoCharacterStyle::ChangeTrackerId);
-        return;
-    }
 
-    if (changeType != KoGenChange::deleteChange) {
+    if (changeType != KoGenChange::DeleteChange) {
         //first check if there already is an identical change registered just before or just after the selection. If so, merge appropriatly.
         //TODO implement for format change. handle the prevFormat/newFormat check.
         QTextCursor checker = QTextCursor(selection);
@@ -354,15 +359,15 @@ void KoTextEditor::registerTrackedChange(QTextCursor &selection, KoGenChange::Ty
         changeId = (idBefore)?idBefore:idAfter;
 
         switch (changeType) {//TODO: this whole thing actually needs to be done like a visitor. If the selection contains several change regions, the parenting needs to be individualised.
-            case KoGenChange::insertChange:
+            case KoGenChange::InsertChange:
                 if (!changeId)
                     changeId = KoTextDocument(d->document).changeTracker()->getInsertChangeId(title, selection.charFormat().property( KoCharacterStyle::ChangeTrackerId ).toInt());
                 break;
-            case KoGenChange::formatChange:
+            case KoGenChange::FormatChange:
                 if (!changeId)
                     changeId = KoTextDocument(d->document).changeTracker()->getFormatChangeId(title, format, prevFormat, d->caret.charFormat().property( KoCharacterStyle::ChangeTrackerId ).toInt());
                 break;
-            case KoGenChange::deleteChange:
+            case KoGenChange::DeleteChange:
                 //this should never be the case
                 break;
         }
@@ -388,7 +393,7 @@ void KoTextEditor::bold(bool bold)
     format.setFontWeight(bold ? QFont::Bold : QFont::Normal);
 
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Bold"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Bold"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -400,7 +405,7 @@ void KoTextEditor::italic(bool italic)
     format.setFontItalic(italic);
 
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Italic"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Italic"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -418,7 +423,7 @@ void KoTextEditor::underline(bool underline)
     }
 
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Underline"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Underline"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -435,7 +440,7 @@ void KoTextEditor::strikeOut(bool strikeout)
         format.setProperty(KoCharacterStyle::StrikeOutStyle, KoCharacterStyle::NoLineStyle);
     }
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Strike Out"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Strike Out"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -470,7 +475,7 @@ void KoTextEditor::setVerticalTextAlignment(Qt::Alignment align)
     QTextCharFormat format;
     format.setVerticalAlignment(charAlign);
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Vertical Alignment"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Vertical Alignment"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -557,7 +562,7 @@ void KoTextEditor::setFontFamily(const QString &font)
     QTextCharFormat format;
     format.setFontFamily(font);
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Font"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Font"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -568,7 +573,7 @@ void KoTextEditor::setFontSize(int size)
     QTextCharFormat format;
     format.setFontPointSize(size);
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Font Size"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Font Size"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -579,7 +584,7 @@ void KoTextEditor::setTextBackgroundColor(const QColor &color)
     QTextCharFormat format;
     format.setBackground(QBrush(color));
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Background Color"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Background Color"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -590,7 +595,7 @@ void KoTextEditor::setTextColor(const QColor &color)
     QTextCharFormat format;
     format.setForeground(QBrush(color));
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Text Color"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Text Color"), format, prevFormat, false);
     d->caret.mergeCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -602,7 +607,7 @@ void KoTextEditor::setStyle(KoCharacterStyle *style)
     QTextCharFormat format;
     style->applyStyle(format);
     QTextCharFormat prevFormat(d->caret.charFormat());
-    registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set Character Style"), format, prevFormat, false);
+    registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set Character Style"), format, prevFormat, false);
     d->caret.setCharFormat(format);
     d->updateState(KoTextEditor::Private::NoOp);
 }
@@ -635,7 +640,7 @@ void KoTextEditor::setDefaultFormat()
         QTextCharFormat format;
         defaultCharStyle->applyStyle(format);
         QTextCharFormat prevFormat(d->caret.charFormat());
-        registerTrackedChange(d->caret, KoGenChange::formatChange, i18n("Set default format"), format, prevFormat, false);
+        registerTrackedChange(d->caret, KoGenChange::FormatChange, i18n("Set default format"), format, prevFormat, false);
         d->caret.setCharFormat(format);
     }
     d->updateState(KoTextEditor::Private::NoOp);
@@ -724,7 +729,7 @@ void KoTextEditor::insertFrameBreak()
     //               bf.pageBreakPolicy() != QTextFormat::PageBreak_Auto) // end of parag or already a pagebreak
     newLine();
     bf = d->caret.blockFormat();
-    bf.setProperty(KoParagraphStyle::BreakBefore, true);
+    bf.setPageBreakPolicy(QTextFormat::PageBreak_AlwaysBefore); // TODO we should create an autostyle instead
     d->caret.setBlockFormat(bf);
     //}
     d->updateState(KoTextEditor::Private::NoOp);
@@ -897,7 +902,7 @@ void KoTextEditor::insertText(const QString &text)
     if (!d->caret.hasSelection() && d->caret.charFormat().hasProperty(KoCharacterStyle::InlineInstanceId))
         d->clearCharFormatProperty(KoCharacterStyle::InlineInstanceId);
     QTextCharFormat format = d->caret.charFormat();
-    registerTrackedChange(d->caret, KoGenChange::insertChange, i18n("Key Press"), format, format, false);
+    registerTrackedChange(d->caret, KoGenChange::InsertChange, i18n("Key Press"), format, format, false);
     int blockNumber = d->caret.blockNumber();
     d->caret.insertText(text);
 
@@ -967,7 +972,6 @@ void KoTextEditor::newLine()
     bf.clearProperty(KoParagraphStyle::UnnumberedListItem);
     bf.clearProperty(KoParagraphStyle::IsListHeader);
     bf.clearProperty(KoParagraphStyle::MasterPageName);
-    bf.clearProperty(KoParagraphStyle::BreakBefore);
     d->caret.setBlockFormat(bf);
     if (nextStyle) {
         QTextBlock block = d->caret.block();
@@ -1002,13 +1006,13 @@ int KoTextEditor::position() const
 
 void KoTextEditor::removeSelectedText()
 {
-//TODO
+    d->caret.removeSelectedText();
 }
 
 void KoTextEditor::select(QTextCursor::SelectionType selection)
 {
     //TODO add selection of previous/next char, and option about hasSelection
-    d->caret.select (selection);
+    d->caret.select(selection);
 }
 
 QString KoTextEditor::selectedText() const
@@ -1071,12 +1075,27 @@ bool KoTextEditor::isBidiDocument() const
 
 void KoTextEditor::beginEditBlock()
 {
+    d->updateState(KoTextEditor::Private::Custom);
     d->caret.beginEditBlock();
 }
 
 void KoTextEditor::endEditBlock()
 {
     d->caret.endEditBlock();
+    d->updateState(KoTextEditor::Private::NoOp);
+}
+
+void KoTextEditor::finishedLoading()
+{
+    QTextBlock block = d->document->begin();
+    while (!d->isBidiDocument && block.isValid()) {
+        bool rtl = isRightToLeft(block.text());
+        if ((QApplication::isLeftToRight() && rtl) || (QApplication::isRightToLeft() && !rtl)) {
+            d->isBidiDocument = true;
+            emit isBidiUpdated();
+        }
+        block = block.next();
+    }
 }
 
 #include <KoTextEditor.moc>
