@@ -122,13 +122,15 @@ public:
 
     KoDocumentRdfBase *rdfData;
 
+    KoShape *shape;
+
     int loadSpanLevel;
     int loadSpanInitialPos;
     QStack<int> changeStack;
     QMap<QString, int> changeTransTable;
     QMap<QString, KoXmlElement> deleteChangeTable;
 
-    explicit Private(KoShapeLoadingContext &context)
+    explicit Private(KoShapeLoadingContext &context, KoShape *s)
             : context(context),
             textSharedData(0),
             // stylesDotXml says from where the office:automatic-styles are to be picked from:
@@ -144,8 +146,11 @@ public:
             currentListLevel(1),
             styleManager(0),
             changeTracker(0),
+            rdfData(0),
+            shape(s),
             loadSpanLevel(0),
-            loadSpanInitialPos(0) {
+            loadSpanInitialPos(0)
+    {
         dt.start();
     }
 
@@ -235,9 +240,9 @@ KoList *KoTextLoader::Private::list(const QTextDocument *document, KoListStyle *
 
 /////////////KoTextLoader
 
-KoTextLoader::KoTextLoader(KoShapeLoadingContext &context, KoDocumentRdfBase *rdfData)
+KoTextLoader::KoTextLoader(KoShapeLoadingContext &context, KoDocumentRdfBase *rdfData, KoShape *shape)
         : QObject()
-        , d(new Private(context))
+        , d(new Private(context, shape))
 {
     d->rdfData = rdfData;
     KoSharedLoadingData *sharedData = context.sharedData(KOTEXT_SHARED_LOADING_ID);
@@ -439,14 +444,14 @@ void KoTextLoader::loadParagraph(const KoXmlElement &element, QTextCursor &curso
 
     // Some paragraph have id's defined which we need to store so that we can eg
     // attach text animations to this specific paragraph later on
-    if (element.hasAttributeNS(KoXmlNS::text, "id")) {
+    if (element.hasAttributeNS(KoXmlNS::text, "id") && d->shape) {
         QTextBlock block = cursor.block();
         KoTextBlockData *data = dynamic_cast<KoTextBlockData*>(block.userData());
         if (!data) {
             data = new KoTextBlockData();
             block.setUserData(data);
         }
-        d->context.addShapeSubItemId(0, qVariantFromValue(data), element.attributeNS(KoXmlNS::text, "id"));
+        d->context.addShapeSubItemId(d->shape, QVariant::fromValue(data), element.attributeNS(KoXmlNS::text, "id"));
     }
 
     // attach Rdf to cursor.block()
@@ -834,8 +839,7 @@ void KoTextLoader::loadSpan(const KoXmlElement &element, QTextCursor &cursor, bo
         const QString localName(ts.localName());
         const bool isTextNS = ts.namespaceURI() == KoXmlNS::text;
         const bool isDrawNS = ts.namespaceURI() == KoXmlNS::draw;
-        const bool isOfficeNS = ts.namespaceURI() == KoXmlNS::office;
-
+//        const bool isOfficeNS = ts.namespaceURI() == KoXmlNS::office;
         if (node.isText()) {
             QString text = node.toText().data();
 #ifdef KOOPENDOCUMENTLOADER_DEBUG
@@ -1124,8 +1128,11 @@ void KoTextLoader::loadDeleteChangeWithinPorH(QString id, QTextCursor &cursor)
 
 void KoTextLoader::loadTable(const KoXmlElement &tableElem, QTextCursor &cursor)
 {
-    cursor.insertText("\n");
-    cursor.movePosition(QTextCursor::Left, QTextCursor::MoveAnchor, 1);
+    //add block before table,
+    if (cursor.block().blockNumber() != 0) {
+        cursor.insertBlock(QTextBlockFormat());
+    }
+
     QTextTableFormat tableFormat;
     QString tableStyleName = tableElem.attributeNS(KoXmlNS::table, "style-name", "");
     if (!tableStyleName.isEmpty()) {
@@ -1133,6 +1140,15 @@ void KoTextLoader::loadTable(const KoXmlElement &tableElem, QTextCursor &cursor)
         if (tblStyle)
             tblStyle->applyStyle(tableFormat);
     }
+
+    // if table has master page style property, copy it to block before table, because this block belongs to table
+    QVariant masterStyle = tableFormat.property(KoTableStyle::MasterPageName);
+    if (!masterStyle.isNull()) {
+        QTextBlockFormat textBlockFormat;
+        textBlockFormat.setProperty(KoParagraphStyle::MasterPageName,masterStyle);
+        cursor.setBlockFormat(textBlockFormat);
+    }
+
     KoTableColumnAndRowStyleManager *tcarManager = new KoTableColumnAndRowStyleManager;
     tableFormat.setProperty(KoTableStyle::ColumnAndRowStyleManager, QVariant::fromValue(reinterpret_cast<void *>(tcarManager)));
     QTextTable *tbl = cursor.insertTable(1, 1, tableFormat);
