@@ -3,7 +3,7 @@
  * Copyright (C) 2007 Thomas Zander <zander@kde.org>
  * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
  * Copyright (C) 2007 Pierre Ducroquet <pinaraf@gmail.com>
- * Copyright (C) 2007-2008 Thorsten Zachmann <zachmann@kde.org>
+ * Copyright (C) 2007-2009 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -27,11 +27,13 @@
 #include <QObject>
 
 #include "kotext_export.h"
+#include "KoXmlReaderForward.h"
 
-class KoXmlElement;
 class KoShapeLoadingContext;
-
+class KoShape;
 class QTextCursor;
+class KoBookmarkManager;
+class KoDocumentRdfBase;
 
 /**
  * The KoTextLoader loads is use to load text for one and only one textdocument or shape
@@ -49,12 +51,22 @@ class KOTEXT_EXPORT KoTextLoader : public QObject
     Q_OBJECT
 public:
 
+    /**
+     * Tries to determine if passing \p element to \a loadBody() would result in rich text
+     *
+     * \param element the element to test for richtext
+     * \return \p true if rich text was detected
+     */
+    static bool containsRichText(const KoXmlElement &element);
+
     /**
     * Constructor.
+    * Notice that despite this being a QObject there is no 'parent' available for
+    * memory management here.
     *
     * @param context The context the KoTextLoader is called in
     */
-    explicit KoTextLoader(KoShapeLoadingContext & context);
+    explicit KoTextLoader(KoShapeLoadingContext &context, KoDocumentRdfBase *rdfData = 0, KoShape *shape = 0);
 
     /**
     * Destructor.
@@ -67,9 +79,9 @@ public:
     * This method got called e.g. at the \a KoTextShapeData::loadOdf() method if a TextShape
     * instance likes to load an ODF element.
     */
-    void loadBody(const KoXmlElement& element, QTextCursor& cursor);
+    void loadBody(const KoXmlElement &element, QTextCursor &cursor, bool isDeleteChange = false);
 
-Q_SIGNALS:
+signals:
 
     /**
     * This signal is emitted during loading with a percentage within 1-100 range
@@ -82,51 +94,59 @@ private:
     /**
     * Load the paragraph from the \p element into the \p cursor .
     */
-    void loadParagraph(const KoXmlElement& element, QTextCursor& cursor);
+    void loadParagraph(const KoXmlElement &element, QTextCursor &cursor);
 
     /**
     * Load the heading from the \p element into the \p cursor .
     */
-    void loadHeading(const KoXmlElement& element, QTextCursor& cursor);
+    void loadHeading(const KoXmlElement &element, QTextCursor &cursor);
 
     /**
     * Load the list from the \p element into the \p cursor .
     */
-    void loadList(const KoXmlElement& element, QTextCursor& cursor);
+    void loadList(const KoXmlElement &element, QTextCursor &cursor, bool isDeleteChange = false);
 
     /**
     * Load the section from the \p element into the \p cursor .
     */
-    void loadSection(const KoXmlElement& element, QTextCursor& cursor);
+    void loadSection(const KoXmlElement &element, QTextCursor &cursor);
 
     /**
     * Load the span from the \p element into the \p cursor .
     */
-    void loadSpan(const KoXmlElement& element, QTextCursor& cursor, bool *leadingSpace);
+    void loadSpan(const KoXmlElement &element, QTextCursor &cursor, bool *leadingSpace);
+
+    /**
+    * Load the deleted change within a \p or a \h and store it in the Delete Change Marker
+    */
+    void loadDeleteChangeWithinPorH(QString id, QTextCursor &cursor);
+
+    /**
+    * Load the deleted change outside of a \p or a \h and store it in the Delete Change Marker
+    */
+    void loadDeleteChangeOutsidePorH(QString id, QTextCursor &cursor);
 
     /**
      * Load the table from the \p element into the \p cursor.
      *
      * The table and its contents are placed in a new shape.
      */
-    void loadTable(const KoXmlElement& element, QTextCursor& cursor);
+    void loadTable(const KoXmlElement &element, QTextCursor& cursor);
 
     /**
      * Load a note \p element into the \p cursor.
      */
-    void loadNote(const KoXmlElement& element, QTextCursor& cursor);
+    void loadNote(const KoXmlElement &element, QTextCursor& cursor);
 
     /**
-    * Load the frame element \p element into the \p cursor .
-    *
-    * This method does normaly something like at the example above with an
-    * own implementation of \a KoTextFrameLoader to handle frames.
-    * \code
-    * KoTextFrameLoader frameloader(this);
-    * frameloader.loadFrame(context, parent, cursor);
-    * \endcode
+    * Load the shape element \p element into the \p cursor .
     */
-    void loadFrame(const KoXmlElement& element, QTextCursor& cursor);
+    void loadShape(const KoXmlElement &element, QTextCursor& cursor);
+
+    /**
+    * Load the table of content element \p element into the \p cursor .
+    */
+    void loadTableOfContents(const KoXmlElement &element, QTextCursor& cursor);
 
     /**
     * This is called in loadBody before reading the body starts.
@@ -143,6 +163,39 @@ private:
     */
     void endBody();
 
+    /**
+    * Store the delete changes in the deleteChangeTable. Will be processed with "change" is encountered
+    */
+    void storeDeleteChanges(KoXmlElement &tag);
+
+    /**
+    * Checks whether a list should be treated as a valid list. A Delete change might have a list but should not be treated as such.
+    * This Information is obtained from the ODF Metadata
+    * **This is a work-around for a bug in the spec**
+    */
+    bool isValidList(const QString& xmlId) const;
+
+    /**
+    * Checks whether a list-item should be treated as a valid list-item. A Delete change might have a list-item but should not be treated as such.
+    * This Information is obtained from the ODF Metadata
+    * **This is a work-around for a bug in the spec**
+    */
+    bool isValidListItem(const QString& xmlId) const;
+
+    /**
+    * Find the level of a list from the Metadata.
+    * **This is a work-around for a bug in the spec**
+    */
+    int listLevel(const QString& xmlId) const;
+
+    /**
+     * This is called in loadSpan to allow Cut and Paste of bookmarks. This
+     * method gives a correct, unique, name, respecting the fact that an
+     * endMarker should be the foo_lastID instead of foo_lastID+1
+     */
+    QString createUniqueBookmarkName(KoBookmarkManager* bmm, QString bookmarkName, bool isEndMarker);
+
+
     /// \internal d-pointer class.
     class Private;
     /// \internal d-pointer instance.
