@@ -21,14 +21,11 @@
 #include "TestLoading.h"
 
 #include <QtGui>
-#include <QDebug>
+#include <KDebug>
 #include <QtScript>
 #include <QtTest>
 
-#include <kdeversion.h>
-
 #include <KoStyleManager.h>
-#include <KoDocument.h>
 #include <KoOdfStylesReader.h>
 #include <KoStore.h>
 #include <KoOdfStylesReader.h>
@@ -48,6 +45,8 @@
 #include <kcomponentdata.h>
 #include <KoTextDebug.h>
 #include <KoListStyle.h>
+#include <KoTableStyle.h>
+#include <KoTableCellStyle.h>
 #include <KoTextDocumentLayout.h>
 #include <KoStyleManager.h>
 #include <KoCharacterStyle.h>
@@ -56,7 +55,12 @@
 #include <KoEmbeddedDocumentSaver.h>
 #include <KoInlineTextObjectManager.h>
 #include <KoTextSharedLoadingData.h>
+#include <KoTextSharedSavingData.h>
 #include <KoTextDocument.h>
+#include <kstandarddirs.h>
+
+#include <KoGenChanges.h>
+#include <KoChangeTracker.h>
 
 typedef KoText::Tab KoTextTab;
 // because in a QtScript, I don't seem to be able to use a namespaced type
@@ -71,7 +75,7 @@ static void showDocument(QTextDocument *document)
 }
 
 // Functions that help compare two QTextDocuments
-static bool compareFragments(const QTextFragment &actualFragment, const QTextFragment &expectedFragment)
+bool TestLoading::compareFragments(const QTextFragment &actualFragment, const QTextFragment &expectedFragment)
 {
     if (actualFragment.text() != expectedFragment.text()) {
         qDebug() << "compareFragments: text not equal " << actualFragment.text() << expectedFragment.text();
@@ -148,7 +152,7 @@ static bool compareFragments(const QTextFragment &actualFragment, const QTextFra
     return equal;
 }
 
-static bool compareTabProperties(QVariant actualTabs, QVariant expectedTabs)
+bool TestLoading::compareTabProperties(QVariant actualTabs, QVariant expectedTabs)
 {
     QList<QVariant> actualTabList = qvariant_cast<QList<QVariant> >(actualTabs);
     QList<QVariant> expectedTabList = qvariant_cast<QList<QVariant> >(expectedTabs);
@@ -173,7 +177,7 @@ static bool compareTabProperties(QVariant actualTabs, QVariant expectedTabs)
     return true;
 }
 
-static bool compareBlockFormats(const QTextBlockFormat &actualFormat, const QTextBlockFormat &expectedFormat)
+bool TestLoading::compareBlockFormats(const QTextBlockFormat &actualFormat, const QTextBlockFormat &expectedFormat)
 {
     if (actualFormat.background() != expectedFormat.background()
             || actualFormat.alignment() != expectedFormat.alignment()
@@ -193,7 +197,7 @@ static bool compareBlockFormats(const QTextBlockFormat &actualFormat, const QTex
         switch (id) {
         case KoParagraphStyle::UnnumberedListItem:
         case KoParagraphStyle::IsListHeader:
-            if (actualProperty[id].toInt() != expectedProperty[id].toBool())
+            if (actualProperty[id].toInt() != static_cast<int>(expectedProperty[id].toBool()))
                 match = false;
             break;
         case KoParagraphStyle::AutoTextIndent:
@@ -241,7 +245,7 @@ static bool compareBlockFormats(const QTextBlockFormat &actualFormat, const QTex
     return match;
 }
 
-static bool compareListFormats(const QTextListFormat &actualFormat, const QTextListFormat &expectedFormat)
+bool TestLoading::compareListFormats(const QTextListFormat &actualFormat, const QTextListFormat &expectedFormat)
 {
     QMap<int, QVariant> actualProperties = actualFormat.properties();
     actualProperties.remove(KoListStyle::StyleId);
@@ -257,7 +261,7 @@ static bool compareListFormats(const QTextListFormat &actualFormat, const QTextL
     return actualProperties == expectedProperties;
 }
 
-static bool compareBlocks(const QTextBlock &actualBlock, const QTextBlock &expectedBlock)
+bool TestLoading::compareBlocks(const QTextBlock &actualBlock, const QTextBlock &expectedBlock)
 {
     QTextList *actualList = actualBlock.textList();
     QTextList *expectedList = expectedBlock.textList();
@@ -317,14 +321,266 @@ static bool compareBlocks(const QTextBlock &actualBlock, const QTextBlock &expec
     return equal;
 }
 
-static bool compareTables(QTextTable * /*actualTable*/, QTextTable * /*expectedTable*/)
+bool TestLoading::compareTableCellFormats(QTextTableCellFormat &actualFormat, QTextTableCellFormat &expectedFormat)
 {
-    // FIXME: Cells of Tables are QTextTableCell's which contain QTextFrames
-    // KWord does not implement tables, yet.
-    return false;
+    if (actualFormat.background() != expectedFormat.background()
+            || actualFormat.leftPadding() != expectedFormat.leftPadding()
+            || actualFormat.rightPadding() != expectedFormat.rightPadding()
+            || actualFormat.topPadding() != expectedFormat.topPadding()
+            || actualFormat.bottomPadding() != expectedFormat.bottomPadding()) {
+        qDebug() << "Background or Padding mismatch";
+        qDebug() << "Actual Background: " << actualFormat.background();
+        qDebug() << "Expected background: " << expectedFormat.background();
+        qDebug() << "Actual Left Padding: " << actualFormat.leftPadding();
+        qDebug() << "Expected Left Padding: " << expectedFormat.leftPadding();
+        qDebug() << "Actual Right Padding: " << actualFormat.rightPadding();
+        qDebug() << "Expected Right Padding: " << expectedFormat.rightPadding();
+        qDebug() << "Actual Top Padding: " << actualFormat.topPadding();
+        qDebug() << "Expected Top Padding: " << expectedFormat.topPadding();
+        qDebug() << "Actual Bottom Padding: " << actualFormat.bottomPadding();
+        qDebug() << "Expected Bottom Padding: " << expectedFormat.bottomPadding();
+        return false;
+    }
+
+    // check custom properties
+    const QMap<int, QVariant> actualProperty = actualFormat.properties();
+    const QMap<int, QVariant> expectedProperty = expectedFormat.properties();
+    QList<int> allPropertyIds = actualProperty.keys();
+    allPropertyIds << expectedProperty.keys();
+    bool match = true;
+    foreach(int id, allPropertyIds) {
+        QString key, value;
+        switch (id) {
+        // double properties
+        case KoTableCellStyle::LeftBorderSpacing:
+        case KoTableCellStyle::RightBorderSpacing:
+        case KoTableCellStyle::TopBorderSpacing:
+        case KoTableCellStyle::BottomBorderSpacing:
+            if (abs(actualProperty[id].toDouble() - expectedProperty[id].toDouble()) > 1e-10) {
+                qDebug() << "Cell Border Spacing Mismatch";
+                qDebug() << "Expected Spacing: " << expectedProperty[id].toDouble();
+                qDebug() << "Actual Spacing: " << actualProperty[id].toDouble();
+                match = false;
+            }
+            break;
+        // string properties
+        case KoTableCellStyle::MasterPageName:
+            if (actualProperty[id].toString() != expectedProperty[id].toString())
+                match = false;
+            break;
+        // pen properties
+        case KoTableCellStyle::LeftBorderOuterPen:
+        case KoTableCellStyle::LeftBorderInnerPen:
+        case KoTableCellStyle::RightBorderOuterPen:
+        case KoTableCellStyle::RightBorderInnerPen:
+        case KoTableCellStyle::TopBorderOuterPen:
+        case KoTableCellStyle::TopBorderInnerPen:
+        case KoTableCellStyle::BottomBorderOuterPen:
+        case KoTableCellStyle::BottomBorderInnerPen: {
+            QPen actualPen = qvariant_cast<QPen>(actualProperty[id]);
+            QPen expectedPen = qvariant_cast<QPen>(expectedProperty[id]);
+            if (actualPen != expectedPen) {
+                qDebug() << "Cell Border Pen MisMatch";
+                qDebug() << "Actual Pen:" << actualPen;
+                qDebug() << "Expected Pen:" << expectedPen;
+                match = false;
+            }
+            break;
+        }
+        // brush properties
+        case KoTableCellStyle::CellBackgroundBrush: {
+            QBrush actualBrush = qvariant_cast<QBrush>(actualProperty[id]);
+            QBrush expectedBrush = qvariant_cast<QBrush>(expectedProperty[id]);
+            if (actualBrush != expectedBrush)
+                match = false;
+            break;
+        }
+        }
+        if (!match) {
+            qDebug() << "Actual property:   " << KoTextDebug::tableCellAttributes(actualFormat);
+            qDebug() << "Expected property: " << KoTextDebug::tableCellAttributes(expectedFormat);
+            qDebug() << "At index: QTextTableFormat::UserProperty + " << id + 7001 - QTextFormat::UserProperty;
+            return false;
+        }
+    }
+    return match;
 }
 
-static bool compareFrames(QTextFrame *actualFrame, QTextFrame *expectedFrame)
+bool TestLoading::compareTableCells(QTextTableCell &actualCell, QTextTableCell &expectedCell)
+{
+    //compare row and column spans
+    if (actualCell.rowSpan() != expectedCell.rowSpan()) {
+        qDebug() << "compareTableCells: table cell row span mismatch";
+        qDebug() << "Actual Row Span : " << actualCell.rowSpan();
+        qDebug() << "Expected Row Span : " << expectedCell.rowSpan();
+        return false;
+    }
+
+    if (actualCell.columnSpan() != expectedCell.columnSpan()) {
+        qDebug() << "comparetableCells: table cell column span mismatch";
+        qDebug() << "Actual Column Span : " << actualCell.columnSpan();
+        qDebug() << "Expected Column Span : " << expectedCell.columnSpan();
+        return false;
+    }
+
+    // compare cell formats
+    QTextTableCellFormat actualFormat = actualCell.format().toTableCellFormat();
+    QTextTableCellFormat expectedFormat = expectedCell.format().toTableCellFormat();
+
+    if (!compareTableCellFormats(actualFormat, expectedFormat)) {
+        qDebug() << "compareTableCells: table cell properties mismatch at " << actualCell.firstCursorPosition().block().text();
+        return false;
+    }
+
+    // compare cell content
+    QTextFrame::iterator actualIterator = actualCell.begin();
+    QTextFrame::iterator expectedIterator = expectedCell.begin();
+
+    for (; !actualIterator.atEnd() && !expectedIterator.atEnd(); ++actualIterator, ++expectedIterator) {
+        QTextFrame *actualChildFrame = actualIterator.currentFrame();
+        QTextBlock actualTextBlock = actualIterator.currentBlock();
+
+        if (actualChildFrame) {
+            QTextFrame *expectedChildFrame = expectedIterator.currentFrame();
+            if (!expectedChildFrame) {
+                qDebug() << "compareTableCells: Unexpected frame at " << actualTextBlock.text();
+                return false;
+            }
+            QTextTable *actualTable = qobject_cast<QTextTable *>(actualChildFrame);
+            QTextTable *expectedTable = qobject_cast<QTextTable *>(expectedChildFrame);
+            if (actualTable) {
+                if (!expectedTable) {
+                    qDebug() << "compareTableCells: Unexpected table at " << actualTextBlock.text();
+                    return false;
+                }
+                if (!compareTables(actualTable, expectedTable))
+                    return false;
+            } else {
+                if (expectedTable) {
+                    qDebug() << "compareTableCells: Expecting table at " << actualTextBlock.text();
+                    return false;
+                }
+                if (!compareFrames(actualChildFrame, expectedChildFrame))
+                    return false;
+            }
+        } else if (actualTextBlock.isValid()) {
+            QTextBlock expectedTextBlock = expectedIterator.currentBlock();
+            if (!expectedTextBlock.isValid()) {
+                qDebug() << "compareTableCells: Unexpected text block at " << actualTextBlock.text();
+                return false;
+            }
+            if (!compareBlocks(actualTextBlock, expectedTextBlock))
+                return false;
+        } else {
+            qDebug() << "compareTableCells: neither frame nor block! - internal error!";
+            return false;
+        }
+    }
+    return actualIterator.atEnd() == expectedIterator.atEnd();
+}
+
+bool TestLoading::compareTableFormats(QTextTableFormat &actualFormat, QTextTableFormat &expectedFormat)
+{
+    if (actualFormat.background() != expectedFormat.background()) {
+        qDebug() << "compareTableFormats: Background mismatch";
+        qDebug() << "Expected Background: " << expectedFormat.background();
+        qDebug() << "Actual Background: " << actualFormat.background();
+        return false;
+    }
+
+    if (actualFormat.alignment() != expectedFormat.alignment()) {
+        qDebug() << "compareTableFormats: Alignment mismatch";
+        qDebug() << "Expected Alignment: " << expectedFormat.alignment();
+        qDebug() << "Actual Alignment: " << actualFormat.alignment();
+        return false;
+    }
+
+    if (actualFormat.width() != expectedFormat.width()) {
+        qDebug() << "compareTableFormats: Width mismatch";
+        qDebug() << "Expected Width: " << expectedFormat.width();
+        qDebug() << "Actual Width: " << actualFormat.width();
+        return false;
+    }
+
+    // check custom properties
+    const QMap<int, QVariant> actualProperty = actualFormat.properties();
+    const QMap<int, QVariant> expectedProperty = expectedFormat.properties();
+    QList<int> allPropertyIds = actualProperty.keys();
+    allPropertyIds << expectedProperty.keys();
+    bool match = true;
+    foreach(int id, allPropertyIds) {
+        QString key, value;
+        switch (id) {
+        // bool properties
+        case KoTableStyle::BreakBefore:
+        case KoTableStyle::BreakAfter:
+        case KoTableStyle::KeepWithNext:
+        case KoTableStyle::MayBreakBetweenRows:
+        case KoTableStyle::CollapsingBorders:
+            if (actualProperty[id].toBool() != expectedProperty[id].toBool())
+                match = false;
+            break;
+        // double properties
+        case QTextFormat::FrameLeftMargin:
+        case QTextFormat::FrameRightMargin:
+        case QTextFormat::FrameTopMargin:
+        case QTextFormat::FrameBottomMargin:
+            if (abs(actualProperty[id].toDouble() - expectedProperty[id].toDouble()) > 1e-10)
+                match = false;
+            break;
+        // string properties
+        case KoTableStyle::MasterPageName:
+            if (actualProperty[id].toString() != expectedProperty[id].toString())
+                match = false;
+            break;
+        }
+        if (!match) {
+            qDebug() << "Actual property:   " << KoTextDebug::tableAttributes(actualFormat);
+            qDebug() << "Expected property: " << KoTextDebug::tableAttributes(expectedFormat);
+            qDebug() << "At index: QTextTableFormat::UserProperty + " << id - QTextTableFormat::UserProperty;
+            return false;
+        }
+    }
+    return match;
+}
+
+bool TestLoading::compareTables(QTextTable *actualTable, QTextTable *expectedTable)
+{
+    QTextTableFormat actualFormat = actualTable->format();
+    QTextTableFormat expectedFormat = expectedTable->format();
+
+    if (!compareTableFormats(actualFormat, expectedFormat)) {
+        qDebug() << "compareTables: table properties mismatch at " << actualTable->cellAt(0, 0).firstCursorPosition().block().text();
+        return false;
+    }
+
+    if (actualTable->rows() != expectedTable->rows()) {
+        qDebug() << "compareTables: Rows mismatch";
+        qDebug() << "Actual Rows : " << actualTable->rows();
+        qDebug() << "Expected Rows : " << expectedTable->rows();
+        return false;
+    }
+
+    if (actualTable->columns() != expectedTable->columns()) {
+        qDebug() << "compareTables: Columns mismatch";
+        qDebug() << "Actual Columns : " << actualTable->columns();
+        qDebug() << "Expected Columns : " << expectedTable->columns();
+        return false;
+    }
+
+    for (int row = 0; row < expectedTable->rows(); ++row) {
+        for (int col = 0; col < expectedTable->columns(); ++col) {
+            QTextTableCell actualCell = actualTable->cellAt(row, col);
+            QTextTableCell expectedCell = expectedTable->cellAt(row, col);
+            if (!compareTableCells(actualCell, expectedCell)) {
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
+bool TestLoading::compareFrames(QTextFrame *actualFrame, QTextFrame *expectedFrame)
 {
     QTextFrame::iterator actualIterator = actualFrame->begin();
     QTextFrame::iterator expectedIterator = expectedFrame->begin();
@@ -372,7 +628,7 @@ static bool compareFrames(QTextFrame *actualFrame, QTextFrame *expectedFrame)
     return actualIterator.atEnd() == expectedIterator.atEnd();
 }
 
-static bool compareDocuments(QTextDocument *actualDocument, QTextDocument *expectedDocument)
+bool TestLoading::compareDocuments(QTextDocument *actualDocument, QTextDocument *expectedDocument)
 {
     QTextFrame *actualFrame = actualDocument->rootFrame();
     QTextFrame *expectedFrame = expectedDocument->rootFrame();
@@ -488,6 +744,7 @@ static QScriptValue copyFormatProperties(QScriptContext *context, QScriptEngine
 TestLoading::TestLoading()
 {
     componentData = new KComponentData("TestLoading");
+    componentData->dirs()->addResourceType("styles", "data", "kword/styles/");
 }
 
 TestLoading::~TestLoading()
@@ -551,8 +808,16 @@ void TestLoading::initTestCase()
 
     engine = new QScriptEngine();
 
-    engine->importExtension("qt.core");
-    engine->importExtension("qt.gui");
+    QScriptValue rc = engine->importExtension("qt.core");
+    if (rc.isError()) {
+        kWarning() << "Failed to find Qt bindings, aborting";
+        QSKIP("Failed to find Qt bindings (qtscript generator), aborting", SkipAll);
+    }
+    rc = engine->importExtension("qt.gui");
+    if (rc.isError()) {
+        kWarning() << "Failed to load QtGui bindings, aborting";
+        abort();
+    }
 
     QScriptValue globalObject = engine->globalObject();
     globalObject.setProperty("qApp", engine->newQObject(qApp));
@@ -586,7 +851,7 @@ void TestLoading::cleanup()
 {
 }
 
-void TestLoading::addData()
+void TestLoading::addData(LoadSave loadSave)
 {
     QTest::newRow("bulletedList") << "TextContents/Lists/bulletedList";
     QTest::newRow("continueNumbering") << "TextContents/Lists/continueNumbering";
@@ -602,19 +867,51 @@ void TestLoading::addData()
 
     QTest::newRow("attributedText") << "TextContents/Paragraph/attributedText";
     QTest::newRow("basicContents") << "TextContents/Paragraph/basicContents";
+    QTest::newRow("nestedSpan") << "TextContents/Paragraph/nestedSpan";
     QTest::newRow("whitespace") << "TextContents/Paragraph/whitespace";
 
     QTest::newRow("fontSize1") << "TextContents/TextFormatting/fontSize";
 
     QTest::newRow("fontColors") << "TextContents/TextFormatting/fontColors";
 
+    if (loadSave == TestLoadingData) {
+        QTest::newRow("simpleTable") << "Tables/simpleTable";
+        QTest::newRow("spanningCells") << "Tables/spanningCells";
+        QTest::newRow("tableWidth") << "Tables/tableWidth";
+        QTest::newRow("tableAlignment") << "Tables/tableAlignment";
+        QTest::newRow("tableTopAndBottomMargin") << "Tables/tableTopAndBottomMargin";
+        QTest::newRow("tableLeftAndRightMargin") << "Tables/tableLeftAndRightMargin";
+        QTest::newRow("tableMargins") << "Tables/tableMargins";
+        QTest::newRow("breakBeforeAndBreakAfter") << "Tables/breakBeforeAndBreakAfter";
+        QTest::newRow("mayBreakBetweenRows") << "Tables/mayBreakBetweenRows";
+        QTest::newRow("tableBackground") << "Tables/tableBackground";
+        QTest::newRow("borderModelProperty") << "Tables/borderModelProperty";
+        QTest::newRow("keepWithNext") << "Tables/keepWithNext";
+        QTest::newRow("cellBackground") << "Tables/cellBackground";
+        QTest::newRow("cellPadding") << "Tables/cellPadding";
+        QTest::newRow("cellBorder") << "Tables/cellBorder";
+        QTest::newRow("cellBorderStyle") << "Tables/cellBorderStyle";
+        QTest::newRow("cellBorderSpacing") << "Tables/cellBorderSpacing";
+    }
+
+    // TODO: Write tests for these.
+    //QTest::newRow("borderModelProperty") << "FormattingProperties/TableFormattingProperties/borderModelProperty";
+    //QTest::newRow("breakBeforeAndBreakAfter") << "FormattingProperties/TableFormattingProperties/breakBeforeAndBreakAfter";
+    //QTest::newRow("display") << "FormattingProperties/TableFormattingProperties/display";
+    //QTest::newRow("mayBreakBetweenRows") << "FormattingProperties/TableFormattingProperties/mayBreakBetweenRows";
+    //QTest::newRow("pageNumber") << "FormattingProperties/TableFormattingProperties/pageNumber";
+    //QTest::newRow("tableAlignment") << "FormattingProperties/TableFormattingProperties/tableAlignment";
+    //QTest::newRow("tableBackgroundAndBackgroundImage") << "FormattingProperties/TableFormattingProperties/tableBackgroundAndBackgroundImage";
+    //QTest::newRow("tableMargins") << "FormattingProperties/TableFormattingProperties/tableMargins";
+    //QTest::newRow("tableShadow") << "FormattingProperties/TableFormattingProperties/tableShadow";
+    //QTest::newRow("writingMode") << "FormattingProperties/TableFormattingProperties/writingMode";
+
     QTest::newRow("color") << "FormattingProperties/TextFormattingProperties/color";
+
     QTest::newRow("country") << "FormattingProperties/TextFormattingProperties/country";
     QTest::newRow("fontCharset") << "FormattingProperties/TextFormattingProperties/fontCharacterSet";
     QTest::newRow("fontFamily") << "FormattingProperties/TextFormattingProperties/fontFamily";
-#if QT_VERSION >= KDE_MAKE_VERSION(4,5,0)
     QTest::newRow("fontFamilyGeneric") << "FormattingProperties/TextFormattingProperties/fontFamilyGeneric";
-#endif
     QTest::newRow("fontName") << "FormattingProperties/TextFormattingProperties/fontName";
     QTest::newRow("fontPitch") << "FormattingProperties/TextFormattingProperties/fontPitch";
     QTest::newRow("fontSize2") << "FormattingProperties/TextFormattingProperties/fontSize";
@@ -622,9 +919,7 @@ void TestLoading::addData()
     QTest::newRow("fontWeight") << "FormattingProperties/TextFormattingProperties/fontWeight";
     QTest::newRow("fontVariant") << "FormattingProperties/TextFormattingProperties/fontVariant";
     QTest::newRow("language") << "FormattingProperties/TextFormattingProperties/language";
-#if QT_VERSION >= KDE_MAKE_VERSION(4,5,0)
     QTest::newRow("letterKerning") << "FormattingProperties/TextFormattingProperties/letterKerning";
-#endif
     QTest::newRow("lineThroughColor") << "FormattingProperties/TextFormattingProperties/lineThroughColor";
     QTest::newRow("lineThroughMode") << "FormattingProperties/TextFormattingProperties/lineThroughMode";
     QTest::newRow("lineThroughStyle") << "FormattingProperties/TextFormattingProperties/lineThroughStyle";
@@ -647,6 +942,7 @@ void TestLoading::addData()
     QTest::newRow("dropCapsDistance") << "FormattingProperties/ParagraphFormattingProperties/dropCapsDistance";
     QTest::newRow("dropCapsLength") << "FormattingProperties/ParagraphFormattingProperties/dropCapsLength";
     QTest::newRow("dropCapsLines") << "FormattingProperties/ParagraphFormattingProperties/dropCapsLines";
+    QTest::newRow("lineSpacing") << "FormattingProperties/ParagraphFormattingProperties/lineSpacing";
     QTest::newRow("margin") << "FormattingProperties/ParagraphFormattingProperties/margin";
     QTest::newRow("marginLeftRight") << "FormattingProperties/ParagraphFormattingProperties/marginLeftRight";
     QTest::newRow("marginTopBottom") << "FormattingProperties/ParagraphFormattingProperties/marginTopBottom";
@@ -691,21 +987,22 @@ QTextDocument *TestLoading::documentFromOdt(const QString &odt)
     KoXmlElement body = KoXml::namedItemNS(realBody, KoXmlNS::office, "text");
 
     KoStyleManager *styleManager = new KoStyleManager;
+    KoChangeTracker *changeTracker = new KoChangeTracker;
 
-    KoOdfLoadingContext odfLoadingContext(odfReadStore.styles(), odfReadStore.store());
-    QMap<QString, KoDataCenter *> dataCenterMap;
-    KoShapeLoadingContext shapeLoadingContext(odfLoadingContext, dataCenterMap);
+    KoOdfLoadingContext odfLoadingContext(odfReadStore.styles(), odfReadStore.store(), *componentData);
+    KoShapeLoadingContext shapeLoadingContext(odfLoadingContext, 0);
     KoTextSharedLoadingData *textSharedLoadingData = new KoTextSharedLoadingData;
-    textSharedLoadingData->loadOdfStyles(odfLoadingContext, styleManager);
+    textSharedLoadingData->loadOdfStyles(shapeLoadingContext, styleManager);
     shapeLoadingContext.addSharedData(KOTEXT_SHARED_LOADING_ID, textSharedLoadingData);
 
     KoTextShapeData *textShapeData = new KoTextShapeData;
     QTextDocument *document = new QTextDocument;
     textShapeData->setDocument(document, false /* ownership */);
     KoTextDocumentLayout *layout = new KoTextDocumentLayout(textShapeData->document());
-    layout->setInlineObjectTextManager(new KoInlineTextObjectManager(layout)); // required while saving
+    layout->setInlineTextObjectManager(new KoInlineTextObjectManager(layout)); // required while saving
     KoTextDocument(document).setStyleManager(styleManager);
     textShapeData->document()->setDocumentLayout(layout);
+    KoTextDocument(document).setChangeTracker(changeTracker);
 
     if (!textShapeData->loadOdf(body, shapeLoadingContext)) {
         qDebug() << "KoTextShapeData failed to load ODT";
@@ -742,41 +1039,74 @@ QString TestLoading::documentToOdt(QTextDocument *document)
     KoXmlWriter xmlWriter(&contentTmpFile, 1);
 
     KoGenStyles mainStyles;
+    KoStyleManager *styleMan = KoTextDocument(document).styleManager();
+    Q_UNUSED(styleMan);
     KoEmbeddedDocumentSaver embeddedSaver;
+
+    KoGenChanges changes;
     KoShapeSavingContext context(xmlWriter, mainStyles, embeddedSaver);
 
-    xmlWriter.startElement("office:body");
-    xmlWriter.startElement("office:text");
+    KoSharedSavingData *sharedData = context.sharedData(KOTEXT_SHARED_SAVING_ID);
+    KoTextSharedSavingData *textSharedData = 0;
+    if (sharedData) {
+        textSharedData = dynamic_cast<KoTextSharedSavingData *>(sharedData);
+    }
+
+    kDebug(32500) << "sharedData" << sharedData << "textSharedData" << textSharedData;
+
+    if (!textSharedData) {
+        textSharedData = new KoTextSharedSavingData();
+        textSharedData->setGenChanges(changes);
+        if (!sharedData) {
+            context.addSharedData(KOTEXT_SHARED_SAVING_ID, textSharedData);
+        } else {
+            kWarning(32500) << "A different type of sharedData was found under the" << KOTEXT_SHARED_SAVING_ID;
+            Q_ASSERT(false);
+        }
+    }
 
     KoTextShapeData *textShapeData = new KoTextShapeData;
     textShapeData->setDocument(document, false /* ownership */);
-    if (dynamic_cast<KoTextDocumentLayout *>(document->documentLayout()) == 0) {
+    if (qobject_cast<KoTextDocumentLayout *>(document->documentLayout()) == 0) {
         // Setup layout and managers just like kotext
         KoTextDocumentLayout *layout = new KoTextDocumentLayout(textShapeData->document());
         textShapeData->document()->setDocumentLayout(layout);
-        layout->setInlineObjectTextManager(new KoInlineTextObjectManager(layout)); // required while saving
+        layout->setInlineTextObjectManager(new KoInlineTextObjectManager(layout)); // required while saving
         KoStyleManager *styleManager = new KoStyleManager;
         KoTextDocument(textShapeData->document()).setStyleManager(styleManager);
     }
-    textShapeData->saveOdf(context);
+    KoChangeTracker* changeTracker = new KoChangeTracker;
+    KoTextDocument(textShapeData->document()).setChangeTracker(changeTracker);
 
-    xmlWriter.endElement(); // office:text
-    xmlWriter.endElement(); // office:body
+    textShapeData->saveOdf(context, 0);
 
     contentTmpFile.close();
 
-    mainStyles.saveOdfAutomaticStyles(contentWriter, false);
+    mainStyles.saveOdfStyles(KoGenStyles::DocumentAutomaticStyles, contentWriter);
+
+    contentWriter->startElement("office:body");
+    contentWriter->startElement("office:text");
+
+//    changes.saveOdfChanges(contentWriter, false);
+
     contentWriter->addCompleteElement(&contentTmpFile);
 
+    contentWriter->endElement(); //office text
+    contentWriter->endElement(); //office body
+
     contentWriter->endElement(); // root element
     contentWriter->endDocument();
     delete contentWriter;
 
+
     if (!store->close())
         qWarning() << "Failed to close the store";
 
+    mainStyles.saveOdfStylesDotXml(store, manifestWriter);
+
     odfWriteStore.closeManifestWriter();
 
+
     delete store;
     delete textShapeData;
 
@@ -787,7 +1117,7 @@ void TestLoading::testLoading_data()
 {
     QTest::addColumn<QString>("testcase");
 
-    addData();
+    addData(TestLoadingData);
 }
 
 void TestLoading::testLoading()
@@ -803,6 +1133,7 @@ void TestLoading::testLoading()
 
     bool documentsEqual = compareDocuments(actualDocument, expectedDocument);
 
+    Q_UNUSED(showDocument);
 //    showDocument(actualDocument);
 //    showDocument(expectedDocument);
     if (!documentsEqual) {
@@ -818,7 +1149,7 @@ void TestLoading::testSaving_data()
 {
     QTest::addColumn<QString>("testcase");
 
-    addData();
+    addData(TestSavingData);
 }
 
 void TestLoading::testSaving()
@@ -853,4 +1184,4 @@ int main(int argc, char *argv[])
     return QTest::qExec(new TestLoading, argc, argv);
 }
 
-#include "TestLoading.moc"
+#include <TestLoading.moc>
