@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
  * Copyright (C) 2006-2007, 2009 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
  * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
  *
  * This library is free software; you can redistribute it and/or
@@ -122,6 +123,8 @@ KoListLevelProperties KoListStyle::levelProperties(int level) const
     if (d->levels.count()) {
         KoListLevelProperties llp = d->levels.begin().value();
         llp.setLevel(level);
+        // TODO make the 10 configurable.
+        llp.setIndent(level * 10.0);
         return llp;
     }
     KoListLevelProperties llp;
@@ -169,7 +172,7 @@ void KoListStyle::applyStyle(const QTextBlock &block, int level)
     KoList::applyStyle(block, this, level);
 }
 
-void KoListStyle::loadOdf(KoOdfLoadingContext& context, const KoXmlElement& style)
+void KoListStyle::loadOdf(KoShapeLoadingContext& scontext, const KoXmlElement& style)
 {
     d->name = style.attributeNS(KoXmlNS::style, "display-name", QString());
     // if no style:display-name is given us the style:name
@@ -180,7 +183,7 @@ void KoListStyle::loadOdf(KoOdfLoadingContext& context, const KoXmlElement& styl
     KoXmlElement styleElem;
     forEachElement(styleElem, style) {
         KoListLevelProperties properties;
-        properties.loadOdf(context, styleElem);
+        properties.loadOdf(scontext, styleElem);
         if (d->styleId)
             properties.setStyleId(d->styleId);
         setLevelProperties(properties);
@@ -198,7 +201,7 @@ void KoListStyle::loadOdf(KoOdfLoadingContext& context, const KoXmlElement& styl
 
 void KoListStyle::saveOdf(KoGenStyle &style)
 {
-    if (!d->name.isEmpty()) {
+    if (!d->name.isEmpty() && !style.isDefaultStyle()) {
         style.addAttribute("style:display-name", d->name);
     }
     QBuffer buffer;
