@@ -2,7 +2,8 @@
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 2000-2005 David Faure <faure@kde.org>
    Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
-
+   Copyright (C) 2010 Boudewijn Rempt <boud@kogmbh.com>
+   
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
@@ -23,7 +24,7 @@
 #define KODOCUMENT_H
 
 #include <QtCore/QDateTime>
-#include <QtGui/QMatrix>
+#include <QtGui/QTransform>
 #include <QList>
 
 #include <kparts/part.h>
@@ -39,6 +40,7 @@
 #include <KoOdfDocument.h>
 
 class QUndoCommand;
+class QGraphicsItem;
 
 class KoStore;
 class KoOdfReadStore;
@@ -358,6 +360,14 @@ public:
      */
     int viewCount() const;
 
+    /**
+     * @return a QGraphicsItem canvas displaying this document. The QGraphicsItem
+     * is created on first call. There is only one QGraphicsItem canvas that can
+     * be shown by many QGraphicsView subclasses (those should reimplement KoCanvasController
+     * as well).
+     */
+    QGraphicsItem *canvasItem();
+
     /**
      * Reimplemented from KParts::Part
      */
@@ -883,6 +893,12 @@ protected:
 
     virtual KoView *createViewInstance(QWidget *parent) = 0;
 
+    /**
+     * Override this to create a QGraphicsItem that does not rely
+     * on proxying a KoCanvasController.
+     */
+    virtual QGraphicsItem *createCanvasItem();
+
     /**
      *  Loads a document from KReadOnlyPart::m_file (KParts takes care of downloading
      *  remote documents).
