@@ -2,130 +2,54 @@
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
                  2000, 2001 Werner Trobin <trobin@kde.org>
    Copyright (C) 2004 Nicolas Goutte <goutte@kde.org>
+   Copyright (C) 2009 Thomas Zander <zander@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Library General Public
+License as published by the Free Software Foundation; either
+version 2 of the License, or (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Library General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+You should have received a copy of the GNU Library General Public License
+along with this library; see the file COPYING.LIB.  If not, write to
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA.
 */
 
 #include "KoFilterManager.h"
 #include "KoFilterManager_p.h"
+#include "KoDocument.h"
+#include "KoDocumentEntry.h"
 
 #include <QFile>
 #include <QLabel>
 #include <QVBoxLayout>
-#include <q3ptrlist.h>
+#include <QList>
 #include <QApplication>
 #include <QByteArray>
-#include <Q3ValueList>
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <KoDocument.h>
-#include <klibloader.h>
-#include <k3listbox.h>
+#include <KLocale>
+#include <KMessageBox>
+#include <KLibLoader>
 #include <KSqueezedTextLabel>
-#include <kmimetype.h>
-#include <kdebug.h>
+#include <KMimeType>
+#include <KDebug>
 
 #include <queue>
 
 #include <unistd.h>
 
-class KoFilterManager::Private
-{
-public:
-    bool m_batch;
-    QByteArray m_importMimeType;
-};
-
-
-KoFilterChooser::KoFilterChooser(QWidget *parent, const QStringList &mimeTypes, const QString &nativeFormat, const KUrl &url)
-        : KDialog(parent),
-        m_mimeTypes(mimeTypes)
-{
-    setObjectName("kofilterchooser");
-    setButtons(Ok | Cancel);
-    setInitialSize(QSize(300, 350));
-    setButtons(KDialog::Ok | KDialog::Cancel);
-    setDefaultButton(KDialog::Ok);
-    setCaption(i18n("Choose Filter"));
-    setModal(true);
-
-    QWidget *page = new QWidget(this);
-    setMainWidget(page);
-
-    QVBoxLayout *layout = new QVBoxLayout(page);
-    if (url.isValid()) {
-        KSqueezedTextLabel *l = new KSqueezedTextLabel(url.path(), page);
-        layout->addWidget(l);
-    }
-    m_filterList = new K3ListBox(page, "filterlist");
-    layout->addWidget(m_filterList);
-    page->setLayout(layout);
-
-    Q_ASSERT(!m_mimeTypes.isEmpty());
-    for (QStringList::ConstIterator it = m_mimeTypes.begin();
-            it != m_mimeTypes.end();
-            it++) {
-        KMimeType::Ptr mime = KMimeType::mimeType(*it);
-        const QString name = mime ? mime->comment() : *it;
-        if (! name.isEmpty())
-            m_filterList->insertItem(name);
-    }
-
-    if (nativeFormat == "application/x-kword") {
-        const int index = m_mimeTypes.indexOf("text/plain");
-        if (index > -1)
-            m_filterList->setCurrentItem(index);
-    }
-
-    if (m_filterList->currentItem() == -1)
-        m_filterList->setCurrentItem(0);
-
-    m_filterList->centerCurrentItem();
-    m_filterList->setFocus();
-
-    connect(m_filterList, SIGNAL(selected(int)), this, SLOT(accept()));
-    resize(QSize(520, 400));//.expandedTo(minimumSizeHint()));
-}
-
-KoFilterChooser::~KoFilterChooser()
-{
-}
-
-QString KoFilterChooser::filterSelected()
-{
-    const int item = m_filterList->currentItem();
-
-    if (item > -1)
-        return m_mimeTypes [item];
-    else
-        return QString();
-}
-
-
 // static cache for filter availability
 QMap<QString, bool> KoFilterManager::m_filterAvailable;
 
-const int KoFilterManager::s_area = 30500;
-
-
 KoFilterManager::KoFilterManager(KoDocument* document) :
         m_document(document), m_parentChain(0), m_graph(""), d(new Private)
 {
-    d -> m_batch = false;
+    d->batch = false;
     if (document)
         QObject::connect(this, SIGNAL(sigProgress(int)),
                          document, SIGNAL(sigProgress(int)));
@@ -137,14 +61,14 @@ KoFilterManager::KoFilterManager(const QString& url, const QByteArray& mimetypeH
         m_document(0), m_parentChain(parentChain), m_importUrl(url), m_importUrlMimetypeHint(mimetypeHint),
         m_graph(""), d(new Private)
 {
-    d -> m_batch = false;
+    d->batch = false;
 }
 
 KoFilterManager::KoFilterManager(const QByteArray& mimeType) :
         m_document(0), m_parentChain(0), m_graph(""), d(new Private)
 {
-    d -> m_batch = false;
-    d -> m_importMimeType = mimeType;
+    d->batch = false;
+    d->importMimeType = mimeType;
 }
 
 KoFilterManager::~KoFilterManager()
@@ -163,7 +87,7 @@ QString KoFilterManager::importDocument(const QString& url, KoFilter::Conversion
     if (!m_graph.isValid()) {
         bool userCancelled = false;
 
-        kWarning(s_area) << "Can't open " << t->name() << ", trying filter chooser";
+        kWarning(30500) << "Can't open " << t->name() << ", trying filter chooser";
         if (m_document) {
             if (!m_document->isAutoErrorHandlingEnabled()) {
                 status = KoFilter::BadConversionGraph;
@@ -173,9 +97,8 @@ QString KoFilterManager::importDocument(const QString& url, KoFilter::Conversion
 
             QApplication::setOverrideCursor(Qt::ArrowCursor);
             KoFilterChooser chooser(0,
-                                    KoFilterManager::mimeFilter(nativeFormat, KoFilterManager::Import, m_document->extraNativeMimeTypes()),
-                                    nativeFormat,
-                                    u);
+                    KoFilterManager::mimeFilter(nativeFormat, KoFilterManager::Import,
+                    m_document->extraNativeMimeTypes(KoDocument::ForImport)), nativeFormat, u);
             if (chooser.exec()) {
                 QByteArray f = chooser.filterSelected().toLatin1();
 
@@ -192,8 +115,8 @@ QString KoFilterManager::importDocument(const QString& url, KoFilter::Conversion
         }
 
         if (!m_graph.isValid()) {
-            kError(s_area) << "Couldn't create a valid graph for this source mimetype: "
-            << t->name() << endl;
+            kError(30500) << "Couldn't create a valid graph for this source mimetype: "
+                << t->name();
             importErrorHelper(t->name(), userCancelled);
             status = KoFilter::BadConversionGraph;
             return QString();
@@ -204,24 +127,29 @@ QString KoFilterManager::importDocument(const QString& url, KoFilter::Conversion
     // Are we owned by a KoDocument?
     if (m_document) {
         QByteArray mimeType = m_document->nativeFormatMimeType();
-        QStringList extraMimes = m_document->extraNativeMimeTypes();
-        int i = 0, n = extraMimes.count();
+        QStringList extraMimes = m_document->extraNativeMimeTypes(KoDocument::ForImport);
+        int i = 0;
+        int n = extraMimes.count();
         chain = m_graph.chain(this, mimeType);
-        while (!chain && i < n) {
-            mimeType = extraMimes[i].toUtf8();
-            chain = m_graph.chain(this, mimeType);
+        while (i < n) {
+            QByteArray extraMime = extraMimes[i].toUtf8();
+            // TODO check if its the same target mime then continue
+            KoFilterChain::Ptr newChain(0);
+            newChain = m_graph.chain(this, extraMime);
+            if (!chain || (newChain && newChain->weight() < chain->weight()))
+                chain = newChain;
             ++i;
         }
-    } else if (!d->m_importMimeType.isEmpty()) {
-        chain = m_graph.chain(this, d->m_importMimeType);
+    } else if (!d->importMimeType.isEmpty()) {
+        chain = m_graph.chain(this, d->importMimeType);
     } else {
-        kError(s_area) << "You aren't supposed to use import() from a filter!" << endl;
+        kError(30500) << "You aren't supposed to use import() from a filter!" << endl;
         status = KoFilter::UsageError;
         return QString();
     }
 
     if (!chain) {
-        kError(s_area) << "Couldn't create a valid filter chain!" << endl;
+        kError(30500) << "Couldn't create a valid filter chain!" << endl;
         importErrorHelper(t->name());
         status = KoFilter::BadConversionGraph;
         return QString();
@@ -255,29 +183,29 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
         // We have to pick the right native mimetype as source.
         QStringList nativeMimeTypes;
         nativeMimeTypes.append(m_document->nativeFormatMimeType());
-        nativeMimeTypes += m_document->extraNativeMimeTypes();
-        QStringList::ConstIterator it = nativeMimeTypes.begin();
-        const QStringList::ConstIterator end = nativeMimeTypes.end();
+        nativeMimeTypes += m_document->extraNativeMimeTypes(KoDocument::ForImport);
+        QStringList::ConstIterator it = nativeMimeTypes.constBegin();
+        const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; !chain && it != end; ++it) {
             m_graph.setSourceMimeType((*it).toLatin1());
             if (m_graph.isValid())
                 chain = m_graph.chain(this, mimeType);
         }
     } else if (!m_importUrlMimetypeHint.isEmpty()) {
-        kDebug(s_area) << "Using the mimetype hint: '" << m_importUrlMimetypeHint << "'";
+        kDebug(30500) << "Using the mimetype hint:" << m_importUrlMimetypeHint;
         m_graph.setSourceMimeType(m_importUrlMimetypeHint);
     } else {
         KUrl u;
         u.setPath(m_importUrl);
         KMimeType::Ptr t = KMimeType::findByUrl(u, 0, true);
         if (!t || t->name() == KMimeType::defaultMimeType()) {
-            kError(s_area) << "No mimetype found for " << m_importUrl << endl;
+            kError(30500) << "No mimetype found for" << m_importUrl;
             return KoFilter::BadMimeType;
         }
         m_graph.setSourceMimeType(t->name().toLatin1());
 
         if (!m_graph.isValid()) {
-            kWarning(s_area) << "Can't open " << t->name() << ", trying filter chooser";
+            kWarning(30500) << "Can't open" << t->name() << ", trying filter chooser";
 
             QApplication::setOverrideCursor(Qt::ArrowCursor);
             KoFilterChooser chooser(0, KoFilterManager::mimeFilter(), QString(), u);
@@ -291,8 +219,8 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
     }
 
     if (!m_graph.isValid()) {
-        kError(s_area) << "Couldn't create a valid graph for this source mimetype." << endl;
-        if (!userCancelled) KMessageBox::error(0L, i18n("Could not export file."), i18n("Missing Export Filter"));
+        kError(30500) << "Couldn't create a valid graph for this source mimetype.";
+        if (!userCancelled) KMessageBox::error(0, i18n("Could not export file."), i18n("Missing Export Filter"));
         return KoFilter::BadConversionGraph;
     }
 
@@ -300,8 +228,8 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
         chain = m_graph.chain(this, mimeType);
 
     if (!chain) {
-        kError(s_area) << "Couldn't create a valid filter chain to " << mimeType << " !" << endl;
-        KMessageBox::error(0L, i18n("Could not export file."), i18n("Missing Export Filter"));
+        kError(30500) << "Couldn't create a valid filter chain to " << mimeType << " !" << endl;
+        KMessageBox::error(0, i18n("Could not export file."), i18n("Missing Export Filter"));
         return KoFilter::BadConversionGraph;
     }
 
@@ -331,19 +259,19 @@ public:
     void addEdge(Vertex* vertex) {
         if (vertex) m_edges.append(vertex);
     }
-    Q3PtrList<Vertex> edges() const {
+    QList<Vertex*> edges() const {
         return m_edges;
     }
 
 private:
     Color m_color;
     QByteArray m_mimeType;
-    Q3PtrList<Vertex> m_edges;
+    QList<Vertex*> m_edges;
 };
 
 // Some helper methods for the static stuff
 // This method builds up the graph in the passed ascii dict
-void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direction)
+void buildGraph(QHash<QByteArray, Vertex*>& vertices, KoFilterManager::Direction direction)
 {
     QStringList stopList; // Lists of mimetypes that are considered end of chains
     stopList << "text/plain";
@@ -351,31 +279,31 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
     stopList << "text/x-tex";
     stopList << "text/html";
 
-    vertices.setAutoDelete(true);
-
     // partly copied from build graph, but I don't see any other
     // way without crude hacks, as we have to obey the direction here
-    Q3ValueList<KoDocumentEntry> parts(KoDocumentEntry::query(false, QString()));
-    Q3ValueList<KoDocumentEntry>::ConstIterator partIt(parts.begin());
-    Q3ValueList<KoDocumentEntry>::ConstIterator partEnd(parts.end());
+    QList<KoDocumentEntry> parts(KoDocumentEntry::query(QFlag(KoDocumentEntry::AllEntries), QString()));
+    QList<KoDocumentEntry>::ConstIterator partIt(parts.constBegin());
+    QList<KoDocumentEntry>::ConstIterator partEnd(parts.constEnd());
 
     while (partIt != partEnd) {
         QStringList nativeMimeTypes = (*partIt).service()->property("X-KDE-ExtraNativeMimeTypes").toStringList();
         nativeMimeTypes += (*partIt).service()->property("X-KDE-NativeMimeType").toString();
-        QStringList::ConstIterator it = nativeMimeTypes.begin();
-        const QStringList::ConstIterator end = nativeMimeTypes.end();
+        QStringList::ConstIterator it = nativeMimeTypes.constBegin();
+        const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; it != end; ++it)
-            if (!(*it).isEmpty())
-                vertices.insert((*it).toLatin1(), new Vertex((*it).toLatin1()));
+            if (!(*it).isEmpty()) {
+                const QByteArray key = (*it).toLatin1();
+                if (!vertices.contains(key))
+                    vertices.insert(key, new Vertex(key));
+            }
         ++partIt;
     }
 
-    Q3ValueList<KoFilterEntry::Ptr> filters = KoFilterEntry::query(); // no constraint here - we want *all* :)
-    Q3ValueList<KoFilterEntry::Ptr>::ConstIterator it = filters.begin();
-    const Q3ValueList<KoFilterEntry::Ptr>::ConstIterator end = filters.end();
-
+    QList<KoFilterEntry::Ptr> filters = KoFilterEntry::query(); // no constraint here - we want *all* :)
+    QList<KoFilterEntry::Ptr>::ConstIterator it = filters.constBegin();
+    QList<KoFilterEntry::Ptr>::ConstIterator end = filters.constEnd();
+    foreach(KoFilterEntry::Ptr filterEntry, filters)
     for (; it != end; ++it) {
-
         QStringList impList; // Import list
         QStringList expList; // Export list
 
@@ -386,7 +314,6 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
                 if (!stopList.contains(testIt))
                     expList.append(testIt);
             }
-
             impList = (*it)->import;
         } else {
             // Export: "stop" mime type should not appear in import
@@ -394,7 +321,6 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
                 if (!stopList.contains(testIt))
                     impList.append(testIt);
             }
-
             expList = (*it)->export_;
         }
 
@@ -405,8 +331,8 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
         }
 
         // First add the "starting points" to the dict
-        QStringList::ConstIterator importIt = impList.begin();
-        const QStringList::ConstIterator importEnd = impList.end();
+        QStringList::ConstIterator importIt = impList.constBegin();
+        const QStringList::ConstIterator importEnd = impList.constEnd();
         for (; importIt != importEnd; ++importIt) {
             const QByteArray key = (*importIt).toLatin1();    // latin1 is okay here (werner)
             // already there?
@@ -416,9 +342,8 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
 
         // Are we allowed to use this filter at all?
         if (KoFilterManager::filterAvailable(*it)) {
-            QStringList::ConstIterator exportIt = expList.begin();
-            const QStringList::ConstIterator exportEnd = expList.end();
-
+            QStringList::ConstIterator exportIt = expList.constBegin();
+            const QStringList::ConstIterator exportEnd = expList.constEnd();
             for (; exportIt != exportEnd; ++exportIt) {
                 // First make sure the export vertex is in place
                 const QByteArray key = (*exportIt).toLatin1();    // latin1 is okay here
@@ -431,7 +356,7 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
                 // direction (import/export)
                 // This is the chunk of code which actually differs from the
                 // graph stuff (apart from the different vertex class)
-                importIt = impList.begin(); // ### TODO: why only the first one?
+                importIt = impList.constBegin(); // ### TODO: why only the first one?
                 if (direction == KoFilterManager::Import) {
                     for (; importIt != importEnd; ++importIt)
                         exp->addEdge(vertices[(*importIt).toLatin1()]);
@@ -440,15 +365,16 @@ void buildGraph(Q3AsciiDict<Vertex>& vertices, KoFilterManager::Direction direct
                         vertices[(*importIt).toLatin1()]->addEdge(exp);
                 }
             }
-        } else
+        } else {
             kDebug(30500) << "Filter:" << (*it)->service()->name() << " does not apply.";
+        }
     }
 }
 
 // This method runs a BFS on the graph to determine the connected
 // nodes. Make sure that the graph is "cleared" (the colors of the
 // nodes are all white)
-QStringList connected(const Q3AsciiDict<Vertex>& vertices, const QByteArray& mimetype)
+QStringList connected(const QHash<QByteArray, Vertex*>& vertices, const QByteArray& mimetype)
 {
     if (mimetype.isEmpty())
         return QStringList();
@@ -464,12 +390,11 @@ QStringList connected(const Q3AsciiDict<Vertex>& vertices, const QByteArray& mim
     while (!queue.empty()) {
         v = queue.front();
         queue.pop();
-        Q3PtrList<Vertex> edges = v->edges();
-        Q3PtrListIterator<Vertex> it(edges);
-        for (; it.current(); ++it) {
-            if (it.current()->color() == Vertex::White) {
-                it.current()->setColor(Vertex::Gray);
-                queue.push(it.current());
+        QList<Vertex*> edges = v->edges();
+        foreach(Vertex* current, edges) {
+            if (current->color() == Vertex::White) {
+                current->setColor(Vertex::Gray);
+                queue.push(current);
             }
         }
         v->setColor(Vertex::Black);
@@ -477,14 +402,14 @@ QStringList connected(const Q3AsciiDict<Vertex>& vertices, const QByteArray& mim
     }
     return connected;
 }
-}
+} // anon namespace
 
 // The static method to figure out to which parts of the
 // graph this mimetype has a connection to.
-QStringList KoFilterManager::mimeFilter(const QByteArray& mimetype, Direction direction, const QStringList& extraNativeMimeTypes)
+QStringList KoFilterManager::mimeFilter(const QByteArray &mimetype, Direction direction, const QStringList &extraNativeMimeTypes)
 {
-    //kDebug(s_area) <<"mimetype=" << mimetype <<" extraNativeMimeTypes=" << extraNativeMimeTypes;
-    Q3AsciiDict<Vertex> vertices;
+    //kDebug(30500) <<"mimetype=" << mimetype <<" extraNativeMimeTypes=" << extraNativeMimeTypes;
+    QHash<QByteArray, Vertex*> vertices;
     buildGraph(vertices, direction);
 
     // TODO maybe use the fake vertex trick from the method below, to make the search faster?
@@ -497,26 +422,29 @@ QStringList KoFilterManager::mimeFilter(const QByteArray& mimetype, Direction di
     QStringList lst = nativeMimeTypes;
 
     // Now look for filters which output each of those natives mimetypes
-    foreach(const QString & natit, nativeMimeTypes) {
+    foreach(const QString &natit, nativeMimeTypes) {
         const QStringList outMimes = connected(vertices, natit.toLatin1());
-        //kDebug(s_area) <<"output formats connected to mime" << natit <<" :" << outMimes;
-        foreach(const QString & mit, outMimes) {
+        //kDebug(30500) <<"output formats connected to mime" << natit <<" :" << outMimes;
+        foreach(const QString &mit, outMimes) {
             if (!lst.contains(mit))     // append only if not there already. Qt4: QSet<QString>?
                 lst.append(mit);
         }
     }
-
+    foreach(Vertex* vertex, vertices) {
+        delete vertex;
+    }
+    vertices.clear();
     return lst;
 }
 
 QStringList KoFilterManager::mimeFilter()
 {
-    Q3AsciiDict<Vertex> vertices;
+    QHash<QByteArray, Vertex*> vertices;
     buildGraph(vertices, KoFilterManager::Import);
 
-    Q3ValueList<KoDocumentEntry> parts(KoDocumentEntry::query(false, QString()));
-    Q3ValueList<KoDocumentEntry>::ConstIterator partIt(parts.begin());
-    Q3ValueList<KoDocumentEntry>::ConstIterator partEnd(parts.end());
+    QList<KoDocumentEntry> parts(KoDocumentEntry::query(QFlag(KoDocumentEntry::AllEntries), QString()));
+    QList<KoDocumentEntry>::ConstIterator partIt(parts.constBegin());
+    QList<KoDocumentEntry>::ConstIterator partEnd(parts.constEnd());
 
     if (partIt == partEnd)
         return QStringList();
@@ -531,8 +459,8 @@ QStringList KoFilterManager::mimeFilter()
     while (partIt != partEnd) {
         QStringList nativeMimeTypes = (*partIt).service()->property("X-KDE-ExtraNativeMimeTypes").toStringList();
         nativeMimeTypes += (*partIt).service()->property("X-KDE-NativeMimeType").toString();
-        QStringList::ConstIterator it = nativeMimeTypes.begin();
-        const QStringList::ConstIterator end = nativeMimeTypes.end();
+        QStringList::ConstIterator it = nativeMimeTypes.constBegin();
+        const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; it != end; ++it)
             if (!(*it).isEmpty())
                 v->addEdge(vertices[(*it).toLatin1()]);
@@ -566,7 +494,7 @@ bool KoFilterManager::filterAvailable(KoFilterEntry::Ptr entry)
         KLibrary* library = KLibLoader::self()->library(QFile::encodeName(entry->service()->library()));
         if (!library) {
             kWarning(30500) << "Huh?? Couldn't load the lib: "
-            << KLibLoader::self()->lastErrorMessage() << endl;
+                << KLibLoader::self()->lastErrorMessage() << endl;
             m_filterAvailable[ key ] = false;
             return false;
         }
@@ -576,34 +504,33 @@ bool KoFilterManager::filterAvailable(KoFilterEntry::Ptr entry)
         KLibrary::void_function_ptr sym = library->resolveFunction(symname);
         if (!sym) {
             kWarning(30500) << "The library " << library->objectName()
-            << " does not offer a check_" << library->objectName()
-            << " function." << endl;
-            m_filterAvailable[ key ] = false;
+                << " does not offer a check_" << library->objectName()
+                << " function." << endl;
+            m_filterAvailable[key] = false;
         } else {
             typedef int (*t_func)();
             t_func check = (t_func)sym;
             m_filterAvailable[ key ] = check() == 1;
         }
     }
-    return m_filterAvailable[ key ];
+    return m_filterAvailable[key];
 }
 
 void KoFilterManager::importErrorHelper(const QString& mimeType, const bool suppressDialog)
 {
     QString tmp = i18n("Could not import file of type\n%1", mimeType);
     // ###### FIXME: use KLibLoader::lastErrorMessage() here
-    if (!suppressDialog) KMessageBox::error(0L, tmp, i18n("Missing Import Filter"));
+    if (!suppressDialog) KMessageBox::error(0, tmp, i18n("Missing Import Filter"));
 }
 
 void KoFilterManager::setBatchMode(const bool batch)
 {
-    d->m_batch = batch;
+    d->batch = batch;
 }
 
 bool KoFilterManager::getBatchMode(void) const
 {
-    return d->m_batch;
+    return d->batch;
 }
 
 #include <KoFilterManager.moc>
-#include <KoFilterManager_p.moc>
