@@ -58,6 +58,8 @@
 #include <QTextTableCell>
 #include <QTextFragment>
 
+extern int qt_defaultDpiY();
+
 // ---------------- layout helper ----------------
 Layout::Layout(KoTextDocumentLayout *parent)
         : m_styleManager(0),
@@ -71,7 +73,7 @@ Layout::Layout(KoTextDocumentLayout *parent)
         m_textShape(0),
         m_demoText(false),
         m_endOfDemoText(false),
-        m_defaultTabSizing(MM_TO_POINT(15)),
+        m_defaultTabSizing(0),
         m_currentTabStop(0),
         m_dropCapsNChars(0),
         m_dropCapsAffectsNMoreLines(0),
@@ -82,6 +84,7 @@ Layout::Layout(KoTextDocumentLayout *parent)
         m_restartingFirstCellAfterTableBreak(false)
 {
     m_frameStack.reserve(5); // avoid reallocs
+    setTabSpacing(MM_TO_POINT(15));
 }
 
 bool Layout::start()
@@ -116,6 +119,8 @@ bool Layout::isInterrupted() const
 qreal Layout::width()
 {
     Q_ASSERT(shape);
+    if (m_dropCapsNChars>0)
+        return m_dropCapsAffectedLineWidthAdjust+10;
     qreal ptWidth = m_inTable ? m_tableLayout.cellContentRect(m_tableCell).width() : shape->size().width();
     if (m_newParag)
         ptWidth -= resolveTextIndent();
@@ -189,11 +194,11 @@ bool Layout::addLine(QTextLine &line)
     }
 
     qreal height = m_format.doubleProperty(KoParagraphStyle::FixedLineHeight);
-    if (line.textLength() == 1 && m_block.text().at(line.textStart()) == QChar::ObjectReplacementCharacter && line.descent() == 0.0) {
-        // thats an (non inline) anchor then, anchors takes no height.
+    qreal objectHeight = 0.0;
+    if (line.textLength() == 1 && m_block.text().at(line.textStart()) == QChar::ObjectReplacementCharacter && line.descent() == 0.0 && line.ascent() == 0.0) {
+        // This is an anchor but not an inline anchor so set to some very small hight
         height = 0.1;
     }
-    qreal objectHeight = 0.0;
     bool useFixedLineHeight = height != 0.0;
     if (useFixedLineHeight) {
         // QTextLine has its position at the top of the line. So if the ascent changes between lines in a parag
@@ -210,9 +215,9 @@ bool Layout::addLine(QTextLine &line)
         }
     } else { // not fixed lineheight
         const bool useFontProperties = m_format.boolProperty(KoParagraphStyle::LineSpacingFromFont);
-        if (useFontProperties)
+        if (useFontProperties) {
             height = line.height();
-        else {
+        } else {
             if (m_fragmentIterator.atEnd()) // no text in parag.
                 height = m_block.charFormat().fontPointSize();
             else {
@@ -348,8 +353,6 @@ bool Layout::addLine(QTextLine &line)
     return false;
 }
 
-extern int qt_defaultDpiY();
-
 bool Layout::nextParag()
 {
     Q_ASSERT(shape);
@@ -382,6 +385,7 @@ bool Layout::nextParag()
                 m_blockData->border()->setParagraphBottom(borderBottom);
         }
     }
+
     layout = 0;
     m_blockData = 0;
     if (m_data == 0) // no shape to layout, so stop here.
@@ -403,6 +407,17 @@ bool Layout::nextParag()
         cleanupShapes();
         return false;
     }
+
+    // make sure m_tableLayout is refering to the right table
+    QTextCursor tableFinder(m_block);
+    QTextTable *table = tableFinder.currentTable();
+    if (table) {
+        // Set the current table on the table layout.
+        m_tableLayout.setTable(table);
+        // Save the current table cell.
+        m_tableCell = table->cellAt(m_block.position());
+        Q_ASSERT(m_tableCell.isValid());
+    }
     m_format = m_block.blockFormat();
     m_blockData = dynamic_cast<KoTextBlockData*>(m_block.userData());
     KoText::Direction dir = static_cast<KoText::Direction>(m_format.intProperty(KoParagraphStyle::TextProgressionDirection));
@@ -501,7 +516,8 @@ bool Layout::nextParag()
         option.setTextDirection(Qt::RightToLeft);
     else
         option.setTextDirection(Qt::LeftToRight);
-    layout->setTextOption(option);
+
+    option.setUseDesignMetrics(true);
 
     // drop caps
 
@@ -536,10 +552,12 @@ bool Layout::nextParag()
         dropCapsFormatRange.format = blockStart.charFormat();
 
         // find out lineHeight for this block.
+        QTextBlock::iterator it = m_block.begin();
+        QTextFragment lineRepresentative = it.fragment();
         qreal lineHeight = m_format.doubleProperty(KoParagraphStyle::FixedLineHeight);
         qreal dropCapsHeight = 0;
         if (lineHeight == 0) {
-            lineHeight = blockStart.charFormat().fontPointSize();
+            lineHeight = lineRepresentative.charFormat().fontPointSize();
             qreal linespacing = m_format.doubleProperty(KoParagraphStyle::LineSpacing);
             if (linespacing == 0) { // unset
                 int percent = m_format.intProperty(KoParagraphStyle::PercentLineHeight);
@@ -551,12 +569,21 @@ bool Layout::nextParag()
             dropCapsHeight = linespacing * (dropCapsLines-1);
         }
         const qreal minimum = m_format.doubleProperty(KoParagraphStyle::MinimumLineHeight);
-        if (minimum > 0.0)
+        if (minimum > 0.0) {
             lineHeight = qMax(lineHeight, minimum);
+        }
 
         dropCapsHeight += lineHeight * dropCapsLines;
 
-        QFont f(blockStart.charFormat().font(), m_parent->paintDevice());
+        int dropCapsStyleId = m_format.intProperty(KoParagraphStyle::DropCapsTextStyle);
+        KoCharacterStyle *dropCapsCharStyle = 0;
+        if (dropCapsStyleId > 0 && m_styleManager) {
+            dropCapsCharStyle = m_styleManager->characterStyle(dropCapsStyleId);
+            if (dropCapsCharStyle) {
+                dropCapsCharStyle->applyStyle(dropCapsFormatRange.format);
+            }
+        }
+        QFont f(dropCapsFormatRange.format.font(), m_parent->paintDevice());
         QString dropCapsText(m_block.text().left(dropCapsLength));
         f.setPointSizeF(dropCapsHeight);
         QChar lastChar = dropCapsText.at(dropCapsText.length()-1);
@@ -588,6 +615,8 @@ bool Layout::nextParag()
         m_dropCapsNChars = 0;
     }
 
+    layout->setTextOption(option);
+
     layout->beginLayout();
     m_fragmentIterator = m_block.begin();
     m_newParag = true;
@@ -622,13 +651,6 @@ void Layout::handleTable()
     QTextCursor tableFinder(m_block);
     QTextTable *table = tableFinder.currentTable();
     if (table) {
-        // Set the current table on the table layout.
-        m_tableLayout.setTable(table);
-
-        // Save the current table cell.
-        m_tableCell = table->cellAt(m_block.position());
-        Q_ASSERT(m_tableCell.isValid());
-
         // previousCell is the cell that the previous blocks are in. It can be
         // the same as the current cell, or it can be different, or it can be
         // invalid (if the previous cell is not in a table at all).
@@ -689,7 +711,7 @@ void Layout::handleTable()
                 // Since we have just stepped into this cell lets
                 // adjust the Y position of the layout to the Y
                 // position of the cell content rectangle.
-                m_y = m_tableLayout.cellContentRect(m_tableCell).y();
+                m_y = m_tableLayout.cellContentY(m_tableCell);
             }
         }
         m_inTable = true; // We are inside a table.
@@ -1078,6 +1100,10 @@ void Layout::drawFrame(QTextFrame *frame, QPainter *painter, const KoTextDocumen
             qSwap(selectionStart, selectionEnd);
     }
 
+    // we need to access the whole (parent) table when trying to find out the clipping rectangle
+    // for the current table cell (we will use cellAt(...) method), thus we try to get the table from frame
+    QTextTable *wholeTable = qobject_cast<QTextTable*>(frame);
+
     QTextFrame::iterator it;
     for (it = frame->begin(); !(it.atEnd()); ++it) {
         QTextBlock block = it.currentBlock();
@@ -1102,7 +1128,7 @@ void Layout::drawFrame(QTextFrame *frame, QPainter *painter, const KoTextDocumen
 
         QTextLayout *layout = block.layout();
 
-        if (!painter->hasClipping() || ! clipRegion.intersect(QRegion(layout->boundingRect().toRect())).isEmpty()) {
+        if (!painter->hasClipping() || clipRegion.intersects(layout->boundingRect().toRect())) {
             started = true;
 
             KoTextBlockData *blockData = dynamic_cast<KoTextBlockData*>(block.userData());
@@ -1118,6 +1144,7 @@ void Layout::drawFrame(QTextFrame *frame, QPainter *painter, const KoTextDocumen
             if (!paintStrategy->isVisible())
                 continue; // this paragraph shouldn't be shown so just skip it
 
+            painter->save();
             QBrush bg = paintStrategy->background(block.blockFormat().background());
             if (bg != Qt::NoBrush)
                 painter->fillRect(layout->boundingRect(), bg);
@@ -1151,15 +1178,32 @@ void Layout::drawFrame(QTextFrame *frame, QPainter *painter, const KoTextDocumen
                     selection.format.property(KoCharacterStyle::ChangeTrackerId);
                 }
             }
+
+           QRectF clipRect;                 // create an empty clipping rectangle
+
+            if (wholeTable) {               // if we're in the table drawing
+                QTextTableCell currentCell = wholeTable->cellAt(block.position());  // get the currently drawn cell
+
+                if (currentCell.isValid()) {                                        // and if the cell is valid
+                    clipRect = m_tableLayout.cellBoundingRect(currentCell);         // get the bounding rectangle from it
+                }
+            }
+
             drawTrackedChangeItem(painter, block, selectionStart - block.position(), selectionEnd - block.position(), context.viewConverter);
+            if (clipRect.isValid()) {
+                painter->save();
+                painter->setClipRect(clipRect, Qt::IntersectClip);
+            }
             layout->draw(painter, QPointF(0, 0), selections);
+            if (clipRect.isValid()) {
+                painter->restore();
+            }
             decorateParagraph(painter, block, selectionStart - block.position(), selectionEnd - block.position(), context.viewConverter);
 
             if (lastBorder && lastBorder != border) {
-                painter->save();
                 lastBorder->paint(*painter);
-                painter->restore();
             }
+            painter->restore();
             lastBorder = border;
         } else if (started && inTable==0) {
             // when out of the cliprect and no longer in a table, then we are done drawing.
@@ -2020,3 +2064,8 @@ void Layout::updateFrameStack()
         }
     }
 }
+
+void Layout::setTabSpacing(qreal spacing)
+{
+    m_defaultTabSizing = spacing * qt_defaultDpiY() / 72.;
+}
