@@ -260,7 +260,10 @@ void TableLayout::layoutRow(int row)
     KoTableRowStyle *rowStyle = carsManager ? carsManager->rowStyle(row) : 0;
 
     // Adjust row height.
-    qreal rowHeight = rowStyle ? rowStyle->minimumRowHeight() : 0.0;
+    qreal minimumRowHeight = rowStyle ? rowStyle->minimumRowHeight() : 0.0;
+    qreal rowHeight = rowStyle ? rowStyle->rowHeight() : 0.0;
+    bool rowHasExactHeight = rowStyle ? rowStyle->hasProperty(KoTableRowStyle::RowHeight) : false;
+
     int col = 0;
     while (col < m_table->columns()) {
         // Get the cell format.
@@ -284,11 +287,14 @@ void TableLayout::layoutRow(int row)
                 cellHeight -= m_tableLayoutData->m_rowHeights[rowAbove];
             }
 
-            /*
-             * Now we know how much height this cell contributes to the row,
-             * and can determine wheather the row height will grow.
-             */
-            rowHeight = qMax(rowHeight, cellHeight);
+            // if the row does not have exact height defined
+            if (!rowHasExactHeight) {
+                /*
+                 * Now we know how much height this cell contributes to the row,
+                 * and can determine wheather the row height will grow.
+                 */
+                rowHeight = qMax(qMax(minimumRowHeight, cellHeight), rowHeight);
+            }
         }
         col += cell.columnSpan(); // Skip across column spans.
     }
@@ -371,32 +377,30 @@ void TableLayout::drawBorders(QPainter *painter, QPainterPath *accuBlankBorders)
                     QRectF bRect = cellBoundingRect(tableCell);
 
                     // First the horizontal borders
-                    if (row == 0)
+                    if (row == 0) {
                         cellStyle.drawTopHorizontalBorder(*painter, bRect.x(), bRect.y(), bRect.width(), accuBlankBorders);
-
+                    }
                     if (row + tableCell.rowSpan() == m_table->rows()) {
                         // we hit the bottom of the table so just draw the bottom border
                         cellStyle.drawBottomHorizontalBorder(*painter, bRect.x(), bRect.bottom(), bRect.width(), accuBlankBorders);
                     } else {
                         // we have cells below so draw sharedborders
                         QTextTableCell tableCellBelow;
-
                         for (int c = column; c < column + tableCell.columnSpan();
                                                     c = tableCellBelow.column()+tableCellBelow.columnSpan()) {
                             tableCellBelow = m_table->cellAt(row + tableCell.rowSpan()-1+1, c);
                             QRectF belowBRect = cellBoundingRect(tableCellBelow);
                             qreal x = qMax(bRect.x(), belowBRect.x());
                             qreal x2 = qMin(bRect.right(), belowBRect.right());
-
                             KoTableCellStyle cellBelowStyle(tableCellBelow.format().toTableCellFormat());
                             cellStyle.drawSharedHorizontalBorder(*painter, cellBelowStyle, x, bRect.bottom(), x2 - x, accuBlankBorders);
                         }
                     }
 
                     // And then the same treatment for vertical borders
-                    if (column == 0)
+                    if (column == 0) {
                         cellStyle.drawLeftmostVerticalBorder(*painter, bRect.x(), bRect.y(), bRect.height(), accuBlankBorders);
-
+                    }
                     if (column + tableCell.columnSpan() == m_table->columns()) {
                         // we hit the rightmost edge of the table so draw the rightmost border
                         cellStyle.drawRightmostVerticalBorder(*painter, bRect.right(), bRect.y(), bRect.height(), accuBlankBorders);
@@ -414,6 +418,8 @@ void TableLayout::drawBorders(QPainter *painter, QPainterPath *accuBlankBorders)
                             cellStyle.drawSharedVerticalBorder(*painter, cellBelowRight, bRect.right(), y, y2-y, accuBlankBorders);
                         }
                     }
+                    // Paint diagonal borders for current cell
+                    cellStyle.paintDiagonalBorders(*painter, bRect);
                 } else { // separating border model
                     cellStyle.paintBorders(*painter, cellBoundingRect(tableCell));
                 }
@@ -447,6 +453,19 @@ QTextTableCell TableLayout::hitTestTable(const QPointF &point) const
     return QTextTableCell();
 }
 
+qreal TableLayout::cellContentY(const QTextTableCell &cell) const
+{
+    Q_ASSERT(isValid());
+    Q_ASSERT(cell.isValid());
+
+    /*
+     * Get the cell style and return the bounding rect adjusted for
+     * borders and paddings by calling KoTableCellStyle::contentRect().
+     */
+    KoTableCellStyle cellStyle(cell.format().toTableCellFormat());
+    return m_tableLayoutData->m_rowPositions[cell.row()] + cellStyle.topPadding() + cellStyle.topBorderWidth();
+}
+
 QRectF TableLayout::cellContentRect(const QTextTableCell &cell) const
 {
     Q_ASSERT(isValid());
@@ -465,8 +484,10 @@ QRectF TableLayout::cellBoundingRect(const QTextTableCell &cell) const
     Q_ASSERT(isValid());
     Q_ASSERT(cell.row() < m_tableLayoutData->m_rowPositions.size());
     TableRect tableRect = m_tableLayoutData->m_tableRects.last();
+    int i = m_tableLayoutData->m_tableRects.size()-1;
     while (tableRect.fromRow > cell.row()) {
-        tableRect =  m_tableLayoutData->m_tableRects.first();
+        --i;
+        tableRect =  m_tableLayoutData->m_tableRects[i];
     }
     Q_ASSERT(cell.column() + cell.columnSpan() <=  tableRect.columnPositions.size());
 
@@ -491,8 +512,10 @@ QRectF TableLayout::rowBoundingRect(int row) const
 {
     Q_ASSERT(row < m_tableLayoutData->m_rowPositions.size());
     TableRect tableRect = m_tableLayoutData->m_tableRects.last();
+    int i = m_tableLayoutData->m_tableRects.size()-1;
     while (tableRect.fromRow > row) {
-        tableRect =  m_tableLayoutData->m_tableRects.first();
+        --i;
+        tableRect =  m_tableLayoutData->m_tableRects[i];
     }
     return QRectF(tableRect.rect.left(), m_tableLayoutData->m_rowPositions[row],
                 tableRect.rect.width(),  m_tableLayoutData->m_rowHeights[row]);
@@ -508,11 +531,15 @@ void TableLayout::setCellContentHeight(const QTextTableCell &cell, qreal bottom)
 
     KoTableCellStyle cellStyle(cell.format().toTableCellFormat());
     qreal top = m_tableLayoutData->m_rowPositions[cell.row()]
-        + cellStyle.topPadding() + cellStyle.topBorderWidth();
-    Q_ASSERT(bottom >= top);
+    + cellStyle.topPadding() + cellStyle.topBorderWidth();
+    qreal contentHeight = bottom - top;
+    if (contentHeight < (qreal)0.126) // rounding problems due to Qt-scribe internally using ints.
+        contentHeight = (qreal)0.0;
+
+    Q_ASSERT(contentHeight >= 0);
 
     // Update content height value of the cell.
-    m_tableLayoutData->m_contentHeights[cell.row()][cell.column()] = bottom - top;
+    m_tableLayoutData->m_contentHeights[cell.row()][cell.column()] = contentHeight;
 }
 
 QTextTableCell TableLayout::cellAt(int position) const
