@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006-2010 Thomas Zander <zander@kde.org>
  * Copyright (C) 2008-2010 Thorsten Zachmann <zachmann@kde.org>
  * Copyright (C) 2008 Pierre Stirnweiss \pierre.stirnweiss_koffice@gadz.org>
  *
@@ -19,6 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "TextShape.h"
+#include <KoTextSharedLoadingData.h>
 
 #define synchronized(T) QMutex T; \
     for(Finalizer finalizer(T); finalizer.loop(); finalizer.inc())
@@ -41,6 +42,7 @@ struct Finalizer {
 };
 
 #include "Layout.h"
+//#include "TextLayerShape.h"
 
 #include <KoCanvasBase.h>
 #include <KoResourceManager.h>
@@ -132,8 +134,6 @@ void TextShape::paintComponent(QPainter &painter, const KoViewConverter &convert
     Q_ASSERT(doc);
     KoTextDocumentLayout *lay = qobject_cast<KoTextDocumentLayout*>(doc->documentLayout());
 
-    //lay->state()->setImageCollection(m_imageCollection);
-
     if (m_textShapeData->endPosition() < 0) { // not layouted yet.
         if (lay == 0) {
             kWarning(32500) << "Painting shape that doesn't have a kotext doc-layout, which can't work";
@@ -325,7 +325,7 @@ void TextShape::saveOdf(KoShapeSavingContext &context) const
     }
     const bool saveMyText = index == 0 && !m_demoText; // only save the text once.
 
-    m_textShapeData->saveOdf(context, 0, saveMyText ? -1 : 0);
+    m_textShapeData->saveOdf(context, 0, 0, saveMyText ? -1 : 0);
     writer.endElement(); // draw:text-box
     saveOdfCommonChildElements(context);
     writer.endElement(); // draw:frame
@@ -393,7 +393,7 @@ bool TextShape::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &cont
 
     if (style) {
         KoParagraphStyle paragraphStyle;
-        paragraphStyle.loadOdf(style, context.odfLoadingContext());
+        paragraphStyle.loadOdf(style, context);
 
         QTextDocument *document = m_textShapeData->document();
         QTextCursor cursor(document);
@@ -424,7 +424,7 @@ bool TextShape::loadOdfFrame(const KoXmlElement &element, KoShapeLoadingContext
 
 bool TextShape::loadOdfFrameElement(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
-    return m_textShapeData->loadOdf(element, context);
+    return m_textShapeData->loadOdf(element, context, 0, this);
 }
 
 QTextDocument *TextShape::footnoteDocument()
@@ -461,6 +461,12 @@ void TextShape::update(const QRectF &shape) const
 
 void TextShape::waitUntilReady(const KoViewConverter &, bool asynchronous) const
 {
+    KoTextDocumentLayout *lay = qobject_cast<KoTextDocumentLayout*>(m_textShapeData->document()->documentLayout());
+    Q_ASSERT(lay);
+    if (!lay->hasLayouter()) {
+        lay->setLayout(new Layout(lay));
+    }
+
     if (asynchronous) {
         synchronized(m_mutex) {
             if (m_textShapeData->isDirty()) {
