@@ -562,9 +562,9 @@ void TextTool::paint(QPainter &painter, const KoViewConverter &converter)
             continue;
 
         painter.save();
-        QMatrix shapeMatrix = ts->absoluteTransformation(&converter);
+        QTransform shapeMatrix = ts->absoluteTransformation(&converter);
         shapeMatrix.scale(zoomX, zoomY);
-        painter.setMatrix(shapeMatrix * painter.matrix());
+        painter.setTransform(shapeMatrix * painter.transform());
         painter.setClipRect(QRectF(QPointF(), ts->size()), Qt::IntersectClip);
         painter.translate(0, -data->documentOffset());
         if ((data->endPosition() >= selectStart && data->position() <= selectEnd)
@@ -968,9 +968,10 @@ void TextTool::keyPressEvent(QKeyEvent *event)
             if (!textEditor->hasSelection() && event->modifiers() & Qt::ControlModifier) // delete prev word.
                 textEditor->movePosition(QTextCursor::PreviousWord, QTextCursor::KeepAnchor);
             if (m_actionRecordChanges->isChecked())
-              textEditor->addCommand(new ChangeTrackedDeleteCommand(ChangeTrackedDeleteCommand::PreviousChar, this));
+                textEditor->addCommand(new ChangeTrackedDeleteCommand(
+                            ChangeTrackedDeleteCommand::PreviousChar, this));
             else
-              textEditor->addCommand(new DeleteCommand(DeleteCommand::PreviousChar, this));
+                textEditor->addCommand(new DeleteCommand(DeleteCommand::PreviousChar, this));
             editingPluginEvents();
         }
         ensureCursorVisible();
@@ -1109,7 +1110,8 @@ void TextTool::keyPressEvent(QKeyEvent *event)
         m_caretTimer.stop();
         m_caretTimer.start();
         m_caretTimerState = moveOperation != QTextCursor::NoMove; // turn caret off while typing
-        if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return) // except the enter key
+        if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return
+                || event->key() == Qt::Key_Backspace) // except the enter/backspace key
             m_caretTimerState = true;
     }
 
@@ -1126,7 +1128,7 @@ QVariant TextTool::inputMethodQuery(Qt::InputMethodQuery query, const KoViewConv
         // The rectangle covering the area of the input cursor in widget coordinates.
         QRectF rect = textRect(textEditor->position(), textEditor->position());
         rect.moveTop(rect.top() - m_textShapeData->documentOffset());
-        QMatrix shapeMatrix = m_textShape->absoluteTransformation(&converter);
+        QTransform shapeMatrix = m_textShape->absoluteTransformation(&converter);
         qreal zoomX, zoomY;
         converter.zoom(&zoomX, &zoomY);
         shapeMatrix.scale(zoomX, zoomY);
@@ -1321,8 +1323,7 @@ void TextTool::activate(ToolActivation toolActivation, const QSet<KoShape*> &sha
         }
     }
 
-    m_textShape->update();
-
+    repaintSelection();
     updateSelectionHandler();
     updateActions();
     updateStyleManager();
