@@ -201,6 +201,7 @@ enum RecordType {
     EMR_POLYLINETO16           = 0x00000059,
     EMR_POLYPOLYLINE16         = 0x0000005A,
     EMR_POLYPOLYGON16          = 0x0000005B,
+    EMR_CREATEMONOBRUSH        = 0x0000005D,
     EMR_EXTCREATEPEN           = 0x0000005F,
     EMR_SETICMMODE             = 0x00000062,
     EMR_SETLAYOUT              = 0x00000073,
@@ -511,6 +512,7 @@ bool Parser::readRecord( QDataStream &stream )
         stream >> clip;
         kDebug(33100) << "EMR_INTERSECTCLIPRECT" << clip;
     }
+    break;
     case EMR_SAVEDC:
     {
         mOutput->saveDC();
@@ -937,6 +939,41 @@ bool Parser::readRecord( QDataStream &stream )
             mOutput->polyPolygon16( bounds, aPoints );
         }
         break;
+    case EMR_CREATEMONOBRUSH:
+        // MS-EMF 2.3.7.5: EMR_CREATEMONOBRUSH Record
+        {
+            kDebug(31000) << "EMR_CREATEMONOBRUSH ============================";
+
+            quint32 ihBrush;    // Index in the EMF Object Table
+            stream >> ihBrush;
+            quint32 usage;      // DIBColors enumeration
+            stream >> usage;
+            quint32 offBmi;     // Offset of the DIB header
+            stream >> offBmi;
+            quint32 cbBmi;      // Size of the DIB header
+            stream >> cbBmi;
+            quint32 offBits;    // Offset of the bitmap
+            stream >> offBits;
+            quint32 cbBits;     // Size of the bitmap
+            stream >> cbBits;
+
+#if 1
+            kDebug(31000) << "index:" << ihBrush;
+            kDebug(31000) << "DIBColors enum:" << usage;
+            kDebug(31000) << "header offset:" << offBmi;
+            kDebug(31000) << "header size:  " << cbBmi;
+            kDebug(31000) << "bitmap offset:" << offBits;
+            kDebug(31000) << "bitmap size:  " << cbBits;
+#endif
+
+            // FIXME: Handle the usage DIBColors info.
+            Bitmap bitmap(stream, size, 8 + 6 * 4, // header + 6 ints
+                          offBmi, cbBmi, offBits, cbBits);
+
+	    mOutput->createMonoBrush(ihBrush, &bitmap);
+
+        }
+        break;
     case EMR_EXTCREATEPEN:
 	{
 	    quint32 ihPen;
