@@ -29,6 +29,7 @@
 
 #define PanTool_ID "PanTool"
 #define TextTool_ID "TextToolFactory_ID"
+#define CellTool_ID "FreOfficeCellToolId"
 
 /*!
 * Size of full screen button
@@ -62,19 +63,37 @@ const QString ABOUT_DIALOG_KOFFICE_PIXMAP("/usr/share/icons/hicolor/64x64/apps/f
  * * Nokia pixmap in about dialog
  * */
 const QString ABOUT_DIALOG_NOKIA_PIXMAP("/usr/share/icons/hicolor/scalable/hildon/about_nokia_logo.png");
+/*!
+ * * notes view icon
+ * */
+const QString VIEW_NOTES_PIXMAP(":/images/64x64/PresentationDrawTool/viewnotes.png");
+/*!
+* Path New Document Template
+*/
+const QString NEW_WORDDOC("/usr/share/freoffice-templates/.templates/NewDocument.odt");
+/*!
+* Path New Presentation Template
+*/
+const QString NEW_PRESENTER("/usr/share/freoffice-templates/.templates/NewPresentation.odp");
+
+/*!
+* Path New Spreadsheet Template
+*/
+const QString NEW_SPREADSHEET("/usr/share/freoffice-templates/.templates/NewSpread.ods");
 
 /*!
 * extensions
 */
 const QString EXT_PPS("pps");
-const QString EXT_PPT("ppt");
 const QString EXT_PPSX("ppsx");
+const QString EXT_PPT("ppt");
 const QString EXT_PPTX("pptx");
 const QString EXT_ODP("odp");
 const QString EXT_DOC("doc");
 const QString EXT_DOCX("docx");
 const QString EXT_ODT("odt");
 const QString EXT_TXT("txt");
+const QString EXT_RTF("rtf");
 const QString EXT_ODS("ods");
 const QString EXT_XLS("xls");
 const QString EXT_XLSX("xlsx");
@@ -94,8 +113,7 @@ const QString FREOFFICE_PATH("/com/nokia/FreOffice");
  * DBus FreOffice ServiceName
  */
 const QString FREOFFICE_SERVICE_NAME("com.nokia.FreOffice");
-
-const QString FILE_CHOOSER_FILTER("File(*.doc *.docx *.odt *.txt *.ppt *.pps *.pptx *.ppsx *.odp *.xls *.xlsx *.ods)");
+const QString FILE_CHOOSER_FILTER("Document(*.doc *.docx *.odt *.txt);;Presentation(*.ppt *.pptx *.odp *.pps *.ppsx);;Spreadsheet(*.xls *.xlsx *.ods)");
 
 const QString FREOFFICE_APPLICATION_PATH("/usr/bin/FreOffice");
 #endif // COMMON_H
